@@ -57,7 +57,6 @@
 #endif
 
 #include "cJSON.h"
-#include <hamlib/rig.h>
 
 /* define our own boolean type */
 #ifdef true
@@ -126,8 +125,8 @@ CJSON_PUBLIC(double) cJSON_GetNumberValue(const cJSON *const item)
 CJSON_PUBLIC(const char *) cJSON_Version(void)
 {
     static char version[15];
-    SNPRINTF(version, sizeof(version), "%i.%i.%i", CJSON_VERSION_MAJOR,
-             CJSON_VERSION_MINOR, CJSON_VERSION_PATCH);
+    sprintf(version, "%i.%i.%i", CJSON_VERSION_MAJOR, CJSON_VERSION_MINOR,
+            CJSON_VERSION_PATCH);
 
     return version;
 }
@@ -168,7 +167,7 @@ typedef struct internal_hooks
 /* work around MSVC error C2322: '...' address of dllimport '...' is not static */
 static void *CJSON_CDECL internal_malloc(size_t size)
 {
-    return calloc(1, size);
+    return malloc(size);
 }
 static void CJSON_CDECL internal_free(void *pointer)
 {
@@ -319,7 +318,7 @@ typedef struct
 
 /* Parse the input text to generate a number, and populate the result into item. */
 static cJSON_bool parse_number(cJSON *const item,
-                               parse_buffer *const input_buffer, int input_buffer_len)
+                               parse_buffer *const input_buffer)
 {
     double number = 0;
     unsigned char *after_end = NULL;
@@ -595,22 +594,23 @@ static cJSON_bool print_number(const cJSON *const item,
     /* This checks for NaN and Infinity */
     if (isnan(d) || isinf(d))
     {
-        SNPRINTF((char *)number_buffer, sizeof(number_buffer), "null");
-        length = strlen((char *)number_buffer);
+        length = sprintf((char *)number_buffer, "null");
+    }
+    else if (d == (double)item->valueint)
+    {
+        length = sprintf((char *)number_buffer, "%d", item->valueint);
     }
     else
     {
         /* Try 15 decimal places of precision to avoid nonsignificant nonzero digits */
-        SNPRINTF((char *)number_buffer, sizeof(number_buffer), "%1.15g", d);
-        length = strlen((char *)number_buffer);
+        length = sprintf((char *)number_buffer, "%1.15g", d);
 
         /* Check whether the original double can be recovered */
         if ((sscanf((char *)number_buffer, "%lg", &test) != 1)
                 || !compare_double((double)test, d))
         {
             /* If not, print with 17 decimal places of precision */
-            SNPRINTF((char *)number_buffer, sizeof(number_buffer), "%1.17g", d);
-            length = strlen((char *)number_buffer);
+            length = sprintf((char *)number_buffer, "%1.17g", d);
         }
     }
 
@@ -813,7 +813,7 @@ fail:
 
 /* Parse the input text into an unescaped cinput, and populate item. */
 static cJSON_bool parse_string(cJSON *const item,
-                               parse_buffer *const input_buffer, int input_buffer_len)
+                               parse_buffer *const input_buffer)
 {
     const unsigned char *input_pointer = buffer_at_offset(input_buffer) + 1;
     const unsigned char *input_end = buffer_at_offset(input_buffer) + 1;
@@ -964,7 +964,7 @@ fail:
 
 /* Render the cstring provided to an escaped version that can be printed. */
 static cJSON_bool print_string_ptr(const unsigned char *const input,
-                                   printbuffer *const output_buffer, int output_buffer_len)
+                                   printbuffer *const output_buffer)
 {
     const unsigned char *input_pointer = NULL;
     unsigned char *output = NULL;
@@ -1104,25 +1104,24 @@ static cJSON_bool print_string_ptr(const unsigned char *const input,
 }
 
 /* Invoke print_string_ptr (which is useful) on an item. */
-static cJSON_bool print_string(const cJSON *const item, printbuffer *const p,
-                               int p_len)
+static cJSON_bool print_string(const cJSON *const item, printbuffer *const p)
 {
-    return print_string_ptr((unsigned char *)item->valuestring, p, p_len);
+    return print_string_ptr((unsigned char *)item->valuestring, p);
 }
 
 /* Predeclare these prototypes. */
 static cJSON_bool parse_value(cJSON *const item,
-                              parse_buffer *const input_buffer, int output_buffer_len);
+                              parse_buffer *const input_buffer);
 static cJSON_bool print_value(const cJSON *const item,
-                              printbuffer *const output_buffer, int output_buffer_len);
+                              printbuffer *const output_buffer);
 static cJSON_bool parse_array(cJSON *const item,
-                              parse_buffer *const input_buffer, int output_buffer_len);
+                              parse_buffer *const input_buffer);
 static cJSON_bool print_array(const cJSON *const item,
-                              printbuffer *const output_buffer, int output_buffer_len);
+                              printbuffer *const output_buffer);
 static cJSON_bool parse_object(cJSON *const item,
-                               parse_buffer *const input_buffer, int output_buffer_len);
+                               parse_buffer *const input_buffer);
 static cJSON_bool print_object(const cJSON *const item,
-                               printbuffer *const output_buffer, int output_buffer_len);
+                               printbuffer *const output_buffer);
 
 /* Utility to jump whitespace and cr/lf */
 static parse_buffer *buffer_skip_whitespace(parse_buffer *const buffer)
@@ -1213,8 +1212,7 @@ CJSON_PUBLIC(cJSON *) cJSON_ParseWithLengthOpts(const char *value,
         goto fail;
     }
 
-    if (!parse_value(item, buffer_skip_whitespace(skip_utf8_bom(&buffer)),
-                     sizeof(buffer)))
+    if (!parse_value(item, buffer_skip_whitespace(skip_utf8_bom(&buffer))))
     {
         /* parse failure. ep is set. */
         goto fail;
@@ -1289,7 +1287,7 @@ static unsigned char *print(const cJSON *const item, cJSON_bool format,
                             const internal_hooks *const hooks)
 {
     static const size_t default_buffer_size = 256;
-    printbuffer buffer[16];
+    printbuffer buffer[1];
     unsigned char *printed = NULL;
 
     memset(buffer, 0, sizeof(buffer));
@@ -1306,7 +1304,7 @@ static unsigned char *print(const cJSON *const item, cJSON_bool format,
     }
 
     /* print the value */
-    if (!print_value(item, buffer, sizeof(buffer)))
+    if (!print_value(item, buffer))
     {
         goto fail;
     }
@@ -1393,7 +1391,7 @@ CJSON_PUBLIC(char *) cJSON_PrintBuffered(const cJSON *item, int prebuffer,
     p.format = fmt;
     p.hooks = global_hooks;
 
-    if (!print_value(item, &p, sizeof(p)))
+    if (!print_value(item, &p))
     {
         global_hooks.deallocate(p.buffer);
         return NULL;
@@ -1419,12 +1417,12 @@ CJSON_PUBLIC(cJSON_bool) cJSON_PrintPreallocated(cJSON *item, char *buffer,
     p.format = format;
     p.hooks = global_hooks;
 
-    return print_value(item, &p, sizeof(p));
+    return print_value(item, &p);
 }
 
 /* Parser core - when encountering text, process appropriately. */
 static cJSON_bool parse_value(cJSON *const item,
-                              parse_buffer *const input_buffer, int input_buffer_len)
+                              parse_buffer *const input_buffer)
 {
     if ((input_buffer == NULL) || (input_buffer->content == NULL))
     {
@@ -1464,7 +1462,7 @@ static cJSON_bool parse_value(cJSON *const item,
     if (can_access_at_index(input_buffer, 0)
             && (buffer_at_offset(input_buffer)[0] == '\"'))
     {
-        return parse_string(item, input_buffer, input_buffer_len);
+        return parse_string(item, input_buffer);
     }
 
     /* number */
@@ -1473,21 +1471,21 @@ static cJSON_bool parse_value(cJSON *const item,
                 || ((buffer_at_offset(input_buffer)[0] >= '0')
                     && (buffer_at_offset(input_buffer)[0] <= '9'))))
     {
-        return parse_number(item, input_buffer, input_buffer_len);
+        return parse_number(item, input_buffer);
     }
 
     /* array */
     if (can_access_at_index(input_buffer, 0)
             && (buffer_at_offset(input_buffer)[0] == '['))
     {
-        return parse_array(item, input_buffer, input_buffer_len);
+        return parse_array(item, input_buffer);
     }
 
     /* object */
     if (can_access_at_index(input_buffer, 0)
             && (buffer_at_offset(input_buffer)[0] == '{'))
     {
-        return parse_object(item, input_buffer, input_buffer_len);
+        return parse_object(item, input_buffer);
     }
 
     return false;
@@ -1495,7 +1493,7 @@ static cJSON_bool parse_value(cJSON *const item,
 
 /* Render a value to text. */
 static cJSON_bool print_value(const cJSON *const item,
-                              printbuffer *const output_buffer, int output_buffer_len)
+                              printbuffer *const output_buffer)
 {
     unsigned char *output = NULL;
 
@@ -1564,13 +1562,13 @@ static cJSON_bool print_value(const cJSON *const item,
     }
 
     case cJSON_String:
-        return print_string(item, output_buffer, output_buffer_len);
+        return print_string(item, output_buffer);
 
     case cJSON_Array:
-        return print_array(item, output_buffer, output_buffer_len);
+        return print_array(item, output_buffer);
 
     case cJSON_Object:
-        return print_object(item, output_buffer, output_buffer_len);
+        return print_object(item, output_buffer);
 
     default:
         return false;
@@ -1579,7 +1577,7 @@ static cJSON_bool print_value(const cJSON *const item,
 
 /* Build an array from input text. */
 static cJSON_bool parse_array(cJSON *const item,
-                              parse_buffer *const input_buffer, int input_buffer_len)
+                              parse_buffer *const input_buffer)
 {
     cJSON *head = NULL; /* head of the linked list */
     cJSON *current_item = NULL;
@@ -1646,7 +1644,7 @@ static cJSON_bool parse_array(cJSON *const item,
         input_buffer->offset++;
         buffer_skip_whitespace(input_buffer);
 
-        if (!parse_value(current_item, input_buffer, input_buffer_len))
+        if (!parse_value(current_item, input_buffer))
         {
             goto fail; /* failed to parse value */
         }
@@ -1689,7 +1687,7 @@ fail:
 
 /* Render an array to text */
 static cJSON_bool print_array(const cJSON *const item,
-                              printbuffer *const output_buffer, int output_buffer_len)
+                              printbuffer *const output_buffer)
 {
     unsigned char *output_pointer = NULL;
     size_t length = 0;
@@ -1715,7 +1713,7 @@ static cJSON_bool print_array(const cJSON *const item,
 
     while (current_element != NULL)
     {
-        if (!print_value(current_element, output_buffer, output_buffer_len))
+        if (!print_value(current_element, output_buffer))
         {
             return false;
         }
@@ -1762,7 +1760,7 @@ static cJSON_bool print_array(const cJSON *const item,
 
 /* Build an object from the text. */
 static cJSON_bool parse_object(cJSON *const item,
-                               parse_buffer *const input_buffer, int input_buffer_len)
+                               parse_buffer *const input_buffer)
 {
     cJSON *head = NULL; /* linked list head */
     cJSON *current_item = NULL;
@@ -1828,7 +1826,7 @@ static cJSON_bool parse_object(cJSON *const item,
         input_buffer->offset++;
         buffer_skip_whitespace(input_buffer);
 
-        if (!parse_string(current_item, input_buffer, input_buffer_len))
+        if (!parse_string(current_item, input_buffer))
         {
             goto fail; /* failed to parse name */
         }
@@ -1849,7 +1847,7 @@ static cJSON_bool parse_object(cJSON *const item,
         input_buffer->offset++;
         buffer_skip_whitespace(input_buffer);
 
-        if (!parse_value(current_item, input_buffer, input_buffer_len))
+        if (!parse_value(current_item, input_buffer))
         {
             goto fail; /* failed to parse value */
         }
@@ -1891,7 +1889,7 @@ fail:
 
 /* Render an object to text. */
 static cJSON_bool print_object(const cJSON *const item,
-                               printbuffer *const output_buffer, int output_buffer_len)
+                               printbuffer *const output_buffer)
 {
     unsigned char *output_pointer = NULL;
     size_t length = 0;
@@ -1942,8 +1940,7 @@ static cJSON_bool print_object(const cJSON *const item,
         }
 
         /* print key */
-        if (!print_string_ptr((unsigned char *)current_item->string, output_buffer,
-                              output_buffer_len))
+        if (!print_string_ptr((unsigned char *)current_item->string, output_buffer))
         {
             return false;
         }
@@ -1968,7 +1965,7 @@ static cJSON_bool print_object(const cJSON *const item,
         output_buffer->offset += length;
 
         /* print value */
-        if (!print_value(current_item, output_buffer, output_buffer_len))
+        if (!print_value(current_item, output_buffer))
         {
             return false;
         }
@@ -2573,9 +2570,9 @@ CJSON_PUBLIC(cJSON_bool) cJSON_ReplaceItemViaPointer(cJSON *const parent,
     else
     {
         /*
-             * To find the last item in array quickly, we use prev in array.
-             * We can't modify the last item's next pointer where this item was the parent's child
-             */
+         * To find the last item in array quickly, we use prev in array.
+         * We can't modify the last item's next pointer where this item was the parent's child
+         */
         if (replacement->prev != NULL)
         {
             replacement->prev->next = replacement;
@@ -2622,6 +2619,12 @@ static cJSON_bool replace_item_in_object(cJSON *object, const char *string,
 
     replacement->string = (char *)cJSON_strdup((const unsigned char *)string,
                           &global_hooks);
+
+    if (replacement->string == NULL)
+    {
+        return false;
+    }
+
     replacement->type &= ~cJSON_StringIsConst;
 
     return cJSON_ReplaceItemViaPointer(object, get_object_item(object, string,
