@@ -19,8 +19,7 @@
  *
  */
 
-#include <hamlib/config.h>
-
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
@@ -29,8 +28,8 @@
 #include "idx_builtin.h"
 #include "alinco.h"
 #include <serial.h>
+#include "tones.h"
 #include <misc.h>
-#include <cal.h>
 
 /*
  * modes in use by the "2G" command
@@ -151,7 +150,7 @@ int dx77_get_mem(RIG *rig, vfo_t vfo, int *ch);
  *  - up/down
  *  - scan
  */
-const struct rig_caps dx77_caps =
+struct rig_caps dx77_caps =
 {
     RIG_MODEL(RIG_MODEL_DX77),
     .model_name =       "DX-77",
@@ -215,7 +214,6 @@ const struct rig_caps dx77_caps =
         RIG_FRNG_END,
     },
     .tx_range_list1 = {RIG_FRNG_END,},
-    .tx_range_list2 = {RIG_FRNG_END,},
 
     .rx_range_list2 =
     {
@@ -291,7 +289,7 @@ const struct rig_caps dx77_caps =
 
 /*
  * dx77_transaction
- * We assume that rig!=NULL, rig->state!= NULL, data!=NULL, data_len!=NULL
+ * We assume that rig!=NULL, RIGPORT(rig)!= NULL, data!=NULL, data_len!=NULL
  * Otherwise, you'll get a nice seg fault. You've been warned!
  * TODO: error case handling
  */
@@ -303,7 +301,7 @@ int dx77_transaction(RIG *rig,
 {
 
     int retval;
-    struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
     char echobuf[BUFSZ + 1];
 
     if (cmd == NULL)
@@ -313,11 +311,9 @@ int dx77_transaction(RIG *rig,
         return -RIG_EINTERNAL;
     }
 
-    rs = &rig->state;
+    rig_flush(rp);
 
-    rig_flush(&rs->rigport);
-
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, cmd_len);
+    retval = write_block(rp, (unsigned char *) cmd, cmd_len);
 
     if (retval != RIG_OK)
     {
@@ -328,7 +324,7 @@ int dx77_transaction(RIG *rig,
      * Transceiver sends an echo of cmd followed by a CR/LF
      * TODO: check whether cmd and echobuf match (optional)
      */
-    retval = read_string(&rs->rigport, (unsigned char *) echobuf, BUFSZ,
+    retval = read_string(rp, (unsigned char *) echobuf, BUFSZ,
                          LF, strlen(LF), 0, 1);
 
     if (retval < 0)
@@ -336,7 +332,7 @@ int dx77_transaction(RIG *rig,
         return retval;
     }
 
-    if (!(data && data_len))
+    if (((data == NULL) && (data_len > 0)) || ((data != NULL) && (data_len == 0)))
     {
         rig_debug(RIG_DEBUG_ERR, "%s: data and datalen not both NULL??\n", __func__);
         return -RIG_EINTERNAL;
@@ -345,7 +341,7 @@ int dx77_transaction(RIG *rig,
     /* no data expected, check for OK returned */
     if (data == NULL)
     {
-        retval = read_string(&rs->rigport, (unsigned char *) echobuf, BUFSZ,
+        retval = read_string(rp, (unsigned char *) echobuf, BUFSZ,
                              LF, strlen(LF), 0, 1);
 
         if (retval < 0)
@@ -367,7 +363,7 @@ int dx77_transaction(RIG *rig,
         }
     }
 
-    retval = read_string(&rs->rigport, (unsigned char *) data, BUFSZ,
+    retval = read_string(rp, (unsigned char *) data, BUFSZ,
                          LF, strlen(LF), 0, 1);
 
     if (retval < 0)
@@ -499,7 +495,6 @@ int dx77_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     }
 
     /* at least 6 digits */
-    // cppcheck-suppress *
     SNPRINTF(freqbuf, sizeof(freqbuf), AL CMD_RXFREQ "%06"PRIll EOM, (int64_t)freq);
 
     return dx77_transaction(rig, freqbuf, strlen(freqbuf), NULL, NULL);
@@ -1015,11 +1010,11 @@ int dx77_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         {
             lvl = 31;
         }
-        else if (val.i >= 6 && val.i < 20)
+        else if (val.i < 20)
         {
             lvl = val.i + 25;
         }
-        else if (val.i >= 20 && val.i <= 50)
+        else if (val.i <= 50)
         {
             lvl = val.i - 20;
         }
@@ -1263,7 +1258,7 @@ int dx77_set_parm(RIG *rig, setting_t parm, value_t val)
  */
 int dx77_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 {
-    const struct rig_caps *caps;
+    struct rig_caps *caps;
     unsigned char tonebuf[BUFSZ];
     int i;
 
