@@ -19,10 +19,9 @@
  *
  */
 
-#include <hamlib/config.h>
-
+#include <stdint.h>
 #include <stdio.h>
-#include <ctype.h>
+#include <string.h>
 
 #include "hamlib/rig.h"
 #include "serial.h"
@@ -59,7 +58,7 @@
 
 /*
  * aor_transaction
- * We assume that rig!=NULL, rig->state!= NULL, data!=NULL, data_len!=NULL
+ * We assume that rig!=NULL, STATE(rig)!= NULL, data!=NULL, data_len!=NULL
  * Otherwise, you'll get a nice seg fault. You've been warned!
  * return value: RIG_OK if everything's fine, negative value otherwise
  * TODO: error case handling
@@ -68,15 +67,13 @@ static int aor_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
                            int *data_len)
 {
     int retval;
-    struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
     char ackbuf[BUFSZ];
     int ack_len;
 
-    rs = &rig->state;
+    rig_flush(rp);
 
-    rig_flush(&rs->rigport);
-
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, cmd_len);
+    retval = write_block(rp, (unsigned char *) cmd, cmd_len);
 
     if (retval != RIG_OK)
     {
@@ -96,7 +93,7 @@ static int aor_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
     /*
      * Do wait for a reply
      */
-    retval = read_string(&rs->rigport, (unsigned char *) data, BUFSZ, EOM,
+    retval = read_string(rp, (unsigned char *) data, BUFSZ, EOM,
                          strlen(EOM), 0, 1);
 
     if (retval < 0)
@@ -125,7 +122,7 @@ static int aor_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
     if (retval >= 1 && data[0] == '?')
     {
         /* command failed? resync with radio */
-        write_block(&rs->rigport, (unsigned char *) EOM, 1);
+        write_block(rp, (unsigned char *) EOM, 1);
 
         return -RIG_EPROTO;
     }
@@ -145,7 +142,7 @@ int aor_close(RIG *rig)
      * since no reply is to be expected.
      */
 
-    return write_block(&rig->state.rigport, (unsigned char *) "EX" EOM, 3);
+    return write_block(RIGPORT(rig), (unsigned char *) "EX" EOM, 3);
 }
 
 static int format_freq(char *buf, int buf_len, freq_t freq)
@@ -175,7 +172,6 @@ static int format_freq(char *buf, int buf_len, freq_t freq)
 
     f = f * 100 + lowhz;
 
-    // cppcheck-suppress *
     SNPRINTF(buf, buf_len, "RF%010"PRIll, f);
     return strlen(buf);
 }
@@ -272,8 +268,8 @@ int aor_set_vfo(RIG *rig, vfo_t vfo)
     case RIG_VFO_MEM: vfocmd = "MR" EOM; break;
 
     default:
-        rig_debug(RIG_DEBUG_ERR, "aor_set_vfo: unsupported vfo %d\n",
-                  vfo);
+        rig_debug(RIG_DEBUG_ERR, "aor_set_vfo: unsupported vfo %s\n",
+                  rig_strvfo(vfo));
         return -RIG_EINVAL;
     }
 
@@ -541,7 +537,8 @@ int parse8k_aor_mode(RIG *rig, char aormode, char aorwidth, rmode_t *mode,
 int aor_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
     struct aor_priv_caps *priv = (struct aor_priv_caps *)rig->caps->priv;
-    char ackbuf[BUFSZ], ackbuf2[BUFSZ];
+    char ackbuf[BUFSZ];
+    char ackbuf2[BUFSZ];
     char *mdp, *mdp2;
     int ack_len, ack2_len, retval;
 
@@ -608,7 +605,7 @@ int aor_set_ts(RIG *rig, vfo_t vfo, shortfreq_t ts)
 
 /*
  * aor_set_level
- * Assumes rig!=NULL, rig->state.priv!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL
  */
 int aor_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
@@ -616,7 +613,7 @@ int aor_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     char lvlbuf[BUFSZ];
     int agc;
 
-    rs = &rig->state;
+    rs = STATE(rig);
 
 
     switch (level)
@@ -673,16 +670,14 @@ int aor_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 
 /*
  * aor_get_level
- * Assumes rig!=NULL, rig->state.priv!=NULL, val!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL, val!=NULL
  */
 int aor_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
-    struct rig_state *rs;
+    struct rig_state *rs = STATE(rig);
     char lvlbuf[BUFSZ], ackbuf[BUFSZ];
     int ack_len, retval;
 
-    rs = &rig->state;
-
     switch (level)
     {
     case RIG_LEVEL_RAWSTR:
@@ -719,7 +714,7 @@ int aor_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
         if (rig->caps->rig_model == RIG_MODEL_AR8000)
         {
-            sscanf(ackbuf + 2, "%x", &val->i);
+            sscanf(ackbuf + 2, "%x", &val->u);
             val->i &= ~0x80; /* mask squelch status */
         }
         else if (rig->caps->rig_model == RIG_MODEL_AR8200 ||
@@ -729,7 +724,7 @@ int aor_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         }
         else
         {
-            sscanf(ackbuf + 3, "%x", &val->i);
+            sscanf(ackbuf + 3, "%x", &val->u);
         }
 
         break;
@@ -760,7 +755,7 @@ int aor_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
         if (att > HAMLIB_MAXDBLSTSIZ || rs->attenuator[att - 1] == 0)
         {
-            rig_debug(RIG_DEBUG_ERR, "Unsupported att %s %d\n",
+            rig_debug(RIG_DEBUG_ERR, "Unsupported att %s %u\n",
                       __func__, att);
             return -RIG_EPROTO;
         }
@@ -823,7 +818,7 @@ int aor_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
 /*
  * aor_get_dcd
- * Assumes rig!=NULL, rig->state.priv!=NULL, val!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL, val!=NULL
  */
 int aor_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {
@@ -850,7 +845,7 @@ int aor_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 
 /*
  * aor_set_powerstat
- * Assumes rig!=NULL, rig->state.priv!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL
  */
 int aor_set_powerstat(RIG *rig, powerstat_t status)
 {
@@ -894,7 +889,7 @@ int aor_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 
 /*
  * aor_scan, scan operation
- * Assumes rig!=NULL, rig->state.priv!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL
  */
 int aor_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch)
 {
@@ -938,7 +933,7 @@ int aor_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch)
  */
 int aor_set_mem(RIG *rig, vfo_t vfo, int ch)
 {
-    struct aor_priv_caps *priv = (struct aor_priv_caps *)rig->caps->priv;
+    const struct aor_priv_caps *priv = (struct aor_priv_caps *)rig->caps->priv;
     char membuf[BUFSZ];
     int mem_num;
     char bank_base;
@@ -972,7 +967,7 @@ int aor_set_mem(RIG *rig, vfo_t vfo, int ch)
  */
 int aor_get_mem(RIG *rig, vfo_t vfo, int *ch)
 {
-    struct aor_priv_caps *priv = (struct aor_priv_caps *)rig->caps->priv;
+    const struct aor_priv_caps *priv = (struct aor_priv_caps *)rig->caps->priv;
     int mem_len, retval;
     char membuf[BUFSZ];
 
@@ -1151,7 +1146,7 @@ static int parse_chan_line(RIG *rig, channel_t *chan, char *basep,
         char *tag2p;
         tagp = strstr(basep, "MD");
 
-        if (!tagp && mem_caps->mode && mem_caps->width)
+        if (!tagp)
         {
             rig_debug(RIG_DEBUG_WARN, "%s: no MD in returned string: '%s'\n",
                       __func__, basep);
@@ -1239,7 +1234,7 @@ static int parse_chan_line(RIG *rig, channel_t *chan, char *basep,
 
 int aor_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
 {
-    struct aor_priv_caps *priv = (struct aor_priv_caps *)rig->caps->priv;
+    const struct aor_priv_caps *priv = (struct aor_priv_caps *)rig->caps->priv;
     char aorcmd[BUFSZ];
     int chan_len;
     char chanbuf[BUFSZ];
@@ -1345,9 +1340,9 @@ int aor_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
 
 int aor_get_chan_all_cb(RIG *rig, vfo_t vfo, chan_cb_t chan_cb, rig_ptr_t arg)
 {
-    struct aor_priv_caps *priv = (struct aor_priv_caps *)rig->caps->priv;
+    const struct aor_priv_caps *priv = (struct aor_priv_caps *)rig->caps->priv;
     int i, j, retval;
-    chan_t *chan_list = rig->state.chan_list;
+    chan_t *chan_list = STATE(rig)->chan_list;
     channel_t *chan;
     int chan_count;
     char aorcmd[BUFSZ];
@@ -1424,7 +1419,7 @@ int aor_get_chan_all_cb(RIG *rig, vfo_t vfo, chan_cb_t chan_cb, rig_ptr_t arg)
             /*
              * get next line
              */
-            retval = read_string(&rig->state.rigport, (unsigned char *) chanbuf, BUFSZ,
+            retval = read_string(RIGPORT(rig), (unsigned char *) chanbuf, BUFSZ,
                                  EOM, strlen(EOM), 0, 1);
 
             if (retval < 0)
@@ -1457,7 +1452,7 @@ const char *aor_get_info(RIG *rig)
         return NULL;
     }
 
-    if (retval > 2) { idbuf[2] = '\0'; }
+    // never executed -- if (retval > 2) { idbuf[2] = '\0'; }
 
     retval = aor_transaction(rig, "VR" EOM, 3, frmbuf, &frm_len);
 
