@@ -19,20 +19,16 @@
  *
  */
 
-#include <hamlib/config.h>
 
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
-#include <stdbool.h>
 
 #include "hamlib/rig.h"
 #include "bandplan.h"
 #include "serial.h"
-#include "register.h"
 #include "tones.h"
 
 #include "dra818.h"
-#include "dorji.h"
 
 static const char *dra818_handshake_cmd = "AT+DMOCONNECT\r\n";
 static const char *dra818_handshake_res = "+DMOCONNECT:0\r\n";
@@ -56,7 +52,7 @@ struct dra818_priv
 static int dra818_response(RIG *rig, const char *expected)
 {
     char response[80];
-    int r = read_string(&rig->state.rigport, (unsigned char *) response,
+    int r = read_string(RIGPORT(rig), (unsigned char *) response,
                         sizeof(response),
                         "\n", 1, 0, 1);
 
@@ -104,7 +100,7 @@ static void dra818_subaudio(RIG *rig, char *subaudio, int subaudio_len,
 
 static int dra818_setgroup(RIG *rig)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
     char cmd[80];
     char subtx[8] = { 0 };
     char subrx[8] = { 0 };
@@ -118,18 +114,18 @@ static int dra818_setgroup(RIG *rig)
              (int)(priv->tx_freq / 1000000), (int)((priv->tx_freq % 1000000) / 100),
              (int)(priv->rx_freq / 1000000), (int)((priv->rx_freq % 1000000) / 100),
              subtx, priv->sql, subrx);
-    write_block(&rig->state.rigport, (unsigned char *) cmd, strlen(cmd));
+    write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     return dra818_response(rig, dra818_setgroup_res);
 }
 
 static int dra818_setvolume(RIG *rig)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
     char cmd[80];
 
     SNPRINTF(cmd, sizeof(cmd), "AT+DMOSETVOLUME=%1d\r\n", priv->vol);
-    write_block(&rig->state.rigport, (unsigned char *) cmd, strlen(cmd));
+    write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     return dra818_response(rig, dra818_setvolume_res);
 }
@@ -140,14 +136,14 @@ int dra818_init(RIG *rig)
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: dra818_init called\n", __func__);
 
-    rig->state.priv = calloc(sizeof(*priv), 1);
+    STATE(rig)->priv = calloc(sizeof(*priv), 1);
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     switch (rig->caps->rig_model)
     {
@@ -178,7 +174,7 @@ int dra818_cleanup(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s: dra818_cleanup called\n", __func__);
 
-    free(rig->state.priv);
+    free(STATE(rig)->priv);
 
     return RIG_OK;
 }
@@ -190,7 +186,7 @@ int dra818_open(RIG *rig)
 
     for (i = 0; i < 3; i++)
     {
-        write_block(&rig->state.rigport, (unsigned char *) dra818_handshake_cmd,
+        write_block(RIGPORT(rig), (unsigned char *) dra818_handshake_cmd,
                     strlen(dra818_handshake_cmd));
 
         r = dra818_response(rig, dra818_handshake_res);
@@ -218,7 +214,7 @@ int dra818_open(RIG *rig)
 
 int dra818_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    struct dra818_priv *priv = STATE(rig)->priv;
 
     /* Nearest channel */
     shortfreq_t sfreq = ((freq + priv->bw / 2) / priv->bw);
@@ -256,7 +252,7 @@ int dra818_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
 int dra818_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    struct dra818_priv *priv = STATE(rig)->priv;
 
     if (width > 12500)
     {
@@ -274,7 +270,7 @@ int dra818_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
 int dra818_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
 
     *mode = RIG_MODE_FM;
     *width = priv->bw;
@@ -284,16 +280,17 @@ int dra818_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
 int dra818_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
+    hamlib_port_t *rp = RIGPORT(rig);
     char cmd[80];
     char response[8];
     int r;
 
     SNPRINTF(cmd, sizeof(cmd), "S+%03d.%04d\r\n",
              (int)(priv->rx_freq / 1000000), (int)((priv->rx_freq % 1000000) / 100));
-    write_block(&rig->state.rigport, (unsigned char *) cmd, strlen(cmd));
+    write_block(rp, (unsigned char *) cmd, strlen(cmd));
 
-    r = read_string(&rig->state.rigport, (unsigned char *) response,
+    r = read_string(rp, (unsigned char *) response,
                     sizeof(response),
                     "\n", 1, 0, 1);
 
@@ -316,7 +313,7 @@ int dra818_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 
 int dra818_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
 
     switch (vfo)
     {
@@ -337,7 +334,7 @@ int dra818_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
 int dra818_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    struct dra818_priv *priv = STATE(rig)->priv;
 
     priv->split = split;
 
@@ -351,7 +348,7 @@ int dra818_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
 
 int dra818_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
 
     *split = priv->split;
 
@@ -369,7 +366,7 @@ int dra818_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 
 int dra818_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
 
     switch (level)
     {
@@ -392,7 +389,7 @@ int dra818_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
 int dra818_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    struct dra818_priv *priv = STATE(rig)->priv;
 
     switch (level)
     {
@@ -437,7 +434,7 @@ int dra818_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 
 int dra818_set_dcs_code(RIG *rig, vfo_t vfo, tone_t code)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    struct dra818_priv *priv = STATE(rig)->priv;
 
     priv->dcs_code = code;
 
@@ -451,7 +448,7 @@ int dra818_set_dcs_code(RIG *rig, vfo_t vfo, tone_t code)
 
 int dra818_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    struct dra818_priv *priv = STATE(rig)->priv;
 
     priv->ctcss_tone = tone;
 
@@ -465,7 +462,7 @@ int dra818_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 
 int dra818_set_dcs_sql(RIG *rig, vfo_t vfo, tone_t code)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    struct dra818_priv *priv = STATE(rig)->priv;
 
     priv->dcs_sql = code;
 
@@ -479,7 +476,7 @@ int dra818_set_dcs_sql(RIG *rig, vfo_t vfo, tone_t code)
 
 int dra818_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    struct dra818_priv *priv = STATE(rig)->priv;
 
     priv->ctcss_sql = tone;
 
@@ -493,7 +490,7 @@ int dra818_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone)
 
 int dra818_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
 
     *tone = priv->ctcss_sql;
     return RIG_OK;
@@ -501,7 +498,7 @@ int dra818_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone)
 
 int dra818_get_dcs_sql(RIG *rig, vfo_t vfo, tone_t *code)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
 
     *code = priv->dcs_sql;
     return RIG_OK;
@@ -509,7 +506,7 @@ int dra818_get_dcs_sql(RIG *rig, vfo_t vfo, tone_t *code)
 
 int dra818_get_dcs_code(RIG *rig, vfo_t vfo, tone_t *code)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
 
     *code = priv->dcs_code;
     return RIG_OK;
@@ -517,20 +514,20 @@ int dra818_get_dcs_code(RIG *rig, vfo_t vfo, tone_t *code)
 
 int dra818_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
 {
-    struct dra818_priv *priv = rig->state.priv;
+    const struct dra818_priv *priv = STATE(rig)->priv;
 
     *tone = priv->ctcss_tone;
     return RIG_OK;
 }
 
-const struct rig_caps dra818u_caps =
+struct rig_caps dra818u_caps =
 {
     RIG_MODEL(RIG_MODEL_DORJI_DRA818U),
     .model_name =       "DRA818U",
     .mfg_name =     "Dorji",
     .version =      "20191209.0",
     .copyright =        "LGPL",
-    .status =       RIG_STATUS_ALPHA,
+    .status =       RIG_STATUS_BETA,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
     .ptt_type =     RIG_PTT_NONE,
     .dcd_type =     RIG_DCD_RIG,
@@ -627,14 +624,14 @@ const struct rig_caps dra818u_caps =
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
-const struct rig_caps dra818v_caps =
+struct rig_caps dra818v_caps =
 {
     RIG_MODEL(RIG_MODEL_DORJI_DRA818V),
     .model_name =       "DRA818V",
     .mfg_name =     "Dorji",
     .version =      "20191209.0",
     .copyright =        "LGPL",
-    .status =       RIG_STATUS_ALPHA,
+    .status =       RIG_STATUS_BETA,
     .rig_type =     RIG_TYPE_TRANSCEIVER,
     .ptt_type =     RIG_PTT_NONE,
     .dcd_type =     RIG_DCD_RIG,
