@@ -19,19 +19,12 @@
  *
  */
 
-#include <hamlib/config.h>
-
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
-#include <errno.h>
 
 #include "hamlib/rotator.h"
 #include "iofunc.h"
-#include "misc.h"
-#include "network.h"
-#include "serial.h"
-
-#include "rot_dummy.h"
 
 #define CMD_MAX 32
 #define BUF_MAX 64
@@ -42,18 +35,19 @@
 static int netrotctl_transaction(ROT *rot, char *cmd, int len, char *buf)
 {
     int ret;
+    hamlib_port_t *rotp = ROTPORT(rot);
 
     /* flush anything in the read buffer before command is sent */
-    rig_flush(&rot->state.rotport);
+    rig_flush(rotp);
 
-    ret = write_block(&rot->state.rotport, (unsigned char *) cmd, len);
+    ret = write_block(rotp, (unsigned char *) cmd, len);
 
     if (ret != RIG_OK)
     {
         return ret;
     }
 
-    ret = read_string(&rot->state.rotport, (unsigned char *) buf, BUF_MAX, "\n",
+    ret = read_string(rotp, (unsigned char *) buf, BUF_MAX, "\n",
                       sizeof("\n"), 0, 1);
 
     if (ret < 0)
@@ -72,7 +66,8 @@ static int netrotctl_transaction(ROT *rot, char *cmd, int len, char *buf)
 static int netrotctl_open(ROT *rot)
 {
     int ret;
-    struct rot_state *rs = &rot->state;
+    struct rot_state *rs = ROTSTATE(rot);
+    hamlib_port_t *rotp = ROTPORT(rot);
     int prot_ver;
     char cmd[CMD_MAX];
     char buf[BUF_MAX];
@@ -92,7 +87,7 @@ static int netrotctl_open(ROT *rot)
     prot_ver = atoi(buf);
 #define ROTCTLD_PROT_VER 1
 
-    ret = read_string(&rot->state.rotport, (unsigned char *) buf, BUF_MAX, "\n",
+    ret = read_string(rotp, (unsigned char *) buf, BUF_MAX, "\n",
                       sizeof("\n"), 0, 1);
 
     if (ret <= 0)
@@ -107,7 +102,7 @@ static int netrotctl_open(ROT *rot)
     {
         char setting[32], value[1024];
 
-        ret = read_string(&rot->state.rotport, (unsigned char *) buf, BUF_MAX, "\n",
+        ret = read_string(rotp, (unsigned char *) buf, BUF_MAX, "\n",
                           sizeof("\n"), 0, 1);
 
         if (ret <= 0)
@@ -165,7 +160,7 @@ static int netrotctl_close(ROT *rot)
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
     /* clean signoff, no read back */
-    write_block(&rot->state.rotport, (unsigned char *) "q\n", 2);
+    write_block(ROTPORT(rot), (unsigned char *) "q\n", 2);
 
     return RIG_OK;
 }
@@ -212,7 +207,7 @@ static int netrotctl_get_position(ROT *rot, azimuth_t *az, elevation_t *el)
 
     *az = atof(buf);
 
-    ret = read_string(&rot->state.rotport, (unsigned char *) buf, BUF_MAX, "\n",
+    ret = read_string(ROTPORT(rot), (unsigned char *) buf, BUF_MAX, "\n",
                       sizeof("\n"), 0, 1);
 
     if (ret <= 0)
@@ -378,3 +373,39 @@ struct rot_caps netrotctl_caps =
     .get_info =      netrotctl_get_info,
 };
 
+/*
+ * S.A.T. rotator mimics net rotor but only minimal capabilities.
+ * Fails to work with net rotor since it fails dump_state.
+ */
+
+static int satrotcrl_rot_init(ROT *rot)
+{
+    rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+    return RIG_OK;
+}
+
+struct rot_caps satrotctl_caps =
+{
+    ROT_MODEL(ROT_MODEL_SATROTCTL),
+    .model_name =     "S.A.T. Satellite ctl",
+    .mfg_name =       "csntechnologies.net",
+    .version =        "20240609.0",
+    .copyright =      "LGPL",
+    .status =         RIG_STATUS_UNTESTED,
+    .rot_type =       ROT_TYPE_AZEL,
+    .port_type =      RIG_PORT_NETWORK,
+    .timeout =        400,
+
+    .min_az =     -180.,
+    .max_az =     450.,
+    .min_el =     0.,
+    .max_el =     90.,
+
+    .priv =  NULL,    /* priv */
+
+    .rot_init =         satrotcrl_rot_init,
+    .set_position =     netrotctl_set_position,
+    .get_position =     netrotctl_get_position,
+};
+
