@@ -22,6 +22,7 @@
 #ifndef _ROT_DUMMY_H
 #define _ROT_DUMMY_H 1
 
+#include "rotator.h"
 #include "token.h"
 
 /* backend conf */
@@ -38,5 +39,7 @@
 
 extern struct rot_caps dummy_rot_caps;
 extern struct rot_caps netrotctl_caps;
+extern struct rot_caps pstrotator;
+extern struct rot_caps satrotctl_caps;
 
 #endif /* _ROT_DUMMY_H */
