@@ -18,7 +18,6 @@
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
-#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,10 +26,7 @@
 #include <hamlib/rig.h>
 #include <serial.h>
 #include <misc.h>
-#include <cal.h>
 #include <token.h>
-#include <register.h>
-#include <network.h>
 
 #include "dummy_common.h"
 
@@ -45,6 +41,9 @@
 #define DEFAULTPATH "127.0.0.1:50001"
 
 #define FALSE 0
+#ifdef TRUE
+#undef TRUE
+#endif
 #define TRUE (!FALSE)
 
 #define TCI_VFOS (RIG_VFO_A|RIG_VFO_B)
@@ -86,8 +85,8 @@ static int tci1x_get_split_freq_mode(RIG *rig, vfo_t vfo, freq_t *freq,
 static int tci1x_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
 static int tci1x_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
 
-static int tci1x_set_ext_parm(RIG *rig, token_t token, value_t val);
-static int tci1x_get_ext_parm(RIG *rig, token_t token, value_t *val);
+static int tci1x_set_ext_parm(RIG *rig, hamlib_token_t token, value_t val);
+static int tci1x_get_ext_parm(RIG *rig, hamlib_token_t token, value_t *val);
 #endif
 
 static const char *tci1x_get_info(RIG *rig);
@@ -133,14 +132,14 @@ static const struct confparams tci1x_ext_parms[] =
     { RIG_CONF_END, NULL, }
 };
 
-const struct rig_caps tci1x_caps =
+struct rig_caps tci1x_caps =
 {
     RIG_MODEL(RIG_MODEL_TCI1X),
     .model_name = "TCI1.X",
     .mfg_name = "Expert Elec",
     .version = "20211125.0",
     .copyright = "LGPL",
-    .status = RIG_STATUS_ALPHA,
+    .status = RIG_STATUS_BETA,
     .rig_type = RIG_TYPE_TRANSCEIVER,
     .targetable_vfo =  RIG_TARGETABLE_FREQ | RIG_TARGETABLE_MODE,
     .ptt_type = RIG_PTT_RIG,
@@ -274,7 +273,6 @@ static int check_vfo(vfo_t vfo)
 static int read_transaction(RIG *rig, unsigned char *buf, int buf_len)
 {
     int retry;
-    struct rig_state *rs = &rig->state;
     char *delims = ";";
 
     ENTERFUNC;
@@ -288,7 +286,7 @@ static int read_transaction(RIG *rig, unsigned char *buf, int buf_len)
             rig_debug(RIG_DEBUG_WARN, "%s: retry needed? retry=%d\n", __func__, retry);
         }
 
-        int len = read_string(&rs->rigport, buf, buf_len, delims,
+        int len = read_string(RIGPORT(rig), buf, buf_len, delims,
                               strlen(delims), 0, 1);
         rig_debug(RIG_DEBUG_TRACE, "%s: string='%s'\n", __func__, buf);
 
@@ -314,14 +312,14 @@ static int read_transaction(RIG *rig, unsigned char *buf, int buf_len)
 * write_transaction
 * Assumes rig!=NULL, xml!=NULL, xml_len=total size of xml for response
 */
-static int write_transaction(RIG *rig, unsigned char *buf, int buf_len)
+static int write_transaction(RIG *rig, const unsigned char *buf, int buf_len)
 {
 
     int try = rig->caps->retry;
 
     int retval = -RIG_EPROTO;
 
-    struct rig_state *rs = &rig->state;
+    hamlib_port_t *rp = RIGPORT(rig);
 
     ENTERFUNC;
 
@@ -335,11 +333,11 @@ static int write_transaction(RIG *rig, unsigned char *buf, int buf_len)
 
     // appears we can lose sync if we don't clear things out
     // shouldn't be anything for us now anyways
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
     while (try-- >= 0 && retval != RIG_OK)
         {
-            retval = write_block(&rs->rigport, buf, buf_len);
+            retval = write_block(rp, buf, buf_len);
 
             if (retval  < 0)
             {
@@ -421,19 +419,20 @@ static int tci1x_transaction(RIG *rig, char *cmd, char *cmd_arg, char *value,
 static int tci1x_init(RIG *rig)
 {
     struct tci1x_priv_data *priv;
+    hamlib_port_t *rp = RIGPORT(rig);
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s version %s\n", __func__, rig->caps->version);
 
-    rig->state.priv  = (struct tci1x_priv_data *)calloc(1, sizeof(
-                           struct tci1x_priv_data));
+    STATE(rig)->priv  = (struct tci1x_priv_data *)calloc(1, sizeof(
+                            struct tci1x_priv_data));
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         RETURNFUNC(-RIG_ENOMEM);
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     memset(priv, 0, sizeof(struct tci1x_priv_data));
     memset(priv->parms, 0, RIG_SETTING_MAX * sizeof(value_t));
@@ -441,7 +440,7 @@ static int tci1x_init(RIG *rig)
     /*
      * set arbitrary initial status
      */
-    rig->state.current_vfo = RIG_VFO_A;
+    STATE(rig)->current_vfo = RIG_VFO_A;
     priv->split = 0;
     priv->ptt = 0;
     priv->curr_modeA = -1;
@@ -454,8 +453,7 @@ static int tci1x_init(RIG *rig)
         RETURNFUNC(-RIG_EINVAL);
     }
 
-    strncpy(rig->state.rigport.pathname, DEFAULTPATH,
-            sizeof(rig->state.rigport.pathname));
+    strncpy(rp->pathname, DEFAULTPATH, sizeof(rp->pathname));
 
     priv->ext_parms = alloc_init_ext(tci1x_ext_parms);
 
@@ -585,7 +583,7 @@ static void modeMapAdd(rmode_t *modes, rmode_t mode_hamlib, char *mode_tci1x)
 
 /*
 * tci1x_open
-* Assumes rig!=NULL, rig->state.priv!=NULL
+* Assumes rig!=NULL, STATE(rig)->priv!=NULL
 */
 static int tci1x_open(RIG *rig)
 {
@@ -596,7 +594,9 @@ static int tci1x_open(RIG *rig)
     rmode_t modes;
     char *p;
     char *pr;
-    //struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    //struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
+    arg[0] = '?';
+    arg[1] = 0;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: version %s\n", __func__, rig->caps->version);
     char *websocket =
@@ -621,7 +621,7 @@ static int tci1x_open(RIG *rig)
         // we fall through and assume old version
     }
 
-    sscanf(&value[2], "device:%s", value);
+    sscanf(&value[2], "device:%8191s", value);
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: TCI Device is %s\n", __func__, arg);
 
@@ -634,8 +634,8 @@ static int tci1x_open(RIG *rig)
                   rigerror(retval));
     }
 
-    sscanf(&value[2], "receive_only:%s", value);
-    rig_debug(RIG_DEBUG_VERBOSE, "%s: readonly is %s\n", __func__, arg);
+    sscanf(&value[2], "receive_only:%8191s", value);
+    rig_debug(RIG_DEBUG_VERBOSE, "%s: readonly is %8191s\n", __func__, arg);
 
     // TRX count
     retval = tci1x_transaction(rig, "trx_count;", NULL, value, sizeof(value));
@@ -657,9 +657,9 @@ static int tci1x_open(RIG *rig)
         rig_debug(RIG_DEBUG_ERR, "%s: tci1x_get_freq not working!!\n", __func__);
     }
 
-    rig->state.current_vfo = RIG_VFO_A;
+    STATE(rig)->current_vfo = RIG_VFO_A;
     rig_debug(RIG_DEBUG_TRACE, "%s: currvfo=%s value=%s\n", __func__,
-              rig_strvfo(rig->state.current_vfo), value);
+              rig_strvfo(STATE(rig)->current_vfo), value);
     //tci1x_get_split_vfo(rig, vfo, &priv->split, &vfo_tx);
     RETURNFUNC2(RIG_OK);
 
@@ -669,7 +669,7 @@ static int tci1x_open(RIG *rig)
 
     if (retval != RIG_OK) { RETURNFUNC2(retval); }
 
-    sscanf(&value[2], "modulations_list:%s", arg);
+    sscanf(&value[2], "modulations_list:%8191s", arg);
     rig_debug(RIG_DEBUG_VERBOSE, "%s: modes=%s\n", __func__, arg);
     modes = 0;
     pr = value;
@@ -784,7 +784,7 @@ static int tci1x_open(RIG *rig)
         else { rig_debug(RIG_DEBUG_ERR, "%s: Unknown mode (new?) for this rig='%s'\n", __func__, p); }
     }
 
-    rig->state.mode_list = modes;
+    STATE(rig)->mode_list = modes;
 
     retval = rig_strrmodes(modes, value, sizeof(value));
 
@@ -811,7 +811,7 @@ static int tci1x_close(RIG *rig)
 
 /*
 * tci1x_cleanup
-* Assumes rig!=NULL, rig->state.priv!=NULL
+* Assumes rig!=NULL, STATE(rig)->priv!=NULL
 */
 static int tci1x_cleanup(RIG *rig)
 {
@@ -819,29 +819,24 @@ static int tci1x_cleanup(RIG *rig)
 
     ENTERFUNC;
 
-    if (!rig)
-    {
-        RETURNFUNC(-RIG_EINVAL);
-    }
-
-    priv = (struct tci1x_priv_data *)rig->state.priv;
+    priv = (struct tci1x_priv_data *)STATE(rig)->priv;
 
     free(priv->ext_parms);
-    free(rig->state.priv);
+    free(STATE(rig)->priv);
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     RETURNFUNC(RIG_OK);
 }
 
 /*
 * tci1x_get_freq
-* Assumes rig!=NULL, rig->state.priv!=NULL, freq!=NULL
+* Assumes rig!=NULL, STATE(rig)->priv!=NULL, freq!=NULL
 */
 static int tci1x_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
     char value[MAXARGLEN];
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
@@ -857,7 +852,7 @@ static int tci1x_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
     if (vfo == RIG_VFO_CURR)
     {
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
         rig_debug(RIG_DEBUG_TRACE, "%s: get_freq2 vfo=%s\n",
                   __func__, rig_strvfo(vfo));
     }
@@ -904,14 +899,14 @@ static int tci1x_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
 /*
 * tci1x_set_freq
-* assumes rig!=NULL, rig->state.priv!=NULL
+* assumes rig!=NULL, STATE(rig)->priv!=NULL
 */
 static int tci1x_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
     int retval;
     char cmd_arg[MAXARGLEN];
     char *cmd;
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s freq=%.0f\n", __func__,
@@ -926,7 +921,7 @@ static int tci1x_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     if (vfo == RIG_VFO_CURR)
     {
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
     }
     else if (vfo == RIG_VFO_TX && priv->split)
     {
@@ -977,7 +972,7 @@ static int tci1x_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
     int retval;
     char cmd_arg[MAXARGLEN];
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: ptt=%d\n", __func__, ptt);
@@ -1020,7 +1015,7 @@ static int tci1x_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 static int tci1x_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
     char value[MAXCMDLEN];
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
@@ -1051,7 +1046,7 @@ static int tci1x_set_split_mode(RIG *rig, vfo_t vfo, rmode_t mode,
                                 pbwidth_t width)
 {
     int retval;
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s mode=%s width=%d\n",
@@ -1060,7 +1055,7 @@ static int tci1x_set_split_mode(RIG *rig, vfo_t vfo, rmode_t mode,
     switch (vfo)
     {
     case RIG_VFO_CURR:
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
         break;
 
     case RIG_VFO_TX:
@@ -1098,8 +1093,8 @@ static int tci1x_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     char cmd_arg[MAXCMDLEN];
     char *p;
     char *pttmode;
-    char *ttmode;
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    char *ttmode = NULL;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s mode=%s width=%d\n",
@@ -1116,7 +1111,7 @@ static int tci1x_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
     if (vfo == RIG_VFO_CURR)
     {
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
     }
 
     if (check_vfo(vfo) == FALSE)
@@ -1136,11 +1131,11 @@ static int tci1x_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     // MDB
     vfoSwitched = 0;
     rig_debug(RIG_DEBUG_TRACE, "%s: curr_vfo = %s\n", __func__,
-              rig_strvfo(rig->state.current_vfo));
+              rig_strvfo(STATE(rig)->current_vfo));
 
     // If we don't have the get_bwA call we have to switch VFOs ourself
     if (!priv->has_get_bwA && vfo == RIG_VFO_B
-            && rig->state.current_vfo != RIG_VFO_B)
+            && STATE(rig)->current_vfo != RIG_VFO_B)
     {
         vfoSwitched = 1;
         rig_debug(RIG_DEBUG_TRACE, "%s: switch to VFOB = %d\n", __func__,
@@ -1286,7 +1281,7 @@ static int tci1x_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     }
 
     rig_debug(RIG_DEBUG_TRACE,
-              "%s: return modeA=%s, widthA=%d\n,modeB=%s, widthB=%d\n", __func__,
+              "%s: Return modeA=%s, widthA=%d\n,modeB=%s, widthB=%d\n", __func__,
               rig_strrmode(priv->curr_modeA), (int)priv->curr_widthA,
               rig_strrmode(priv->curr_modeB), (int)priv->curr_widthB);
     RETURNFUNC(RIG_OK);
@@ -1294,7 +1289,7 @@ static int tci1x_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
 /*
 * tci1x_get_mode
-* Assumes rig!=NULL, rig->state.priv!=NULL, mode!=NULL
+* Assumes rig!=NULL, STATE(rig)->priv!=NULL, mode!=NULL
 */
 static int tci1x_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
@@ -1304,7 +1299,7 @@ static int tci1x_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
     char *cmdp;
     vfo_t curr_vfo;
     rmode_t my_mode;
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
@@ -1317,11 +1312,11 @@ static int tci1x_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
         RETURNFUNC(-RIG_EINVAL);
     }
 
-    curr_vfo = rig->state.current_vfo;
+    curr_vfo = STATE(rig)->current_vfo;
 
     if (vfo == RIG_VFO_CURR)
     {
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
     }
 
     rig_debug(RIG_DEBUG_TRACE, "%s: using vfo=%s\n", __func__,
@@ -1459,8 +1454,9 @@ static int tci1x_set_vfo(RIG *rig, vfo_t vfo)
 {
     int retval;
     char cmd_arg[MAXBUFLEN];
-    struct rig_state *rs = &rig->state;
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct rig_state *rs = STATE(rig);
+    const struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(
+            rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
@@ -1482,7 +1478,7 @@ static int tci1x_set_vfo(RIG *rig, vfo_t vfo)
 
     if (vfo == RIG_VFO_CURR)
     {
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
     }
 
     SNPRINTF(cmd_arg, sizeof(cmd_arg),
@@ -1497,7 +1493,7 @@ static int tci1x_set_vfo(RIG *rig, vfo_t vfo)
         RETURNFUNC(retval);
     }
 
-    rig->state.current_vfo = vfo;
+    STATE(rig)->current_vfo = vfo;
     rs->tx_vfo = RIG_VFO_B; // always VFOB
 
     /* for some rigs TCI turns off split when VFOA is selected */
@@ -1561,7 +1557,7 @@ static int tci1x_get_vfo(RIG *rig, vfo_t *vfo)
         RETURNFUNC(-RIG_EINVAL);
     }
 
-    rig->state.current_vfo = *vfo;
+    STATE(rig)->current_vfo = *vfo;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
               rig_strvfo(*vfo));
@@ -1578,7 +1574,7 @@ static int tci1x_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
     int retval;
     char cmd_arg[MAXBUFLEN];
     freq_t qtx_freq;
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s freq=%.1f\n", __func__,
@@ -1620,7 +1616,7 @@ static int tci1x_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
 static int tci1x_get_split_freq(RIG *rig, vfo_t vfo, freq_t *tx_freq)
 {
     int retval;
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
@@ -1640,7 +1636,7 @@ static int tci1x_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
     int retval;
     vfo_t qtx_vfo;
     split_t qsplit;
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
     char cmd_arg[MAXBUFLEN];
 
     ENTERFUNC;
@@ -1682,7 +1678,7 @@ static int tci1x_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split,
                                vfo_t *tx_vfo)
 {
     char value[MAXCMDLEN];
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
 
@@ -1712,7 +1708,7 @@ static int tci1x_set_split_freq_mode(RIG *rig, vfo_t vfo, freq_t freq,
     int retval;
     rmode_t qmode;
     pbwidth_t qwidth;
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(rig)->priv;
 
     ENTERFUNC;
 
@@ -1828,14 +1824,15 @@ static int tci1x_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 
 /*
 * tci1x_get_level
-* Assumes rig!=NULL, rig->state.priv!=NULL, val!=NULL
+* Assumes rig!=NULL, STATE(rig)->priv!=NULL, val!=NULL
 */
 static int tci1x_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
     char value[MAXARGLEN];
     char *cmd;
     int retval;
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    const struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(
+            rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
@@ -1911,7 +1908,8 @@ static int tci1x_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 */
 static const char *tci1x_get_info(RIG *rig)
 {
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    const struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(
+            rig)->priv;
 
     return (priv->info);
 }
@@ -1919,7 +1917,8 @@ static const char *tci1x_get_info(RIG *rig)
 static int tci1x_power2mW(RIG *rig, unsigned int *mwpower, float power,
                           freq_t freq, rmode_t mode)
 {
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *) rig->state.priv;
+    const struct tci1x_priv_data *priv = (struct tci1x_priv_data *) STATE(
+            rig)->priv;
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: passed power = %f\n", __func__, power);
     rig_debug(RIG_DEBUG_TRACE, "%s: passed freq = %"PRIfreq" Hz\n", __func__, freq);
@@ -1948,9 +1947,9 @@ static int tci1x_mW2power(RIG *rig, float *power, unsigned int mwpower,
 }
 
 #ifdef XXNOTIMPLEMENTED
-static int tci1x_set_ext_parm(RIG *rig, token_t token, value_t val)
+static int tci1x_set_ext_parm(RIG *rig, hamlib_token_t token, value_t val)
 {
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *)rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *)STATE(rig)->priv;
     char lstr[64];
     const struct confparams *cfp;
     struct ext_list *epp;
@@ -2025,9 +2024,9 @@ static int tci1x_set_ext_parm(RIG *rig, token_t token, value_t val)
     RETURNFUNC(RIG_OK);
 }
 
-static int tci1x_get_ext_parm(RIG *rig, token_t token, value_t *val)
+static int tci1x_get_ext_parm(RIG *rig, hamlib_token_t token, value_t *val)
 {
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *)rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *)STATE(rig)->priv;
     const struct confparams *cfp;
     struct ext_list *epp;
 
@@ -2070,7 +2069,7 @@ static int tci1x_get_ext_parm(RIG *rig, token_t token, value_t *val)
 
 static int tci1x_set_ext_parm(RIG *rig, setting_t parm, value_t val)
 {
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *)rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *)STATE(rig)->priv;
     int idx;
     char pstr[32];
 
@@ -2100,7 +2099,7 @@ static int tci1x_set_ext_parm(RIG *rig, setting_t parm, value_t val)
 
 static int tci1x_get_ext_parm(RIG *rig, setting_t parm, value_t *val)
 {
-    struct tci1x_priv_data *priv = (struct tci1x_priv_data *)rig->state.priv;
+    struct tci1x_priv_data *priv = (struct tci1x_priv_data *)STATE(rig)->priv;
     int idx;
 
     ENTERFUNC;
