@@ -19,7 +19,6 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,11 +26,6 @@
 
 #include <hamlib/rig.h>
 #include <serial.h>
-#include <misc.h>
-#include <cal.h>
-#include <token.h>
-#include <register.h>
-#include <network.h>
 
 #include "trxmanager.h"
 
@@ -214,7 +208,7 @@ static int vfo_curr(RIG *rig, vfo_t vfo)
     int retval = 0;
     vfo_t vfocurr;
     struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
-                                        rig->state.priv;
+                                        STATE(rig)->priv;
 
     // get the current VFO from trxmanager in case user changed it
     if ((retval = trxmanager_get_vfo(rig, &vfocurr)) != RIG_OK)
@@ -234,13 +228,12 @@ static int vfo_curr(RIG *rig, vfo_t vfo)
  */
 static int read_transaction(RIG *rig, char *response, int response_len)
 {
-    struct rig_state *rs = &rig->state;
-    char *delims = "\n";
+    const char *delims = "\n";
     int len;
 
     rig_debug(RIG_DEBUG_TRACE, "%s\n", __func__);
 
-    len = read_string(&rs->rigport, (unsigned char *) response, response_len,
+    len = read_string(RIGPORT(rig), (unsigned char *) response, response_len,
                       delims,
                       strlen(delims), 0, 1);
 
@@ -260,18 +253,19 @@ static int read_transaction(RIG *rig, char *response, int response_len)
 static int trxmanager_init(RIG *rig)
 {
     struct trxmanager_priv_data *priv;
+    hamlib_port_t *rp = RIGPORT(rig);
 
     rig_debug(RIG_DEBUG_TRACE, "%s version %s\n", __func__, BACKEND_VER);
 
-    rig->state.priv = (struct trxmanager_priv_data *)calloc(1,
-                      sizeof(struct trxmanager_priv_data));
+    STATE(rig)->priv = (struct trxmanager_priv_data *)calloc(1,
+                       sizeof(struct trxmanager_priv_data));
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     memset(priv, 0, sizeof(struct trxmanager_priv_data));
 
@@ -286,15 +280,14 @@ static int trxmanager_init(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    strncpy(rig->state.rigport.pathname, DEFAULTPATH,
-            sizeof(rig->state.rigport.pathname));
+    strncpy(rp->pathname, DEFAULTPATH, sizeof(rp->pathname));
 
     return RIG_OK;
 }
 
 /*
  * trxmanager_open
- * Assumes rig!=NULL, rig->state.priv!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL
  */
 static int trxmanager_open(RIG *rig)
 {
@@ -302,13 +295,13 @@ static int trxmanager_open(RIG *rig)
     char *cmd;
     char *saveptr;
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
+    hamlib_port_t *rp = RIGPORT(rig);
     struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
-                                        rig->state.priv;
+                                        STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s version %s\n", __func__, BACKEND_VER);
 
-    rs->rigport.timeout = 10000; // long timeout for antenna switching/tuning
+    rp->timeout = 10000; // long timeout for antenna switching/tuning
     retval = read_transaction(rig, response, sizeof(response));
 
     if (retval != RIG_OK)
@@ -329,7 +322,7 @@ static int trxmanager_open(RIG *rig)
 
     // Turn off active messages
     cmd = "AI0;";
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(rp, (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -352,7 +345,7 @@ static int trxmanager_open(RIG *rig)
     rig_debug(RIG_DEBUG_VERBOSE, "%s AI response=%s\n", __func__, response);
 
     cmd = "FN;";
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(rp, (unsigned char *) cmd, strlen(cmd));
 
     if (retval != RIG_OK)
     {
@@ -384,7 +377,7 @@ static int trxmanager_close(RIG *rig)
 
 /*
  * trxmanager_cleanup
- * Assumes rig!=NULL, rig->state.priv!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL
  */
 static int trxmanager_cleanup(RIG *rig)
 {
@@ -394,15 +387,15 @@ static int trxmanager_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    free(rig->state.priv);
-    rig->state.priv = NULL;
+    free(STATE(rig)->priv);
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
 
 /*
  * trxmanager_get_freq
- * Assumes rig!=NULL, rig->state.priv!=NULL, freq!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL, freq!=NULL
  */
 static int trxmanager_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
@@ -411,9 +404,8 @@ static int trxmanager_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
     char vfoab;
     char cmd[MAXCMDLEN];
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
     struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
-                                        rig->state.priv;
+                                        STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
               rig_strvfo(vfo));
@@ -440,7 +432,7 @@ static int trxmanager_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
     vfoab = vfo == RIG_VFO_A ? 'R' : 'T';
     SNPRINTF(cmd, sizeof(cmd), "X%c;", vfoab);
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -473,7 +465,7 @@ static int trxmanager_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
 /*
  * trxmanager_set_freq
- * assumes rig!=NULL, rig->state.priv!=NULL
+ * assumes rig!=NULL, STATE(rig)->priv!=NULL
  */
 static int trxmanager_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
@@ -481,9 +473,8 @@ static int trxmanager_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     char vfoab;
     char cmd[MAXCMDLEN];
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
-    struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
-                                        rig->state.priv;
+    const struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
+            STATE(rig)->priv;
 
 
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s freq=%.1f\n", __func__,
@@ -510,7 +501,7 @@ static int trxmanager_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     vfoab = vfo == RIG_VFO_A ? 'A' : 'B';
     SNPRINTF(cmd, sizeof(cmd), "F%c%011lu;", vfoab, (unsigned long)freq);
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -537,7 +528,6 @@ static int trxmanager_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
     int retval;
     char cmd[MAXCMDLEN];
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: ptt=%d\n", __func__, ptt);
 
@@ -549,7 +539,7 @@ static int trxmanager_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
     }
 
     SNPRINTF(cmd, sizeof(cmd), "%s;", ptt == 1 ? "TX" : "RX");
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -582,13 +572,12 @@ static int trxmanager_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
     char cptt;
     char cmd[MAXCMDLEN];
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
               rig_strvfo(vfo));
 
     SNPRINTF(cmd, sizeof(cmd), "IF;");
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -641,7 +630,6 @@ static int trxmanager_set_mode(RIG *rig, vfo_t vfo, rmode_t mode,
     char ttmode;
     char cmd[MAXCMDLEN];
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s mode=%s width=%d\n",
               __func__, rig_strvfo(vfo), rig_strrmode(mode), (int)width);
@@ -713,7 +701,7 @@ static int trxmanager_set_mode(RIG *rig, vfo_t vfo, rmode_t mode,
     }
 
     SNPRINTF(cmd, sizeof(cmd), "MD%c;", ttmode);
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -737,7 +725,7 @@ static int trxmanager_set_mode(RIG *rig, vfo_t vfo, rmode_t mode,
 
 /*
  * trxmanager_get_mode
- * Assumes rig!=NULL, rig->state.priv!=NULL, mode!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL, mode!=NULL
  */
 static int trxmanager_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode,
                                pbwidth_t *width)
@@ -748,9 +736,9 @@ static int trxmanager_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode,
     char tmode;
     char cmd[MAXCMDLEN];
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
+    hamlib_port_t *rp = RIGPORT(rig);
     struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
-                                        rig->state.priv;
+                                        STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
               rig_strvfo(vfo));
@@ -776,7 +764,7 @@ static int trxmanager_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode,
               rig_strvfo(vfo));
 
     SNPRINTF(cmd, sizeof(cmd), "MD;");
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(rp, (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -849,7 +837,7 @@ static int trxmanager_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode,
 
     // now get the bandwidth
     SNPRINTF(cmd, sizeof(cmd), "BW;");
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(rp, (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -889,9 +877,9 @@ static int trxmanager_set_vfo(RIG *rig, vfo_t vfo)
     int retval;
     char cmd[MAXCMDLEN];
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
+    struct rig_state *rs = STATE(rig);
     struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
-                                        rig->state.priv;
+                                        rs->priv;
 
 
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s\n", __func__,
@@ -916,7 +904,7 @@ static int trxmanager_set_vfo(RIG *rig, vfo_t vfo)
     }
 
     SNPRINTF(cmd, sizeof(cmd), "FN%d;", vfo == RIG_VFO_A ? 0 : 1);
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -941,7 +929,7 @@ static int trxmanager_get_vfo(RIG *rig, vfo_t *vfo)
     // So we maintain our own internal state during set_vfo
     // This keeps the hamlib interface consistent with other rigs
     struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
-                                        rig->state.priv;
+                                        STATE(rig)->priv;
     char vfoab;
 
 
@@ -988,7 +976,6 @@ static int trxmanager_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
     int retval;
     char cmd[MAXCMDLEN];
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: vfo=%s freq=%.1f\n", __func__,
               rig_strvfo(vfo), tx_freq);
@@ -1001,7 +988,7 @@ static int trxmanager_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
     }
 
     SNPRINTF(cmd, sizeof(cmd), "XT%011lu;", (unsigned long) tx_freq);
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -1044,7 +1031,6 @@ static int trxmanager_set_split_vfo(RIG *rig, vfo_t vfo, split_t split,
     char response[MAXCMDLEN] = "";
     split_t tsplit;
     vfo_t ttx_vfo;
-    struct rig_state *rs = &rig->state;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: tx_vfo=%s\n", __func__,
               rig_strvfo(tx_vfo));
@@ -1069,7 +1055,7 @@ static int trxmanager_set_split_vfo(RIG *rig, vfo_t vfo, split_t split,
     if (tsplit == split) { return RIG_OK; } // don't need to change it
 
     SNPRINTF(cmd, sizeof(cmd), "SP%c;", split ? '1' : '0');
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -1105,13 +1091,12 @@ static int trxmanager_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split,
     int n;
     char cmd[MAXCMDLEN];
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
     struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
-                                        rig->state.priv;
+                                        STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s\n", __func__);
     SNPRINTF(cmd, sizeof(cmd), "SP;");
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -1129,7 +1114,7 @@ static int trxmanager_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split,
     *tx_vfo = RIG_VFO_B;
     n = sscanf(response, "SP%d", &tsplit);
 
-    if (n == 0)
+    if (n == 0 || n == EOF)
     {
         rig_debug(RIG_DEBUG_ERR, "%s error getting split from '%s'\n", __func__,
                   response);
@@ -1150,9 +1135,8 @@ static int trxmanager_set_split_freq_mode(RIG *rig, vfo_t vfo, freq_t freq,
     int retval;
     char cmd[MAXCMDLEN];
     char response[MAXCMDLEN] = "";
-    struct rig_state *rs = &rig->state;
     struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
-                                        rig->state.priv;
+                                        STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s\n", __func__);
 
@@ -1164,7 +1148,7 @@ static int trxmanager_set_split_freq_mode(RIG *rig, vfo_t vfo, freq_t freq,
     // assume split is on B
     //
     SNPRINTF(cmd, sizeof(cmd), "XT%011lu;", (unsigned long)freq);
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 
     if (retval < 0)
     {
@@ -1220,8 +1204,8 @@ static int trxmanager_get_split_freq_mode(RIG *rig, vfo_t vfo, freq_t *freq,
 
 static const char *trxmanager_get_info(RIG *rig)
 {
-    struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
-                                        rig->state.priv;
+    const struct trxmanager_priv_data *priv = (struct trxmanager_priv_data *)
+            STATE(rig)->priv;
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
     return priv->info;
