@@ -21,8 +21,8 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-#include <hamlib/config.h>
 
+#include <stdint.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>  /* String function definitions */
@@ -31,7 +31,6 @@
 #include <ctype.h>
 
 #include "hamlib/rig.h"
-#include "network.h"
 #include "serial.h"
 #include "misc.h"
 #include "register.h"
@@ -146,7 +145,7 @@ const struct confparams elad_cfg_params[] =
 
 /**
  * elad_transaction
- * Assumes rig!=NULL rig->state!=NULL rig->caps!=NULL
+ * Assumes rig!=NULL STATE(rig)!=NULL rig->caps!=NULL
  *
  * Parameters:
  * cmdstr:    Command to be sent to the rig. cmdstr can also be NULL,
@@ -165,9 +164,10 @@ const struct confparams elad_cfg_params[] =
  */
 int elad_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasize)
 {
-    struct elad_priv_data *priv = rig->state.priv;
-    struct elad_priv_caps *caps = elad_caps(rig);
+    struct elad_priv_data *priv = STATE(rig)->priv;
+    const struct elad_priv_caps *caps = elad_caps(rig);
     struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
     int retval;
     char cmdtrm[2];  /* Default Command/Reply termination char */
     char *cmd;
@@ -185,12 +185,12 @@ int elad_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasize)
         return -RIG_EINVAL;
     }
 
-    rs = &rig->state;
+    rs = STATE(rig);
 
     rs->transaction_active = 1;
 
     /* Emulators don't need any post_write_delay */
-    if (priv->is_emulation) { rs->rigport.post_write_delay = 0; }
+    if (priv->is_emulation) { rp->post_write_delay = 0; }
 
     cmdtrm[0] = caps->cmdtrm;
     cmdtrm[1] = '\0';
@@ -221,9 +221,9 @@ transaction_write:
         }
 
         /* flush anything in the read buffer before command is sent */
-        rig_flush(&rs->rigport);
+        rig_flush(rp);
 
-        retval = write_block(&rs->rigport, (unsigned char *) cmd, len);
+        retval = write_block(rp, (unsigned char *) cmd, len);
 
         free(cmd);
 
@@ -235,13 +235,13 @@ transaction_write:
 
     if (!datasize)
     {
-        rig->state.transaction_active = 0;
+        rs->transaction_active = 0;
 
         /* no reply expected so we need to write a command that always
            gives a reply so we can read any error replies from the actual
            command being sent without blocking */
-        if (RIG_OK != (retval = write_block(&rs->rigport,
-                                            (unsigned char *) priv->verify_cmd, strlen(priv->verify_cmd))))
+        if (RIG_OK != (retval = write_block(rp, (unsigned char *) priv->verify_cmd,
+                                            strlen(priv->verify_cmd))))
         {
             goto transaction_quit;
         }
@@ -251,12 +251,12 @@ transaction_read:
     /* allow one extra byte for terminator we don't return */
     len = min(datasize ? datasize + 1 : strlen(priv->verify_cmd) + 13,
               ELAD_MAX_BUF_LEN);
-    retval = read_string(&rs->rigport, (unsigned char *) buffer, len,
+    retval = read_string(rp, (unsigned char *) buffer, len,
                          cmdtrm, strlen(cmdtrm), 0, 1);
 
     if (retval < 0)
     {
-        if (retry_read++ < rs->rigport.retry)
+        if (retry_read++ < rp->retry)
         {
             goto transaction_write;
         }
@@ -270,7 +270,7 @@ transaction_read:
         rig_debug(RIG_DEBUG_ERR, "%s: Command is not correctly terminated '%s'\n",
                   __func__, buffer);
 
-        if (retry_read++ < rs->rigport.retry)
+        if (retry_read++ < rp->retry)
         {
             goto transaction_write;
         }
@@ -302,7 +302,7 @@ transaction_read:
                 rig_debug(RIG_DEBUG_VERBOSE, "%s: Overflow for '%s'\n", __func__, cmdstr);
             }
 
-            if (retry_read++ < rs->rigport.retry)
+            if (retry_read++ < rp->retry)
             {
                 goto transaction_write;
             }
@@ -319,7 +319,7 @@ transaction_read:
                           cmdstr);
             }
 
-            if (retry_read++ < rs->rigport.retry)
+            if (retry_read++ < rp->retry)
             {
                 goto transaction_write;
             }
@@ -336,7 +336,7 @@ transaction_read:
                           cmdstr);
             }
 
-            if (retry_read++ < rs->rigport.retry)
+            if (retry_read++ < rp->retry)
             {
                 rig_debug(RIG_DEBUG_ERR, "%s: Retrying shortly\n", __func__);
                 hl_usleep(rig->caps->timeout * 1000);
@@ -366,7 +366,7 @@ transaction_read:
             rig_debug(RIG_DEBUG_ERR, "%s: Wrong reply %c%c for command %c%c\n",
                       __func__, buffer[0], buffer[1], cmdstr[0], cmdstr[1]);
 
-            if (retry_read++ < rs->rigport.retry)
+            if (retry_read++ < rp->retry)
             {
                 goto transaction_write;
             }
@@ -399,7 +399,7 @@ transaction_read:
                       __func__, buffer[0], buffer[1]
                       , priv->verify_cmd[0], priv->verify_cmd[1], (int)datasize);
 
-            if (retry_read++ < rs->rigport.retry)
+            if (retry_read++ < rp->retry)
             {
                 goto transaction_write;
             }
@@ -471,7 +471,7 @@ int elad_safe_transaction(RIG *rig, const char *cmd, char *buf,
             hl_usleep(rig->caps->timeout * 1000);
         }
     }
-    while (err != RIG_OK && ++retry < rig->state.rigport.retry);
+    while (err != RIG_OK && ++retry < RIGPORT(rig)->retry);
 
     return err;
 }
@@ -515,14 +515,14 @@ int elad_init(RIG *rig)
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
-    rig->state.priv = calloc(1, sizeof(struct elad_priv_data));
+    STATE(rig)->priv = calloc(1, sizeof(struct elad_priv_data));
 
-    if (rig->state.priv == NULL)
+    if (STATE(rig)->priv == NULL)
     {
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     memset(priv, 0x00, sizeof(struct elad_priv_data));
     strcpy(priv->verify_cmd, RIG_MODEL_XG3 == rig->caps->rig_model ? ";" : "ID;");
@@ -551,15 +551,15 @@ int elad_cleanup(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
-    free(rig->state.priv);
-    rig->state.priv = NULL;
+    free(STATE(rig)->priv);
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
 
 int elad_open(RIG *rig)
 {
-    struct elad_priv_data *priv = rig->state.priv;
+    struct elad_priv_data *priv = STATE(rig)->priv;
     int err, i;
     char *idptr;
     char id[ELAD_MAX_BUF_LEN];
@@ -699,7 +699,7 @@ int elad_open(RIG *rig)
 
 int elad_close(RIG *rig)
 {
-    struct elad_priv_data *priv = rig->state.priv;
+    const struct elad_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -734,8 +734,8 @@ int elad_get_id(RIG *rig, char *buf)
  */
 static int elad_get_if(RIG *rig)
 {
-    struct elad_priv_data *priv = rig->state.priv;
-    struct elad_priv_caps *caps = elad_caps(rig);
+    struct elad_priv_data *priv = STATE(rig)->priv;
+    const struct elad_priv_caps *caps = elad_caps(rig);
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -754,7 +754,7 @@ int elad_set_vfo(RIG *rig, vfo_t vfo)
     char cmdbuf[6];
     int retval;
     char vfo_function;
-    struct elad_priv_data *priv = rig->state.priv;
+    const struct elad_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -904,7 +904,9 @@ int elad_get_vfo_main_sub(RIG *rig, vfo_t *vfo)
  */
 int elad_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
 {
-    struct elad_priv_data *priv = rig->state.priv;
+    // this is a bogus suppress which complains priv is not used -- but it is 20231012
+    // cppcheck-suppress unreadVariable
+    struct elad_priv_data *priv = STATE(rig)->priv;
     char cmdbuf[6];
     int retval;
     unsigned char vfo_function;
@@ -915,6 +917,11 @@ int elad_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
 
     retval = elad_get_split_vfo_if(rig, vfo, &tsplit, &tvfo);
 
+    if (retval != RIG_OK)
+    {
+        return retval;
+    }
+
     if (split == tsplit)
     {
         rig_debug(RIG_DEBUG_TRACE, "%s: No change detected...ignoring request\n",
@@ -978,6 +985,12 @@ int elad_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
     }
 
     retval = elad_set_split(rig, vfo, split, txvfo);
+
+    if (retval != RIG_OK)
+    {
+        return retval;
+    }
+
     /* Remember whether split is on, for elad_set_vfo */
     priv->split = split;
 
@@ -991,7 +1004,7 @@ int elad_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
  */
 int elad_set_split(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
 {
-    struct elad_priv_data *priv = rig->state.priv;
+    struct elad_priv_data *priv = STATE(rig)->priv;
     char cmdbuf[6];
     int retval;
 
@@ -1020,7 +1033,7 @@ int elad_set_split(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
  */
 int elad_get_split_vfo_if(RIG *rig, vfo_t rxvfo, split_t *split, vfo_t *txvfo)
 {
-    struct elad_priv_data *priv = rig->state.priv;
+    struct elad_priv_data *priv = STATE(rig)->priv;
     int retval;
     int transmitting;
 
@@ -1119,7 +1132,7 @@ int elad_get_split_vfo_if(RIG *rig, vfo_t rxvfo, split_t *split, vfo_t *txvfo)
 int elad_get_vfo_if(RIG *rig, vfo_t *vfo)
 {
     int retval;
-    struct elad_priv_data *priv = rig->state.priv;
+    struct elad_priv_data *priv = STATE(rig)->priv;
     int split_and_transmitting;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -1171,13 +1184,13 @@ int elad_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     unsigned char vfo_letter = '\0';
     vfo_t tvfo;
     int err;
-    struct elad_priv_data *priv = rig->state.priv;
+    const struct elad_priv_data *priv = STATE(rig)->priv;
 
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
     tvfo = (vfo == RIG_VFO_CURR
-            || vfo == RIG_VFO_VFO) ? rig->state.current_vfo : vfo;
+            || vfo == RIG_VFO_VFO) ? STATE(rig)->current_vfo : vfo;
 
     if (RIG_VFO_CURR == tvfo)
     {
@@ -1208,7 +1221,6 @@ int elad_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
         return -RIG_EINVAL;
     }
 
-    // cppcheck-suppress *
     SNPRINTF(freqbuf, sizeof(freqbuf), "F%c%011"PRIll, vfo_letter, (int64_t)freq);
 
     err = elad_transaction(rig, freqbuf, NULL, 0);
@@ -1258,7 +1270,7 @@ int elad_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
 int elad_get_freq_if(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    struct elad_priv_data *priv = rig->state.priv;
+    const struct elad_priv_data *priv = STATE(rig)->priv;
     char freqbuf[50];
     int retval;
 
@@ -1302,7 +1314,7 @@ int elad_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
     }
 
     tvfo = (vfo == RIG_VFO_CURR
-            || vfo == RIG_VFO_VFO) ? rig->state.current_vfo : vfo;
+            || vfo == RIG_VFO_VFO) ? STATE(rig)->current_vfo : vfo;
 
     if (RIG_VFO_CURR == tvfo)
     {
@@ -1358,7 +1370,7 @@ int elad_get_rit(RIG *rig, vfo_t vfo, shortfreq_t *rit)
 {
     int retval;
     char buf[6];
-    struct elad_priv_data *priv = rig->state.priv;
+    const struct elad_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -1491,7 +1503,7 @@ static int elad_set_filter(RIG *rig, pbwidth_t width)
  */
 int elad_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
-    struct elad_priv_data *priv = rig->state.priv;
+    const struct elad_priv_data *priv = STATE(rig)->priv;
     struct elad_priv_caps *caps = elad_caps(rig);
     char buf[6];
     char kmode;
@@ -1693,7 +1705,7 @@ static int elad_get_filter(RIG *rig, pbwidth_t *width)
  */
 int elad_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-    struct elad_priv_data *priv = rig->state.priv;
+    struct elad_priv_data *priv = STATE(rig)->priv;
     struct elad_priv_caps *caps = elad_caps(rig);
     char cmd[4];
     char modebuf[10];
@@ -1812,7 +1824,7 @@ int elad_get_mode_if(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
     int err;
     struct elad_priv_caps *caps = elad_caps(rig);
-    struct elad_priv_data *priv = rig->state.priv;
+    const struct elad_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -1907,9 +1919,9 @@ int elad_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         {
             int foundit = 0;
 
-            for (i = 0; i < HAMLIB_MAXDBLSTSIZ && rig->state.attenuator[i]; i++)
+            for (i = 0; i < HAMLIB_MAXDBLSTSIZ && STATE(rig)->attenuator[i]; i++)
             {
-                if (val.i == rig->state.attenuator[i])
+                if (val.i == STATE(rig)->attenuator[i])
                 {
                     SNPRINTF(levelbuf, sizeof(levelbuf), "RA%02d", i + 1);
                     foundit = 1;
@@ -1936,9 +1948,9 @@ int elad_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         {
             int foundit = 0;
 
-            for (i = 0; i < HAMLIB_MAXDBLSTSIZ && rig->state.preamp[i]; i++)
+            for (i = 0; i < HAMLIB_MAXDBLSTSIZ && STATE(rig)->preamp[i]; i++)
             {
-                if (val.i == rig->state.preamp[i])
+                if (val.i == STATE(rig)->preamp[i])
                 {
                     SNPRINTF(levelbuf, sizeof(levelbuf), "PA%01d", i + 1);
                     foundit = 1;
@@ -2121,7 +2133,7 @@ int elad_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         {
             for (i = 0; i < lvl && i < HAMLIB_MAXDBLSTSIZ; i++)
             {
-                if (rig->state.attenuator[i] == 0)
+                if (STATE(rig)->attenuator[i] == 0)
                 {
                     rig_debug(RIG_DEBUG_ERR, "%s: "
                               "unexpected att level %d\n",
@@ -2135,7 +2147,7 @@ int elad_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
                 return -RIG_EINTERNAL;
             }
 
-            val->i = rig->state.attenuator[i - 1];
+            val->i = STATE(rig)->attenuator[i - 1];
         }
 
         break;
@@ -2158,7 +2170,7 @@ int elad_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
             for (i = 0; i < lvl && i < HAMLIB_MAXDBLSTSIZ; i++)
             {
-                if (rig->state.preamp[i] == 0)
+                if (STATE(rig)->preamp[i] == 0)
                 {
                     rig_debug(RIG_DEBUG_ERR, "%s: "
                               "unexpected preamp level %d\n",
@@ -2172,7 +2184,7 @@ int elad_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
                 return -RIG_EINTERNAL;
             }
 
-            val->i = rig->state.preamp[i - 1];
+            val->i = STATE(rig)->preamp[i - 1];
         }
         else
         {
@@ -2460,7 +2472,7 @@ int elad_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
  */
 int elad_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 {
-    const struct rig_caps *caps;
+    struct rig_caps *caps;
     char tonebuf[16];
     int i;
 
@@ -2490,7 +2502,7 @@ int elad_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 
 int elad_set_ctcss_tone_tn(RIG *rig, vfo_t vfo, tone_t tone)
 {
-    const struct rig_caps *caps = rig->caps;
+    struct rig_caps *caps = rig->caps;
     char buf[16];
     int i;
 
@@ -2547,12 +2559,12 @@ int elad_set_ctcss_tone_tn(RIG *rig, vfo_t vfo, tone_t tone)
 
 /*
  * elad_get_ctcss_tone
- * Assumes rig->state.priv != NULL
+ * Assumes STATE(rig)->priv != NULL
  */
 int elad_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
 {
-    struct elad_priv_data *priv = rig->state.priv;
-    const struct rig_caps *caps;
+    const struct elad_priv_data *priv = STATE(rig)->priv;
+    struct rig_caps *caps;
     char tonebuf[3];
     int i, retval;
     unsigned int tone_idx;
@@ -2629,7 +2641,7 @@ int elad_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
 
 int elad_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone)
 {
-    const struct rig_caps *caps = rig->caps;
+    struct rig_caps *caps = rig->caps;
     char buf[16];
     int i;
 
@@ -2685,7 +2697,7 @@ int elad_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone)
 
 int elad_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone)
 {
-    const struct rig_caps *caps;
+    struct rig_caps *caps;
     char cmd[4];
     char tonebuf[6];
     int offs;
@@ -2896,7 +2908,7 @@ int elad_get_ant(RIG *rig, vfo_t vfo, ant_t dummy, value_t *option,
  */
 int elad_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
-    struct elad_priv_data *priv = rig->state.priv;
+    struct elad_priv_data *priv = STATE(rig)->priv;
     int retval;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -3355,7 +3367,7 @@ int elad_get_mem_if(RIG *rig, vfo_t vfo, int *ch)
 {
     int err;
     char buf[4];
-    struct elad_priv_data *priv = rig->state.priv;
+    const struct elad_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -3572,7 +3584,7 @@ int elad_set_channel(RIG *rig, const channel_t *chan)
     return elad_transaction(rig, buf, NULL, 0);
 }
 
-int elad_set_ext_parm(RIG *rig, token_t token, value_t val)
+int elad_set_ext_parm(RIG *rig, hamlib_token_t token, value_t val)
 {
     char buf[4];
 
@@ -3599,10 +3611,10 @@ int elad_set_ext_parm(RIG *rig, token_t token, value_t val)
     return -RIG_EINVAL;
 }
 
-int elad_get_ext_parm(RIG *rig, token_t token, value_t *val)
+int elad_get_ext_parm(RIG *rig, hamlib_token_t token, value_t *val)
 {
     int err;
-    struct elad_priv_data *priv = rig->state.priv;
+    struct elad_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -3684,6 +3696,7 @@ DECLARE_PROBERIG_BACKEND(elad)
     int retval = -1;
     int rates[] = { 115200, 57600, 38400, 19200, 9600, 4800, 1200, 0 }; /* possible baud rates */
     int rates_idx;
+    idbuf[0] = 0;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
