@@ -26,6 +26,8 @@
 #define _ELAD_H 1
 
 #include <string.h>
+
+#include "rig.h"
 #include "token.h"
 
 #define BACKEND_VER "20220608"
@@ -127,8 +129,8 @@ int elad_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
 int elad_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
 int elad_set_func(RIG *rig, vfo_t vfo, setting_t func, int status);
 int elad_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status);
-int elad_set_ext_parm(RIG *rig, token_t token, value_t val);
-int elad_get_ext_parm(RIG *rig, token_t token, value_t *val);
+int elad_set_ext_parm(RIG *rig, hamlib_token_t token, value_t val);
+int elad_get_ext_parm(RIG *rig, hamlib_token_t token, value_t *val);
 int elad_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone);
 int elad_set_ctcss_tone_tn(RIG *rig, vfo_t vfo, tone_t tone);
 int elad_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone);
@@ -162,13 +164,15 @@ int elad_get_trn(RIG *rig, int *trn);
 int get_elad_level(RIG *rig, const char *cmd, float *f);
 int get_elad_func(RIG *rig, const char *cmd, int *status);
 
-extern const struct rig_caps fdm_duo_caps;
+extern struct rig_caps fdm_duo_caps;
 
+#if 0
 /* use when not interested in the answer, but want to check its len */
 static int inline elad_simple_transaction(RIG *rig, const char *cmd, size_t expected)
 {
-  struct elad_priv_data *priv = rig->state.priv;
+  struct elad_priv_data *priv = STATE(rig)->priv;
   return elad_safe_transaction(rig, cmd, priv->info, ELAD_MAX_BUF_LEN, expected);
 }
+#endif
 
 #endif /* _ELAD_H */
