@@ -23,12 +23,17 @@
 
 #include <string.h>  /* String function definitions */
 
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
+
 #include "hamlib/rig.h"
 #include "serial.h"
 #include "misc.h"
 #include "icom.h"
 #include "icom_defs.h"
 #include "frame.h"
+#include "cache.h"
 
 /*
  * Build a CI-V frame.
@@ -111,7 +116,7 @@ int icom_frame_fix_preamble(int frame_len, unsigned char *frame)
 /*
  * icom_one_transaction
  *
- * We assume that rig!=NULL, rig->state!= NULL, payload!=NULL, data!=NULL, data_len!=NULL
+ * We assume that rig!=NULL, STATE(rig)!= NULL, payload!=NULL, data!=NULL, data_len!=NULL
  * Otherwise, you'll get a nice seg fault. You've been warned!
  * payload can be NULL if payload_len == 0
  * subcmd can be equal to -1 (no subcmd wanted)
@@ -126,7 +131,8 @@ int icom_one_transaction(RIG *rig, unsigned char cmd, int subcmd,
 {
     struct icom_priv_data *priv;
     const struct icom_priv_caps *priv_caps;
-    struct rig_state *rs;
+    struct rig_state *rs = STATE(rig);
+    hamlib_port_t *rp = RIGPORT(rig);
     struct timeval start_time, current_time, elapsed_time;
     // this buf needs to be large enough for 0xfe strings for power up
     // at 115,200 this is now at least 150
@@ -134,29 +140,37 @@ int icom_one_transaction(RIG *rig, unsigned char cmd, int subcmd,
     unsigned char sendbuf[MAXFRAMELEN];
     int frm_len, frm_data_len, retval;
     unsigned char ctrl_id;
+    int collision_retry = 0;
 
     ENTERFUNC;
     memset(buf, 0, 200);
     memset(sendbuf, 0, MAXFRAMELEN);
-    rs = &rig->state;
     priv = (struct icom_priv_data *)rs->priv;
     priv_caps = (struct icom_priv_caps *)rig->caps->priv;
 
     ctrl_id = priv_caps->serial_full_duplex == 0 ? CTRLID : 0x80;
 
+    // Should check return code and that write wrote cmd_len chars!
+
+    set_transaction_active(rig);
+
+collision_retry:
+
+    // The IC7100 cannot separate the CI-V port from the USB CI-V
+    // We see async packets coming in so we'll try and do the flush
+    // This also means the IC7100 will not support async packets anymore
+    if (rig->caps->rig_model == RIG_MODEL_IC7100)
+    {
+        rig_flush(rp);
+    }
+
     frm_len = make_cmd_frame(sendbuf, priv->re_civ_addr, ctrl_id, cmd,
                              subcmd, payload, payload_len);
 
-    /*
-     * should check return code and that write wrote cmd_len chars!
-     */
-    set_transaction_active(rig);
-
-    rig_flush(&rs->rigport);
 
     if (data_len) { *data_len = 0; }
 
-    retval = write_block(&rs->rigport, sendbuf, frm_len);
+    retval = write_block(rp, sendbuf, frm_len);
 
     if (retval != RIG_OK)
     {
@@ -176,7 +190,8 @@ int icom_one_transaction(RIG *rig, unsigned char cmd, int subcmd,
          *          up to rs->retry times.
          */
 
-        retval = read_icom_frame(&rs->rigport, buf, sizeof(buf));
+again1:
+        retval = read_icom_frame(rp, buf, sizeof(buf));
 
         if (retval == -RIG_ETIMEOUT || retval == 0)
         {
@@ -188,7 +203,7 @@ int icom_one_transaction(RIG *rig, unsigned char cmd, int subcmd,
         if (retval < 0)
         {
             set_transaction_inactive(rig);
-            /* Other error, return it */
+            // Other error, return it
             RETURNFUNC(retval);
         }
 
@@ -198,6 +213,28 @@ int icom_one_transaction(RIG *rig, unsigned char cmd, int subcmd,
             RETURNFUNC(-RIG_EPROTO);
         }
 
+        if (icom_is_async_frame(rig, frm_len, buf))
+        {
+            icom_process_async_frame(rig, frm_len, buf);
+            goto again1;
+        }
+
+        // if we get a reply that is not our cmd/subcmd we should just ignore it and retry the read.
+        // this should somewhat allow splitting the COM port between two controllers
+        if (cmd != buf[4])
+        {
+            rig_debug(RIG_DEBUG_VERBOSE, "%s: cmd x%02x != buf x%02x so retry read\n",
+                      __func__, cmd, buf[4]);
+            goto again1;
+        }
+
+        if (subcmd != -1 && subcmd != buf[5])
+        {
+            rig_debug(RIG_DEBUG_VERBOSE, "%s: subcmd x%02x != buf x%02x so retry read\n",
+                      __func__, subcmd, buf[5]);
+            goto again1;
+        }
+
         // we might have 0xfe string during rig wakeup
         rig_debug(RIG_DEBUG_TRACE, "%s: DEBUG retval=%d, frm_len=%d, cmd=0x%02x\n",
                   __func__, retval, frm_len, cmd);
@@ -218,7 +255,18 @@ int icom_one_transaction(RIG *rig, unsigned char cmd, int subcmd,
         switch (buf[retval - 1])
         {
         case COL:
+
             /* Collision */
+            // IC746 for example responds 0xfc when tuning is active so we will retry
+            if (collision_retry++ < 20)
+            {
+                rig_debug(RIG_DEBUG_VERBOSE, "%s: collision retry#%d\n", __func__,
+                          collision_retry);
+                hl_usleep(500 *
+                          1000); // 500ms 20 times for ~15 second max before we back out for a retry if needed
+                goto collision_retry;
+            }
+
             set_transaction_inactive(rig);
             RETURNFUNC(-RIG_BUSBUSY);
 
@@ -242,7 +290,9 @@ int icom_one_transaction(RIG *rig, unsigned char cmd, int subcmd,
             RETURNFUNC(-RIG_EPROTO);
         }
 
-        if (memcmp(buf, sendbuf, frm_len) != 0)
+        // first 2 bytes of everything are 0xfe so we won't test those
+        // this allows some corruptin of the 0xfe bytes which has been seen in the wild
+        if (memcmp(&buf[2], &sendbuf[2], frm_len - 2) != 0)
         {
             /* Frames are different? */
             /* Problem on ci-v bus? */
@@ -269,8 +319,51 @@ read_another_frame:
      * FIXME: handle padding/collisions
      * ACKFRMLEN is the smallest frame we can expect from the rig
      */
+    priv->serial_USB_echo_off = 1;
+again2:
     buf[0] = 0;
-    frm_len = read_icom_frame(&rs->rigport, buf, sizeof(buf));
+    frm_len = read_icom_frame(rp, buf, sizeof(buf));
+
+    if (frm_len <= 0)
+    {
+        set_transaction_inactive(rig);
+        RETURNFUNC(frm_len);
+    }
+
+    if (frm_len > 4 && memcmp(buf, sendbuf, frm_len) == 0)
+    {
+        priv->serial_USB_echo_off = 0;
+        goto again2;
+    }
+
+    // https://github.com/Hamlib/Hamlib/issues/1575
+    // these types of async can interrupt the cmd we sent
+    // if our host number changes must not be for us
+    if (icom_is_async_frame(rig, frm_len, buf))
+    {
+        icom_process_async_frame(rig, frm_len, buf);
+        goto again2;
+    }
+
+    // IC-PW2 was sending fe fe 94 aa 1c 03
+    if (buf[3] == 0xaa || buf[2] == 0xaa)
+    {
+        goto again2;
+    }
+
+    if (sendbuf[3] != buf[2])
+    {
+        rig_debug(RIG_DEBUG_VERBOSE, "%s: unknown async?  read again\n", __func__);
+        hl_usleep(100);
+        rig_flush(rp);
+        collision_retry++;
+
+        if (collision_retry < 2)
+        {
+            goto collision_retry;
+        }
+    }
+
 
 #if 0
 
@@ -281,7 +374,7 @@ read_another_frame:
         // Hmmm -- got an echo back when not expected so let's change
         priv->serial_USB_echo_off = 0;
         // And try again
-        frm_len = read_icom_frame(&rs->rigport, buf, sizeof(buf));
+        frm_len = read_icom_frame(rp, buf, sizeof(buf));
     }
 
 #endif
@@ -289,8 +382,15 @@ read_another_frame:
     if (frm_len < 0)
     {
         set_transaction_inactive(rig);
-        /* RIG_TIMEOUT: timeout getting response, return timeout */
-        /* other error: return it */
+
+        if (priv_caps->re_civ_addr != priv->re_civ_addr)
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: Icom timeout civ expected=%02x, used=%02x\n",
+                      __func__, priv_caps->re_civ_addr, priv->re_civ_addr);
+        }
+
+        // RIG_TIMEOUT: timeout getting response, return timeout
+        // other error: return it
         RETURNFUNC(frm_len);
     }
 
@@ -373,15 +473,15 @@ read_another_frame:
     // TODO: Does ctrlid (detected by icom_is_async_frame) vary (seeing some code above using 0x80 for non-full-duplex)?
     if (icom_is_async_frame(rig, frm_len, buf))
     {
-        int elapsed_ms;
+        int elapsedms;
         icom_process_async_frame(rig, frm_len, buf);
 
         gettimeofday(&current_time, NULL);
         timersub(&current_time, &start_time, &elapsed_time);
 
-        elapsed_ms = (int)(elapsed_time.tv_sec * 1000 + elapsed_time.tv_usec / 1000);
+        elapsedms = (int)(elapsed_time.tv_sec * 1000 + elapsed_time.tv_usec / 1000);
 
-        if (elapsed_ms > rs->rigport.timeout)
+        if (elapsedms > rp->timeout)
         {
             set_transaction_inactive(rig);
             RETURNFUNC(-RIG_ETIMEOUT);
@@ -394,7 +494,7 @@ read_another_frame:
 
     *data_len = frm_data_len;
 
-    if (data != NULL && data_len != NULL) { memcpy(data, buf + 4, *data_len); }
+    if (data != NULL) { memcpy(data, buf + 4, *data_len); }
 
     /*
      * TODO: check addresses in reply frame
@@ -408,7 +508,7 @@ read_another_frame:
  *
  * This function honors rigport.retry count.
  *
- * We assume that rig!=NULL, rig->state!= NULL, payload!=NULL, data!=NULL, data_len!=NULL
+ * We assume that rig!=NULL, STATE(rig)!= NULL, payload!=NULL, data!=NULL, data_len!=NULL
  * Otherwise, you'll get a nice seg fault. You've been warned!
  * payload can be NULL if payload_len == 0
  * subcmd can be equal to -1 (no subcmd wanted)
@@ -427,14 +527,15 @@ int icom_transaction(RIG *rig, int cmd, int subcmd,
               "%s: cmd=0x%02x, subcmd=0x%02x, payload_len=%d\n", __func__,
               cmd, subcmd, payload_len);
 
-    retry = rig->state.rigport.retry;
+    retry = RIGPORT(rig)->retry;
 
     do
     {
         retval = icom_one_transaction(rig, cmd, subcmd, payload, payload_len, data,
                                       data_len);
 
-        if (retval == RIG_OK || retval == -RIG_ERJCTED)
+        // codes that make us return immediately
+        if (retval == RIG_OK || retval == -RIG_ERJCTED || retval == -RIG_BUSERROR)
         {
             break;
         }
@@ -496,7 +597,7 @@ static int read_icom_frame_generic(hamlib_port_t *p,
                             icom_block_end, icom_block_end_length, 0, 1);
         }
 
-        if (i < 0 && i != RIG_BUSBUSY) /* die on errors */
+        if (i < 0 && i != -RIG_BUSBUSY) /* die on errors */
         {
             return (i);
         }
@@ -520,7 +621,8 @@ static int read_icom_frame_generic(hamlib_port_t *p,
             && (rxbuffer[read - 1] != COL));
 
     // Check that we have a valid frame preamble (which might be just a single preable character)
-    if (rxbuffer[0] != PR)
+    // Or an error code
+    if (rxbuffer[0] != PR && rxbuffer[0] != COL)
     {
         return -RIG_EPROTO;
     }
@@ -557,7 +659,8 @@ int rig2icom_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width,
     unsigned char icmode;
     signed char icmode_ext;
     pbwidth_t width_tmp = width;
-    struct icom_priv_data *priv_data = (struct icom_priv_data *) rig->state.priv;
+    const struct icom_priv_data *priv_data = (struct icom_priv_data *)
+            STATE(rig)->priv;
 
     ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: mode=%d, width=%d\n", __func__, (int)mode,
@@ -708,8 +811,20 @@ int rig2icom_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width,
 void icom2rig_mode(RIG *rig, unsigned char md, int pd, rmode_t *mode,
                    pbwidth_t *width)
 {
-    ENTERFUNC;
     rig_debug(RIG_DEBUG_TRACE, "%s: mode=0x%02x, pd=%d\n", __func__, md, pd);
+
+    // Some rigs return fixed with for FM mode
+    if ((RIG_IS_IC7300 || RIG_IS_IC9700) && (md == S_FM || md == S_WFM))
+    {
+        *mode = RIG_MODE_FM;
+
+        if (*width == 1) { *width = 15000; }
+        else if (*width == 2) { *width = 10000; }
+        else { *width = 7000; }
+
+        return;
+    }
+
     *width = RIG_PASSBAND_NORMAL;
 
     switch (md)
@@ -839,6 +954,5 @@ void icom2rig_mode(RIG *rig, unsigned char md, int pd, rmode_t *mode,
     default:
         rig_debug(RIG_DEBUG_ERR, "icom: Unsupported Icom mode width %#.2x\n", pd);
     }
-
 }
 
