@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include "hamlib/rig.h"
@@ -54,7 +52,7 @@ static const struct icom_priv_caps ic375_priv_caps =
     ic737_ts_sc_list
 };
 
-const struct rig_caps ic275_caps =
+struct rig_caps ic275_caps =
 {
     RIG_MODEL(RIG_MODEL_IC275),
     .model_name = "IC-275",
@@ -120,7 +118,7 @@ const struct rig_caps ic275_caps =
     },
 
     .tuning_steps =     {
-        {IC275_MODES, 10}, /* TBC: does this rig supports settin tuning step? */
+        {IC275_MODES, 10}, /* TBC: does this rig supports setting tuning step? */
         RIG_TS_END,
     },
     /* mode/filter list, remember: order matters! */
@@ -153,7 +151,7 @@ const struct rig_caps ic275_caps =
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
-const struct rig_caps ic375_caps =
+struct rig_caps ic375_caps =
 {
     RIG_MODEL(RIG_MODEL_IC375),
     .model_name = "IC-375",
@@ -219,7 +217,7 @@ const struct rig_caps ic375_caps =
     },
 
     .tuning_steps =     {
-        {IC275_MODES, 10}, /* TBC: does this rig supports settin tuning step? */
+        {IC275_MODES, 10}, /* TBC: does this rig supports setting tuning step? */
         RIG_TS_END,
     },
     /* mode/filter list, remember: order matters! */
