@@ -19,16 +19,14 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include "hamlib/rig.h"
 #include "icom.h"
 #include "icom_defs.h"
 #include "frame.h"
-#include "idx_builtin.h"
 #include "bandplan.h"
+#include "tones.h"
 
 
 /*
@@ -146,7 +144,7 @@ static const struct icom_priv_caps ic706_priv_caps =
     .r2i_mode = ic706_r2i_mode
 };
 
-const struct rig_caps ic706_caps =
+struct rig_caps ic706_caps =
 {
     RIG_MODEL(RIG_MODEL_IC706),
     .model_name = "IC-706",
@@ -264,7 +262,7 @@ const struct rig_caps ic706_caps =
     .get_freq =  icom_get_freq,
     .set_mode =  icom_set_mode,
     .get_mode =  icom_get_mode,
-    .get_vfo =  icom_get_vfo,
+//    .get_vfo =  icom_get_vfo,
     .set_vfo =  icom_set_vfo,
 
     .decode_event =  icom_decode_event,
@@ -294,7 +292,7 @@ static const struct icom_priv_caps ic706mkii_priv_caps =
     .r2i_mode = ic706_r2i_mode
 };
 
-const struct rig_caps ic706mkii_caps =
+struct rig_caps ic706mkii_caps =
 {
     RIG_MODEL(RIG_MODEL_IC706MKII),
     .model_name = "IC-706MkII",
@@ -415,7 +413,7 @@ const struct rig_caps ic706mkii_caps =
     .get_freq =  icom_get_freq,
     .set_mode =  icom_set_mode,
     .get_mode =  icom_get_mode,
-    .get_vfo =  icom_get_vfo,
+//    .get_vfo =  icom_get_vfo,
     .set_vfo =  icom_set_vfo,
 
     .decode_event =  icom_decode_event,
@@ -465,7 +463,7 @@ static const struct icom_priv_caps ic706mkiig_priv_caps =
     .r2i_mode = ic706_r2i_mode
 };
 
-const struct rig_caps ic706mkiig_caps =
+struct rig_caps ic706mkiig_caps =
 {
     RIG_MODEL(RIG_MODEL_IC706MKIIG),
     .model_name = "IC-706MkIIG",
@@ -612,7 +610,7 @@ const struct rig_caps ic706mkiig_caps =
     .get_freq =  icom_get_freq,
     .set_mode =  icom_set_mode,
     .get_mode =  icom_get_mode,
-    .get_vfo =  icom_get_vfo,
+//    .get_vfo =  icom_get_vfo,
     .set_vfo =  icom_set_vfo,
 
     .decode_event =  icom_decode_event,
