@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include "hamlib/rig.h"
@@ -57,7 +55,7 @@ static const struct icom_priv_caps ic781_priv_caps =
     ic737_ts_sc_list
 };
 
-const struct rig_caps ic781_caps =
+struct rig_caps ic781_caps =
 {
     RIG_MODEL(RIG_MODEL_IC781),
     .model_name = "IC-781",
@@ -177,7 +175,7 @@ const struct rig_caps ic781_caps =
     .set_mode =  icom_set_mode,
     .get_mode =  icom_get_mode,
     .set_vfo =  icom_set_vfo,
-    .get_vfo =  icom_get_vfo,
+//    .get_vfo =  icom_get_vfo,
     .set_split_vfo =  icom_set_split_vfo,
     .set_split_freq =  icom_set_split_freq,
     .get_split_freq =  icom_get_split_freq,
