@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>
 
@@ -105,7 +103,7 @@ static struct icom_priv_caps icr75_priv_caps =
     .ant_count = 2
 };
 
-const struct rig_caps icr75_caps =
+struct rig_caps icr75_caps =
 {
     RIG_MODEL(RIG_MODEL_ICR75),
     .model_name = "IC-R75",
@@ -135,18 +133,26 @@ const struct rig_caps icr75_caps =
     .has_set_parm =  RIG_PARM_SET(ICR75_PARM_ALL),
     .level_gran =
     {
+#define NO_LVL_PBT_IN
+#define NO_LVL_PBT_OUT
+#define NO_LVL_CWPITCH
 #include "level_gran_icom.h"
-        // cppcheck-suppress *
-        [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
         [LVL_PBT_IN] = { .min = { .f = -1280 }, .max = { .f = +1280 }, .step = { .f = 15 } },
         [LVL_PBT_OUT] = { .min = { .f = -1280 }, .max = { .f = +1280 }, .step = { .f = 15 } },
         [LVL_CWPITCH] = { .min = { .i = 300 }, .max = { .i = 900 }, .step = { .i = 10 } },
-        [LVL_NR] = { .min = { .f = 0.0 }, .max = { .f = 1.0 }, .step = { .f = 0.066666667 } },
+#undef NO_LVL_PBT_IN
+#undef NO_LVL_PBT_OUT
+#undef NO_LVL_CWPITCH
     },
     .parm_gran =  {
         [PARM_APO] = { .min = { .i = 1 }, .max = { .i = 1439} },
         [PARM_TIME] = { .min = { .i = 0 }, .max = { .i = 86399} },
+        [PARM_BACKLIGHT] = {.min = {.f = 0.0f}, .max = {.f = 1.0f}, .step = {.f = 1.0f / 255.0f}},
+        [PARM_BANDSELECT] = {.step = {.s = "BANDUNUSED,BAND160M,BAND80M,BAND40M,BAND30M,BAND20M,BAND17M,BAND15M,BAND12M,BAND10M,BAND6M,BANDGEN"}},
+        [PARM_BEEP] = {.min = {.i = 0}, .max = {.i = 1}, .step = {.i = 1}},
+        [PARM_ANN] = {.min = {.i = 0}, .max = {.i = 2}, .step = {.i = 1}},
     },
+
     .ctcss_list =  NULL,
     .dcs_list =  NULL,
     .preamp =   { 10, 20, RIG_DBLST_END, }, /* TBC */
@@ -250,7 +256,7 @@ const struct rig_caps icr75_caps =
 
 /*
  * icr75_set_channel
- * Assumes rig!=NULL, rig->state.priv!=NULL, chan!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL, chan!=NULL
  * TODO: still a WIP --SF
  */
 int icr75_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
@@ -263,7 +269,7 @@ int icr75_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
     signed char icmode_ext;
     int err;
 
-    rs = &rig->state;
+    rs = STATE(rig);
     priv = (struct icom_priv_data *)rs->priv;
 
     to_bcd_be(chanbuf, chan->channel_num, 4);
@@ -319,7 +325,7 @@ int icr75_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
 
 /*
  * icr75_get_channel
- * Assumes rig!=NULL, rig->state.priv!=NULL, chan!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL, chan!=NULL
  * TODO: still a WIP --SF
  */
 int icr75_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
@@ -329,7 +335,7 @@ int icr75_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
     unsigned char chanbuf[24];
     int chan_len, freq_len, retval;
 
-    rs = &rig->state;
+    rs = STATE(rig);
     priv = (struct icom_priv_data *)rs->priv;
 
     to_bcd_be(chanbuf, chan->channel_num, 4);
