@@ -20,15 +20,12 @@
  *
  */
 
-#include <hamlib/config.h>
-
-
 #include "hamlib/rig.h"
 #include "token.h"
 #include "icom.h"
 #include "idx_builtin.h"
 #include "icom_defs.h"
-#include "frame.h"
+#include "tones.h"
 
 /*
  * Specs and protocol details comes from the chapter 17 of ID-51A_E_PLUS2_CD_0.pdf
@@ -85,14 +82,14 @@ static struct icom_priv_caps id51_priv_caps =
     1,      /* no XCHG */
 };
 
-const struct rig_caps id51_caps =
+struct rig_caps id51_caps =
 {
     RIG_MODEL(RIG_MODEL_ID51),
     .model_name = "ID-51",
     .mfg_name =  "Icom",
     .version =  BACKEND_VER ".1",
     .copyright =  "LGPL",
-    .status =  RIG_STATUS_ALPHA,
+    .status =  RIG_STATUS_BETA,
     .rig_type =  RIG_TYPE_HANDHELD,
     .ptt_type =  RIG_PTT_RIG,
     .dcd_type =  RIG_DCD_RIG,
@@ -114,7 +111,6 @@ const struct rig_caps id51_caps =
     .has_get_parm =  ID51_PARM_ALL,
     .has_set_parm =  ID51_PARM_ALL,
     .level_gran = {
-        // cppcheck-suppress *
         [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
     },
     .ext_tokens = id51_tokens,
