@@ -24,8 +24,6 @@
  * Email: james (dot) m (dot) smith (at) earthlink (dot) net
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include <hamlib/rig.h>
@@ -63,7 +61,7 @@ static struct icom_priv_caps os535_priv_caps =
     .settle_time = 12,
 };
 
-const struct rig_caps os535_caps =
+struct rig_caps os535_caps =
 {
     RIG_MODEL(RIG_MODEL_OS535),
     .model_name = "OptoScan535",
@@ -92,7 +90,6 @@ const struct rig_caps os535_caps =
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,
     .level_gran = {
-        // cppcheck-suppress *
         [LVL_RAWSTR] = { .min = { .i = 0 }, .max = { .i = 255 } },
     },
     .parm_gran =  {},
