@@ -20,8 +20,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>
 
@@ -75,7 +73,7 @@ struct jst145_priv_data
  * JST-145 rig capabilities.
  *
  */
-const struct rig_caps jst145_caps =
+struct rig_caps jst145_caps =
 {
     RIG_MODEL(RIG_MODEL_JST145),
     .model_name = "JST-145",
@@ -176,7 +174,7 @@ const struct rig_caps jst145_caps =
  * JST-245 rig capabilities.
  *
  */
-const struct rig_caps jst245_caps =
+struct rig_caps jst245_caps =
 {
     RIG_MODEL(RIG_MODEL_JST245),
     .model_name = "JST-245",
@@ -288,7 +286,7 @@ static int jst145_init(RIG *rig)
         return -RIG_ENOMEM;
     }
 
-    rig->state.priv = (void *)priv;
+    STATE(rig)->priv = (void *)priv;
     return RIG_OK;
 }
 
@@ -298,9 +296,9 @@ static int jst145_open(RIG *rig)
     freq_t freq;
     rmode_t mode;
     pbwidth_t width;
-    struct jst145_priv_data *priv = rig->state.priv;
+    struct jst145_priv_data *priv = STATE(rig)->priv;
 
-    retval = write_block(&rig->state.rigport, (unsigned char *) "H1\r", 3);
+    retval = write_block(RIGPORT(rig), (unsigned char *) "H1\r", 3);
 
     if (retval != RIG_OK)
     {
@@ -319,7 +317,7 @@ static int jst145_open(RIG *rig)
 
 static int jst145_close(RIG *rig)
 {
-    return write_block(&rig->state.rigport, (unsigned char *) "H0\r", 3);
+    return write_block(RIGPORT(rig), (unsigned char *) "H0\r", 3);
 }
 
 static int jst145_set_vfo(RIG *rig, vfo_t vfo)
@@ -327,7 +325,7 @@ static int jst145_set_vfo(RIG *rig, vfo_t vfo)
     char cmd[MAX_LEN];
     SNPRINTF(cmd, sizeof(cmd), "F%c\r", vfo == RIG_VFO_A ? 'A' : 'B');
 
-    return write_block(&rig->state.rigport, (unsigned char *) cmd, strlen(cmd));
+    return write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 }
 
 static int jst145_get_vfo(RIG *rig, vfo_t *vfo)
@@ -341,13 +339,13 @@ static int jst145_get_vfo(RIG *rig, vfo_t *vfo)
 
     jst145_get_ptt(rig, RIG_VFO_A,
                    &ptt); // set priv->ptt to current transmit status
-    rig->state.cache.ptt = ptt;
+    CACHE(rig)->ptt = ptt;
 
 ptt_retry:
 
     if (ptt)  // can't get vfo while transmitting
     {
-        *vfo = rig->state.current_vfo;
+        *vfo = STATE(rig)->current_vfo;
         return RIG_OK;
     }
 
@@ -373,10 +371,10 @@ static int jst145_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
     char freqbuf[MAX_LEN];
     int retval;
-    struct jst145_priv_data *priv = rig->state.priv;
-    vfo_t save_vfo = rig->state.current_vfo;
+    struct jst145_priv_data *priv = STATE(rig)->priv;
+    vfo_t save_vfo = STATE(rig)->current_vfo;
 
-    if (vfo == RIG_VFO_CURR) vfo = save_vfo;
+    if (vfo == RIG_VFO_CURR) { vfo = save_vfo; }
 
     SNPRINTF(freqbuf, sizeof(freqbuf), "F%08u%c\r", (unsigned)(freq),
              vfo == RIG_VFO_A ? 'A' : 'B');
@@ -390,7 +388,7 @@ static int jst145_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
         priv->freqA = freq;
     }
 
-    retval = write_block(&rig->state.rigport, (unsigned char *) freqbuf,
+    retval = write_block(RIGPORT(rig), (unsigned char *) freqbuf,
                          strlen(freqbuf));
 
     if (retval != RIG_OK)
@@ -416,14 +414,14 @@ static int jst145_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
     int freqbuf_size = sizeof(freqbuf);
     int retval;
     int n;
-    vfo_t save_vfo = rig->state.current_vfo;
+    vfo_t save_vfo = STATE(rig)->current_vfo;
 
-    //struct jst145_priv_data *priv = rig->state.priv;
+    //struct jst145_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: vfo=%s curr_vfo=%s\n", __func__,
               rig_strvfo(vfo), rig_strvfo(save_vfo));
 
-    if (vfo == RIG_VFO_CURR) vfo = save_vfo;
+    if (vfo == RIG_VFO_CURR) { vfo = save_vfo; }
 
     if (save_vfo != vfo)
     {
@@ -457,7 +455,7 @@ static int jst145_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
     int retval;
     char *modestr;
-    struct jst145_priv_data *priv = rig->state.priv;
+    struct jst145_priv_data *priv = STATE(rig)->priv;
 
     switch (mode)
     {
@@ -477,7 +475,7 @@ static int jst145_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
         return -RIG_EINVAL;
     }
 
-    retval = write_block(&rig->state.rigport, (unsigned char *) modestr,
+    retval = write_block(RIGPORT(rig), (unsigned char *) modestr,
                          strlen(modestr));
 
     if (retval != RIG_OK)
@@ -508,7 +506,7 @@ static int jst145_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
     if (retval != RIG_OK)
     {
-        rig_debug(RIG_DEBUG_ERR, "%s: jrc_transcation failed: %s\n", __func__,
+        rig_debug(RIG_DEBUG_ERR, "%s: jrc_transaction failed: %s\n", __func__,
                   rigerror(retval));
     }
 
@@ -544,7 +542,7 @@ static int jst145_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
     {
         char *cmd = val.i == RIG_AGC_SLOW ? "G0\r" : (val.i == RIG_AGC_FAST ? "G1\r" :
                     "G2\r");
-        return write_block(&rig->state.rigport, (unsigned char *) cmd, 3);
+        return write_block(RIGPORT(rig), (unsigned char *) cmd, 3);
     }
 
     default:
@@ -560,7 +558,7 @@ static int jst145_set_mem(RIG *rig, vfo_t vfo, int ch)
 
     SNPRINTF(membuf, sizeof(membuf), "C%03d\r", ch);
 
-    return write_block(&rig->state.rigport, (unsigned char *) membuf,
+    return write_block(RIGPORT(rig), (unsigned char *) membuf,
                        strlen(membuf));
 }
 
@@ -569,7 +567,7 @@ static int jst145_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
     switch (op)
     {
     case RIG_OP_FROM_VFO:
-        return write_block(&rig->state.rigport, (unsigned char *) "E1\r", 3);
+        return write_block(RIGPORT(rig), (unsigned char *) "E1\r", 3);
 
     default:
         return -RIG_EINVAL;
@@ -581,11 +579,11 @@ static int jst145_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 static int jst145_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
     char cmd[MAX_LEN];
-    struct jst145_priv_data *priv = rig->state.priv;
+    struct jst145_priv_data *priv = STATE(rig)->priv;
     rig_debug(RIG_DEBUG_TRACE, "%s: entered\n", __func__);
     SNPRINTF(cmd, sizeof(cmd), "X%c\r", ptt ? '1' : '0');
     priv->ptt = ptt;
-    return write_block(&rig->state.rigport, (unsigned char *) cmd, strlen(cmd));
+    return write_block(RIGPORT(rig), (unsigned char *) cmd, strlen(cmd));
 }
 
 static int jst145_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
@@ -594,7 +592,7 @@ static int jst145_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
     char pttstatus[MAX_LEN];
     int pttstatus_size = sizeof(pttstatus);
     int retval;
-    struct jst145_priv_data *priv = rig->state.priv;
+    struct jst145_priv_data *priv = STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: entered\n", __func__);
 
@@ -611,7 +609,7 @@ static int jst145_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
     if (pttstatus[1] == '1') { *ptt = RIG_PTT_ON; }
     else { *ptt = RIG_PTT_OFF; }
 
-    priv->ptt = rig->state.cache.ptt = *ptt;
+    priv->ptt = CACHE(rig)->ptt = *ptt;
 
     return RIG_OK;
 }
