@@ -21,8 +21,7 @@
  *
  */
 
-#include <hamlib/config.h>
-
+#include <stdint.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>  /* String function definitions */
@@ -31,7 +30,6 @@
 #include "hamlib/rig.h"
 #include "serial.h"
 #include "misc.h"
-#include "register.h"
 
 #include "kenwood.h"
 #include "ic10.h"
@@ -69,25 +67,29 @@ int ic10_cmd_trim(char *data, int data_len)
 
 /**
  * ic10_transaction
- * Assumes rig!=NULL rig->state!=NULL rig->caps!=NULL
+ * Assumes rig!=NULL STATE(rig)!=NULL rig->caps!=NULL
 **/
 int ic10_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
                      int *data_len)
 {
     int retval;
     int retry_cmd = 0;
-    struct rig_state *rs;
+    struct hamlib_port *rp = RIGPORT(rig);
+
+    if (cmd == NULL)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: cmd==NULL?\n", __func__);
+        return -RIG_EARG;
+    }
 
     rig_debug(RIG_DEBUG_TRACE,
               "%s: called cmd='%s', len=%d, data=%p, data_len=%p\n", __func__, cmd, cmd_len,
               data, data_len);
 
-    rs = &rig->state;
-
 transaction:
-    rig_flush(&rs->rigport);
+    rig_flush(rp);
 
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, cmd_len);
+    retval = write_block(rp, (unsigned char *) cmd, cmd_len);
 
     if (retval != RIG_OK)
     {
@@ -97,20 +99,20 @@ transaction:
     if (!data)
     {
         char buffer[50];
-        struct kenwood_priv_data *priv = rig->state.priv;
+        const struct kenwood_priv_data *priv = STATE(rig)->priv;
 
-        if (RIG_OK != (retval = write_block(&rs->rigport,
+        if (RIG_OK != (retval = write_block(rp,
                                             (unsigned char *) priv->verify_cmd, strlen(priv->verify_cmd))))
         {
             return retval;
         }
 
         // this should be the ID response
-        retval = read_string(&rs->rigport, (unsigned char *) buffer, sizeof(buffer),
+        retval = read_string(rp, (unsigned char *) buffer, sizeof(buffer),
                              ";", 1, 0, 1);
 
         // might be ?; too
-        if (buffer[0] == '?' && retry_cmd++ < rs->rigport.retry)
+        if (buffer[0] == '?' && retry_cmd++ < rp->retry)
         {
             rig_debug(RIG_DEBUG_ERR, "%s: retrying cmd #%d\n", __func__, retry_cmd);
             goto transaction;
@@ -126,7 +128,7 @@ transaction:
         return RIG_OK;
     }
 
-    retval = read_string(&rs->rigport, (unsigned char *) data, 50, ";", 1, 0, 1);
+    retval = read_string(rp, (unsigned char *) data, 50, ";", 1, 0, 1);
 
     if (retval == -RIG_ETIMEOUT)
     {
@@ -148,12 +150,13 @@ transaction:
  */
 static int get_ic10_if(RIG *rig, char *data)
 {
-    struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)rig->caps->priv;
+    const struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)
+                                           rig->caps->priv;
     int i, data_len, retval = RIG_EINVAL;
 
     rig_debug(RIG_DEBUG_TRACE, "%s: called\n", __func__);
 
-    for (i = 0; retval != RIG_OK && i < rig->state.rigport.retry; i++)
+    for (i = 0; retval != RIG_OK && i < RIGPORT(rig)->retry; i++)
     {
         data_len = 37;
         retval = ic10_transaction(rig, "IF;", 3, data, &data_len);
@@ -163,9 +166,8 @@ static int get_ic10_if(RIG *rig, char *data)
             continue;
         }
 
-        if (retval == RIG_OK &&
-                (data_len < priv->if_len ||
-                 data[0] != 'I' || data[1] != 'F'))
+        if (data_len < priv->if_len ||
+                data[0] != 'I' || data[1] != 'F')
         {
             rig_debug(RIG_DEBUG_WARN, "%s: unexpected answer %s, len=%d\n",
                       __func__, data, data_len);
@@ -219,7 +221,8 @@ int ic10_set_vfo(RIG *rig, vfo_t vfo)
  */
 int ic10_get_vfo(RIG *rig, vfo_t *vfo)
 {
-    struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)rig->caps->priv;
+    const struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)
+                                           rig->caps->priv;
     char vfobuf[50];
     unsigned char c;
     int retval, iflen;
@@ -286,7 +289,8 @@ int ic10_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
 
 int ic10_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *txvfo)
 {
-    struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)rig->caps->priv;
+    const struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)
+                                           rig->caps->priv;
     char infobuf[50];
     int retval, iflen;
 
@@ -315,7 +319,8 @@ int ic10_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *txvfo)
  */
 int ic10_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-    struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)rig->caps->priv;
+    const struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)
+                                           rig->caps->priv;
     char modebuf[50];
     unsigned char c;
     int retval, iflen;
@@ -446,7 +451,7 @@ int ic10_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     if (vfo == RIG_VFO_CURR)
     {
-        tvfo = rig->state.current_vfo;
+        tvfo = STATE(rig)->current_vfo;
     }
     else
     {
@@ -467,7 +472,6 @@ int ic10_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
         return -RIG_EINVAL;
     }
 
-    // cppcheck-suppress *
     SNPRINTF(freqbuf, sizeof(freqbuf), "F%c%011"PRIll";", vfo_letter,
              (int64_t)freq);
     retval = ic10_transaction(rig, freqbuf, strlen(freqbuf), NULL, 0);
@@ -530,7 +534,8 @@ int ic10_get_ant(RIG *rig, vfo_t vfo, ant_t dummy, value_t *option,
  */
 int ic10_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
-    struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)rig->caps->priv;
+    const struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)
+                                           rig->caps->priv;
     char infobuf[50];
     int retval, iflen, offset;
 
@@ -551,8 +556,9 @@ int ic10_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
     /* QRP QDX should be 37 bytes but used only 1 byte for p14 instead of 2 bytes */
     /* 12345678901234567890123456789012345678 */
     offset = 5;
-    if (iflen == 36) offset = 8; // QRP QDX gets completely bogus length
-    else if (iflen == 37) offset = 9; // just incase somebody does this add p13/p14x2/p15
+
+    if (iflen == 36) { offset = 8; } // QRP QDX gets completely bogus length
+    else if (iflen == 37) { offset = 9; } // just in case somebody does this add p13/p14x2/p15
 
     *ptt = infobuf[iflen - offset] == '0' ? RIG_PTT_OFF : RIG_PTT_ON;
 
@@ -598,7 +604,8 @@ int ic10_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
  */
 int ic10_get_mem(RIG *rig, vfo_t vfo, int *ch)
 {
-    struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)rig->caps->priv;
+    const struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)
+                                           rig->caps->priv;
     char membuf[50];
     int retval, iflen;
 
@@ -1153,7 +1160,8 @@ const char *ic10_get_info(RIG *rig)
  */
 int ic10_decode_event(RIG *rig)
 {
-    struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)rig->caps->priv;
+    const struct kenwood_priv_caps *priv = (struct kenwood_priv_caps *)
+                                           rig->caps->priv;
     char asyncbuf[128], c;
     int retval, async_len = 128, iflen;
     vfo_t vfo;
