@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include <hamlib/rig.h>
@@ -41,6 +39,7 @@
 static struct kenwood_priv_caps  ts50_priv_caps  =
 {
     .cmdtrm =  EOM_KEN,
+    .tone_table_base = 1,
 };
 
 /*
@@ -48,7 +47,7 @@ static struct kenwood_priv_caps  ts50_priv_caps  =
  *
  * part of infos comes from .http = //www.kenwood.net/
  */
-const struct rig_caps ts50s_caps =
+struct rig_caps ts50s_caps =
 {
     RIG_MODEL(RIG_MODEL_TS50),
     .model_name = "TS-50S",
