@@ -17,163 +17,110 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-
-#include <hamlib/config.h>
+/* SPDX-License-Identifier: LGPL-2.1-or-later */
 
 #include <stdio.h>
+#include <string.h>
+#include <math.h>
 
 #include <hamlib/rig.h>
 #include "kenwood.h"
 #include "cal.h"
+#include "misc.h"
 
-// TODO: Copied from TS-480, to be verified
 #define TS890_VFO (RIG_VFO_A|RIG_VFO_B)
 
 #define TS890_ALL_MODES (RIG_MODE_LSB|RIG_MODE_USB|RIG_MODE_CW|RIG_MODE_FM|RIG_MODE_AM|RIG_MODE_RTTY|RIG_MODE_CWR|RIG_MODE_RTTYR|RIG_MODE_PSK|RIG_MODE_PSKR|RIG_MODE_PKTLSB|RIG_MODE_PKTUSB|RIG_MODE_PKTFM|RIG_MODE_PKTAM)
 
-// TODO: Copied from TS-480, to be verified
 #define TS890_OTHER_TX_MODES (RIG_MODE_CW|RIG_MODE_SSB|RIG_MODE_FM|RIG_MODE_RTTY)
-// TODO: Copied from TS-480, to be verified
 #define TS890_AM_TX_MODES RIG_MODE_AM
 
-// TODO: Copied from TS-480, to be verified
-#define TS890_LEVEL_SET (RIG_LEVEL_RFPOWER|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_SQL|RIG_LEVEL_AGC|RIG_LEVEL_KEYSPD|RIG_LEVEL_CWPITCH|RIG_LEVEL_ATT)
-#define TS890_LEVEL_GET (RIG_LEVEL_RFPOWER|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_SQL|RIG_LEVEL_AGC|RIG_LEVEL_KEYSPD|RIG_LEVEL_ALC|RIG_LEVEL_SWR|RIG_LEVEL_COMP_METER|RIG_LEVEL_ID_METER|RIG_LEVEL_VD_METER|RIG_LEVEL_TEMP_METER|RIG_LEVEL_CWPITCH|RIG_LEVEL_RAWSTR|RIG_LEVEL_STRENGTH|RIG_LEVEL_ATT)
-#define TS890_FUNC_ALL (RIG_FUNC_NB|RIG_FUNC_NB2|RIG_FUNC_COMP|RIG_FUNC_VOX|RIG_FUNC_NR|RIG_FUNC_BC|RIG_FUNC_BC2|RIG_FUNC_RIT|RIG_FUNC_XIT|RIG_FUNC_TUNER|RIG_FUNC_SEND_MORSE)
+#define TS890_LEVEL_SET (RIG_LEVEL_RFPOWER|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_SQL|RIG_LEVEL_AGC|RIG_LEVEL_KEYSPD|RIG_LEVEL_CWPITCH|RIG_LEVEL_ATT|RIG_LEVEL_USB_AF|RIG_LEVEL_USB_AF_INPUT)
+#define TS890_LEVEL_GET (RIG_LEVEL_RFPOWER|RIG_LEVEL_AF|RIG_LEVEL_RF|RIG_LEVEL_SQL|RIG_LEVEL_AGC|RIG_LEVEL_KEYSPD|RIG_LEVEL_ALC|RIG_LEVEL_SWR|RIG_LEVEL_COMP_METER|RIG_LEVEL_ID_METER|RIG_LEVEL_VD_METER|RIG_LEVEL_TEMP_METER|RIG_LEVEL_CWPITCH|RIG_LEVEL_RAWSTR|RIG_LEVEL_STRENGTH|RIG_LEVEL_ATT|RIG_LEVEL_USB_AF|RIG_LEVEL_USB_AF_INPUT|RIG_LEVEL_RFPOWER_METER_WATTS)
+#define TS890_FUNC_ALL (RIG_FUNC_NB|RIG_FUNC_NB2|RIG_FUNC_COMP|RIG_FUNC_VOX|RIG_FUNC_NR|RIG_FUNC_BC|RIG_FUNC_BC2|RIG_FUNC_RIT|RIG_FUNC_XIT|RIG_FUNC_TUNER|RIG_FUNC_SEND_MORSE|RIG_FUNC_TONE|RIG_FUNC_TSQL)
 
 #define TS890_VFO_OPS (RIG_OP_UP|RIG_OP_DOWN|RIG_OP_BAND_UP|RIG_OP_BAND_DOWN|RIG_OP_CPY|RIG_OP_TUNE)
 
-int kenwood_ts890_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
+static int kenwood_ts890_set_level(RIG *rig, vfo_t vfo, setting_t level,
+                                   value_t val)
 {
-    char levelbuf[16];
-    int kenwood_val;
+    char levelbuf[16], *command_string;
+    int kenwood_val, retval;
+    gran_t *level_info;
 
     rig_debug(RIG_DEBUG_TRACE, "%s called\n", __func__);
 
+    retval = check_level_param(rig, level, val, &level_info);
+
+    if (retval != RIG_OK)
+    {
+        return retval;
+    }
+
     switch (level)
     {
-    case RIG_LEVEL_RF:
-        kenwood_val = val.f * 255;
-        SNPRINTF(levelbuf, sizeof(levelbuf), "RG%03d", kenwood_val);
-        break;
-
-    case RIG_LEVEL_SQL:
-        kenwood_val = val.f * 255;
-        SNPRINTF(levelbuf, sizeof(levelbuf), "SQ%03d", kenwood_val);
-        break;
-
     case RIG_LEVEL_AGC:
         /* hamlib argument is int, possible values rig.h:enum agc_level_e */
         /* possible values for TS890 0(=off), 1(=slow), 2(=mid), 3(=fast), 4(=off/Last) */
         rig_debug(RIG_DEBUG_VERBOSE, "%s TS890S RIG_LEVEL_AGC\n", __func__);
 
-        switch (val.i)
+        kenwood_val = -1; /* Flag invalid value */
+
+        for (int j = 0; j < rig->caps->agc_level_count; j++)
         {
-        case RIG_AGC_OFF:
-            kenwood_val = 0;
-            break;
+            if (val.i == rig->caps->agc_levels[j])
+            {
+                kenwood_val = j;
+                break;
+            }
+        }
 
-        case RIG_AGC_SLOW:
-            kenwood_val = 1;
-            break;
-
-        case RIG_AGC_MEDIUM:
-            kenwood_val = 2;
-            break;
-
-        case RIG_AGC_FAST:
-            kenwood_val = 3;
-            break;
-
-        case RIG_AGC_AUTO:
-            kenwood_val = 4;
-            break;
-
-        default:
-            rig_debug(RIG_DEBUG_ERR, "%s: unsupported agc value", __func__);
+        if (kenwood_val < 0)
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: unsupported agc value:%d\n", __func__, val.i);
             return -RIG_EINVAL;
         }
 
         SNPRINTF(levelbuf, sizeof(levelbuf), "GC%d", kenwood_val);
+        return kenwood_transaction(rig, levelbuf, NULL, 0); /* Odd man out */
+
+    case RIG_LEVEL_RF:
+        command_string = "RG%03d";
         break;
 
-    case RIG_LEVEL_CWPITCH:
+    case RIG_LEVEL_SQL:
+        command_string = "SQ%03d";
+        break;
 
-        // TODO: Merge this and formatting difference into kenwood.c
-        if (val.i < 300 || val.i > 1100)
-        {
-            return -RIG_EINVAL;
-        }
+    case RIG_LEVEL_USB_AF:
+        command_string = "EX00708 %03d";
+        break;
 
-        /* 300 - 1100 Hz -> 000 - 160 */
-        kenwood_val = (val.i - 298) / 5; /* Round to nearest 5Hz */
-        SNPRINTF(levelbuf, sizeof(levelbuf), "PT%03d", kenwood_val);
+    case RIG_LEVEL_USB_AF_INPUT:
+        command_string = "EX00706 %03d";
         break;
 
     default:
         return kenwood_set_level(rig, vfo, level, val);
     }
 
+    //TODO: Add use of RIG_LEVEL_IS_FLOAT() if need to handle int level
+    kenwood_val = val.f / level_info->step.f + 0.5;
+    SNPRINTF(levelbuf, sizeof(levelbuf), command_string, kenwood_val);
     return kenwood_transaction(rig, levelbuf, NULL, 0);
 }
 
-/* Helper to get and parse meter values using RM
- * Note that we turn readings on, but nothing off.
- * 'pips' is the number of LED bars lit in the digital meter, max=70
- */
-static
-int ts890_get_meter_reading(RIG *rig, char meter, int *pips)
-{
-    char reading[9];   /* 8 char + '\0' */
-    int retval;
-    char target[] = "RMx1"; /* Turn on reading this meter */
-
-    target[2] = meter;
-    retval = kenwood_transaction(rig, target, NULL, 0);
-
-    if (retval != RIG_OK)
-    {
-        return retval;
-    }
-
-    /* Read the first value */
-    retval = kenwood_transaction(rig, "RM", reading, sizeof(reading));
-
-    if (retval != RIG_OK)
-    {
-        return retval;
-    }
-
-    /* Find the one we want */
-    while (strncmp(reading, target, 3) != 0)
-    {
-        /* That wasn't it, get the next one */
-        retval = kenwood_transaction(rig, NULL, reading, sizeof(reading));
-
-        if (retval != RIG_OK)
-        {
-            return retval;
-        }
-
-        if (reading[0] != target[0] || reading[1] != target[1])
-        {
-            /* Somebody else's data, bail */
-            return -RIG_EPROTO;
-        }
-    }
-
-    sscanf(reading + 3, "%4d", pips);
-    return RIG_OK;
-
-}
-
-int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
+static int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level,
+                                   value_t *val)
 {
     char ackbuf[50];
-    size_t ack_len, ack_len_expected;
+    size_t ack_len, ack_len_expected, len;
     int levelint;
     int retval;
+    char *command_string;
+    gran_t *level_info;
 
+    level_info = &rig->caps->level_gran[rig_setting2idx(level)];
     rig_debug(RIG_DEBUG_TRACE, "%s called\n", __func__);
 
     switch (level)
@@ -236,56 +183,30 @@ int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
             return -RIG_EPROTO;
         }
 
-        val->f = (float) levelint / 255.;
+        val->f = (float) levelint * level_info->step.f;
         return RIG_OK;
 
     case RIG_LEVEL_AGC:
-        retval = kenwood_transaction(rig, "GC", ackbuf, sizeof(ackbuf));
-        ack_len_expected = 3;
+        retval = kenwood_safe_transaction(rig, "GC", ackbuf, sizeof(ackbuf), 3);
 
         if (RIG_OK != retval)
         {
             return retval;
         }
 
-        ack_len = strlen(ackbuf);
+        levelint = ackbuf[2] - '0';  /* atoi */
 
-        if (ack_len != ack_len_expected)
+        if (levelint < 0 || levelint >= rig->caps->agc_level_count)
         {
+            rig_debug(RIG_DEBUG_ERR, "%s: unknown agc value: %s\n", __func__, ackbuf);
             return -RIG_EPROTO;
         }
 
-        switch (ackbuf[ack_len_expected - 1])
-        {
-        case '0':
-            val->i = RIG_AGC_OFF;
-            break;
-
-        case '1':
-            val->i = RIG_AGC_SLOW;
-
-            break;
-
-        case '2':
-            val->i = RIG_AGC_MEDIUM;
-            break;
-
-        case '3':
-            val->i = RIG_AGC_FAST;
-            break;
-
-        case '4':
-            val->i = RIG_AGC_AUTO;
-            break;
-
-        default:
-            return -RIG_EPROTO;
-        }
-
+        val->i = rig->caps->agc_levels[levelint];
         return RIG_OK;
 
     case RIG_LEVEL_ALC:
-        retval = ts890_get_meter_reading(rig, '1', &levelint);
+        retval = get_kenwood_meter_reading(rig, '1', &levelint);
 
         if (retval != RIG_OK)
         {
@@ -296,7 +217,7 @@ int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         return RIG_OK;
 
     case RIG_LEVEL_SWR:
-        retval = ts890_get_meter_reading(rig, '2', &levelint);
+        retval = get_kenwood_meter_reading(rig, '2', &levelint);
 
         if (retval != RIG_OK)
         {
@@ -319,7 +240,7 @@ int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         return RIG_OK;
 
     case RIG_LEVEL_COMP_METER:
-        retval = ts890_get_meter_reading(rig, '3', &levelint);
+        retval = get_kenwood_meter_reading(rig, '3', &levelint);
 
         if (retval != RIG_OK)
         {
@@ -333,7 +254,7 @@ int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         return RIG_OK;
 
     case RIG_LEVEL_ID_METER:
-        retval = ts890_get_meter_reading(rig, '4', &levelint);
+        retval = get_kenwood_meter_reading(rig, '4', &levelint);
 
         if (retval != RIG_OK)
         {
@@ -344,7 +265,7 @@ int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         return RIG_OK;
 
     case RIG_LEVEL_VD_METER:
-        retval = ts890_get_meter_reading(rig, '5', &levelint);
+        retval = get_kenwood_meter_reading(rig, '5', &levelint);
 
         if (retval != RIG_OK)
         {
@@ -356,7 +277,7 @@ int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
     case RIG_LEVEL_TEMP_METER:
 #if 0
-        retval = ts890_get_meter_reading(rig, '6', &levelint);
+        retval = get_kenwood_meter_reading(rig, '6', &levelint);
 
         if (retval != RIG_OK)
         {
@@ -366,6 +287,117 @@ int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 #endif
         return -RIG_ENIMPL;
 
+    case RIG_LEVEL_STRENGTH:
+    case RIG_LEVEL_RFPOWER_METER_WATTS:
+    {
+        cal_table_float_t *table;
+        ptt_t ptt = RIG_PTT_OFF;
+        /* Values taken from the TS-890S In-Depth Manual (IDM), p. 8
+         * 0.03 - 21.5 MHz, Preamp 1
+         */
+        /* Meter Type 1 - Kenwood specific, factory default */
+        static cal_table_float_t meter_type1 =
+        {
+            9, { { 0, -28.4f}, { 3, -26}, {11, -19.5f},
+                {19, -13}, {27, -6.5f}, {35, 0},
+                {48, 20}, {59, 40}, {70, 60}
+            }
+        };
+        /* Meter Type 2 - IARU recommended */
+        static cal_table_float_t meter_type2 =
+        {
+            9, { { 0, -54}, { 3, -48}, {11, -36},
+                {19, -24}, {27, -12}, {35, 0},
+                {48, 20}, {59, 40}, {70, 60}
+            }
+        };
+        static cal_table_t power_meter =
+        {
+            7, { { 0, 0}, { 5, 5}, { 10, 10}, {19, 25},
+                { 35, 50}, { 59, 100}, { 70, 150}
+            }
+        };
+
+        /* Make sure we're asking the right question */
+        kenwood_get_ptt(rig, vfo, &ptt);
+
+        if ((ptt == RIG_PTT_OFF) != (level == RIG_LEVEL_STRENGTH))
+        {
+            /* We're sorry, the number you have dialed is not in service */
+            if (level == RIG_LEVEL_RFPOWER_METER_WATTS)
+            {
+                val->f = 0;
+            }
+            else
+            {
+                val->i = 0;
+            }
+
+            return RIG_OK;
+        }
+
+        /* Find out which meter type is in use */
+        retval = kenwood_safe_transaction(rig, "EX00011", ackbuf, sizeof(ackbuf), 11);
+
+        if (retval != RIG_OK)
+        {
+            return retval;
+        }
+
+        if (strncmp(ackbuf + 8, "000", 3) == 0)
+        {
+            table = &meter_type1;
+        }
+        else if (strncmp(ackbuf + 8, "001", 3) == 0)
+        {
+            table = &meter_type2;
+        }
+        else
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: Unexpected meter type: %s\n",
+                      __func__, ackbuf);
+            return -RIG_EPROTO;
+        }
+
+        retval = kenwood_safe_transaction(rig, "SM", ackbuf, 10, 6);
+
+        if (retval != RIG_OK)
+        {
+            return retval;
+        }
+
+        sscanf(ackbuf + 2, "%d", &val->i);
+
+        if (level == RIG_LEVEL_RFPOWER_METER_WATTS)
+        {
+            val->f = roundf(rig_raw2val(val->i, &power_meter));
+        }
+        else
+        {
+            /* Convert reading back to dB (rounded) */
+            val->i = (int)floorf(rig_raw2val_float(val->i, table) + 0.5f);
+        }
+
+        return RIG_OK;
+    }
+
+    case RIG_LEVEL_USB_AF:
+    case RIG_LEVEL_USB_AF_INPUT:
+        if (level == RIG_LEVEL_USB_AF)
+        { command_string = "EX00708"; }
+        else
+        { command_string = "EX00706"; }
+
+        len = strlen(command_string);
+        retval = kenwood_safe_transaction(rig, command_string, ackbuf, sizeof(ackbuf),
+                                          len + 4);
+
+        if (retval != RIG_OK) { return retval; }
+
+        sscanf(&ackbuf[len + 1], "%3d", &levelint);  /* Skip the extra space */
+        val->f = levelint * level_info->step.f;
+        return RIG_OK;
+
     default:
         return kenwood_get_level(rig, vfo, level, val);
     }
@@ -373,44 +405,118 @@ int kenwood_ts890_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     return -RIG_EINTERNAL;
 }
 
+static int ts890_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
+{
+    int mask, retval;
+    char current[4];
+
+    switch (func)
+    {
+    case RIG_FUNC_TONE:
+        mask = 1;
+        break;
+
+    case RIG_FUNC_TSQL:
+        mask = 2;
+        break;
+
+    default:
+        return (kenwood_set_func(rig, vfo, func, status));
+    }
+
+    retval = kenwood_safe_transaction(rig, "TO", current, sizeof(current), 3);
+
+    if (retval != RIG_OK)
+    {
+        return (retval);
+    }
+
+    current[2] &= ~mask;
+    current[2] |= status == 0 ? 0 : mask;
+    return kenwood_transaction(rig, current, NULL, 0);
+}
+
+static int ts890_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
+{
+    int mask, retval;
+    char current[4];
+
+    switch (func)
+    {
+    case RIG_FUNC_TONE:
+        mask = 1;
+        break;
+
+    case RIG_FUNC_TSQL:
+        mask = 2;
+        break;
+
+    default:
+        return (kenwood_get_func(rig, vfo, func, status));
+    }
+
+    retval = kenwood_safe_transaction(rig, "TO", current, sizeof(current), 3);
+
+    if (retval != RIG_OK)
+    {
+        return retval;
+    }
+
+    *status = current[2] & mask ? 1 : 0;
+    return RIG_OK;
+}
+
+/*
+ *  Gets split VFO status
+ *
+ */
+static int ts890s_get_split_vfo(RIG *rig, vfo_t rxvfo, split_t *split,
+                                vfo_t *txvfo)
+{
+    char buf[4];
+    int retval;
+    vfo_t tvfo;
+    struct rig_state *rs = STATE(rig);
+    struct kenwood_priv_data *priv = rs->priv;
+
+    if (RIG_OK == (retval = kenwood_safe_transaction(rig, "FT", buf, sizeof(buf),
+                                3)))
+    {
+        if ('0' == buf[2])
+        {
+            tvfo = RIG_VFO_A;
+        }
+        else if ('1' == buf[2])
+        {
+            tvfo = RIG_VFO_B;
+        }
+        else if ('3' == buf[2])
+        {
+            tvfo = RIG_VFO_MEM;
+        }
+        else
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: Unknown VFO - %s\n", __func__, buf);
+            return -RIG_EPROTO;
+        }
+
+        *txvfo = priv->tx_vfo = rs->tx_vfo = tvfo;
+	// Now get split status
+	retval = kenwood_safe_transaction(rig, "TB", buf, sizeof buf, 3);
+	if (RIG_OK != retval) {return retval;}
+        *split = priv->split = buf[2] == '1';
+    }
+
+    return retval;
+}
+
+
 static struct kenwood_priv_caps ts890s_priv_caps =
 {
     .cmdtrm = EOM_KEN,
+    .tone_table_base = 0,
 };
 
-/* S-meter calibration table
- * The TS-890S has two distinct S-meter curves, selectable
- * by menu option.  Define both, but since Hamlib has only
- * one slot, use the the IARU one.
- * Values taken from TS-890S In-Depth Manual, p. 8
- */
-/* Meter Type 1 - Kenwood specific (default) */
-#define TS890_SM_CAL2 { 9, \
-  { \
-    { 0, -28 }, \
-    { 3, -26 }, \
-    { 11, -20 }, \
-    { 19, -13 }, \
-    { 27, -7 }, \
-    { 35, 0 }, \
-    { 48, 20 }, \
-    { 59, 40 }, \
-    { 70, 60 }, \
-  } }
-/* Meter Type 2 - IARU Standard */
-#define TS890_SM_CAL1 { 9, \
-  { \
-    { 0, -54 }, \
-    { 3, -48 }, \
-    { 11, -36 }, \
-    { 19, -24 }, \
-    { 27, -12 }, \
-    { 35, 0 }, \
-    { 48, 20 }, \
-    { 59, 40 }, \
-    { 70, 60 }, \
-  } }
-
 /* SWR meter calibration table */
 /* The full scale value reads infinity, so arbitrary */
 #define TS890_SWR_CAL { 5, \
@@ -424,15 +530,14 @@ static struct kenwood_priv_caps ts890s_priv_caps =
 
 /*
  * TS-890S rig capabilities
- * Copied from ts480_caps, many of the values have not been verified.
  * Notice that some rigs share the same functions.
  */
-const struct rig_caps ts890s_caps =
+struct rig_caps ts890s_caps =
 {
     RIG_MODEL(RIG_MODEL_TS890S),
     .model_name = "TS-890S",
     .mfg_name = "Kenwood",
-    .version = BACKEND_VER ".10",
+    .version = BACKEND_VER ".16",
     .copyright = "LGPL",
     .status = RIG_STATUS_STABLE,
     .rig_type = RIG_TYPE_TRANSCEIVER,
@@ -447,8 +552,8 @@ const struct rig_caps ts890s_caps =
     .serial_handshake = RIG_HANDSHAKE_NONE,
     .write_delay = 0,
     .post_write_delay = 0,
-    .timeout = 500,
-    .retry = 10,
+    .timeout = 200,
+    .retry = 1,
     .preamp = {12, RIG_DBLST_END,},
     .attenuator = {6, 12, 18, RIG_DBLST_END,},
     .max_rit = kHz(9.99),
@@ -458,7 +563,11 @@ const struct rig_caps ts890s_caps =
     .transceive = RIG_TRN_RIG,
     .agc_level_count = 5,
     .agc_levels = { RIG_AGC_OFF, RIG_AGC_SLOW, RIG_AGC_MEDIUM, RIG_AGC_FAST, RIG_AGC_ON },
-
+    .chan_list =  {
+        { 1,   6, RIG_MTYPE_VOICE },
+        { 1,   8, RIG_MTYPE_MORSE },
+        RIG_CHAN_END,
+    },
     .rx_range_list1 = {
         {kHz(100),   Hz(59999999), TS890_ALL_MODES, -1, -1, TS890_VFO},
         RIG_FRNG_END,
@@ -542,8 +651,8 @@ const struct rig_caps ts890s_caps =
         RIG_FLT_END,
     },
     .vfo_ops = TS890_VFO_OPS,
+    .ctcss_list = kenwood51_ctcss_list,
 
-    .str_cal = TS890_SM_CAL1,
     .swr_cal = TS890_SWR_CAL,
 
     .priv = (void *)& ts890s_priv_caps,
@@ -552,16 +661,20 @@ const struct rig_caps ts890s_caps =
     .rig_cleanup = kenwood_cleanup,
     .set_freq = kenwood_set_freq,
     .get_freq = kenwood_get_freq,
-    .set_rit = kenwood_set_rit,
-    .get_rit = kenwood_get_rit,
-    .set_xit = kenwood_set_xit,
-    .get_xit = kenwood_get_xit,
+    .set_rit = kenwood_set_rit_new,
+    .get_rit = kenwood_get_rit_new,
+    .set_xit = kenwood_set_rit_new,  // Same routines as for RIT
+    .get_xit = kenwood_get_rit_new,  // Same
     .set_mode = kenwood_set_mode,
     .get_mode = kenwood_get_mode,
     .set_vfo = kenwood_set_vfo,
     .get_vfo = kenwood_get_vfo_if,
     .set_split_vfo = kenwood_set_split_vfo,
-    .get_split_vfo = kenwood_get_split_vfo_if,
+    .get_split_vfo = ts890s_get_split_vfo,
+    .set_ctcss_tone = kenwood_set_ctcss_tone_tn,
+    .get_ctcss_tone = kenwood_get_ctcss_tone,
+    .set_ctcss_sql = kenwood_set_ctcss_sql,
+    .get_ctcss_sql = kenwood_get_ctcss_sql,
     .get_ptt = kenwood_get_ptt,
     .set_ptt = kenwood_set_ptt,
     .get_dcd = kenwood_get_dcd,
@@ -572,6 +685,9 @@ const struct rig_caps ts890s_caps =
     .set_ant = kenwood_set_ant,
     .get_ant = kenwood_get_ant,
     .send_morse =  kenwood_send_morse,
+    .stop_morse =  kenwood_stop_morse,
+    .send_voice_mem = kenwood_send_voice_mem,
+    .stop_voice_mem = kenwood_stop_voice_mem,
     .wait_morse =  rig_wait_morse,
     .scan = kenwood_scan,     /* not working, invalid arguments using rigctl; kenwood_scan does only support on/off and not tone and CTCSS scan */
     .has_set_level = TS890_LEVEL_SET,
@@ -580,11 +696,28 @@ const struct rig_caps ts890s_caps =
     .get_level = kenwood_ts890_get_level,
     .level_gran =
     {
+#define NO_LVL_ATT
+#define NO_LVL_CWPITCH
+#define NO_LVL_SQL
+#define NO_LVL_USB_AF
+#define NO_LVL_USB_AF_INPUT
 #include "level_gran_kenwood.h"
+#undef NO_LVL_ATT
+#undef NO_LVL_CWPITCH
+#undef NO_LVL_SQL
+#undef NO_LVL_USB_AF
+#undef NO_LVL_USB_AF_INPUT
+        [LVL_ATT]     = { .min = { .i = 0 }, .max = { .i = 18 }, .step = { .i = 6 } },
+        [LVL_CWPITCH] = { .min = { .i = 300 }, .max = { .i = 1100 }, .step = { .i = 5 } },
+        [LVL_SQL] = { .min = { .f = 0 }, .max = { .f = 1.0f }, .step = { .f = 1.0 / 255.0 } },
+        [LVL_USB_AF] = { .min = { .f = 0 }, .max = { .f = 1.0f }, .step = { .f = 1.0 / 100.0 } },
+        [LVL_USB_AF_INPUT] = { .min = { .f = 0 }, .max = { .f = 1.0f }, .step = { .f = 1.0 / 100.0 } },
     },
     .has_get_func = TS890_FUNC_ALL,
     .has_set_func = TS890_FUNC_ALL,
-    .set_func = kenwood_set_func,
-    .get_func = kenwood_get_func,
+    .set_func = ts890_set_func,
+    .get_func = ts890_get_func,
+    .get_clock = kenwood_get_clock,
+    .set_clock = kenwood_set_clock,
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
