@@ -20,9 +20,8 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
 
 #include <hamlib/rig.h>
@@ -95,6 +94,7 @@ tone_t tx500_dcs_list[] =
 static struct kenwood_priv_caps  tx500_priv_caps  =
 {
     .cmdtrm =  EOM_KEN,
+    .tone_table_base = 1,     /* TS-2000 compatible ??? */
 };
 
 /* memory capabilities */
@@ -122,7 +122,7 @@ static struct kenwood_priv_caps  tx500_priv_caps  =
  * TX-500 rig capabilities.
  *
  */
-const struct rig_caps tx500_caps =
+struct rig_caps tx500_caps =
 {
     RIG_MODEL(RIG_MODEL_LAB599_TX500),
     .model_name = "TX-500",
@@ -151,7 +151,9 @@ const struct rig_caps tx500_caps =
     .has_set_level =  RIG_LEVEL_SET(TX500_LEVEL_ALL),
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,    /* FIXME: parms */
-    .level_gran =  {},                 /* FIXME: granularity */
+    .level_gran =  {
+#include "level_gran_kenwood.h"
+    },                 /* FIXME: granularity */
     .parm_gran =  {},
     .vfo_ops =  TX500_VFO_OP,
     .scan_ops =  TX500_SCAN_OP,
@@ -852,7 +854,7 @@ int ts2000_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
         if (lvl > 9)
         {
-            val->i = rig->state.preamp[0];
+            val->i = STATE(rig)->preamp[0];
         }
 
         break;
@@ -883,7 +885,8 @@ int ts2000_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
         if (lvl > 99)
         {
-            val->i = rig->state.attenuator[0];    /* Since the TS-2000 only has one step on the attenuator */
+            val->i = STATE(
+                         rig)->attenuator[0];    /* Since the TS-2000 only has one step on the attenuator */
         }
 
         break;
