@@ -34,8 +34,6 @@
 #include "hamlib/rig.h"
 #include "token.h"
 
-#include "kit.h"
-
 /*
  * Compile this model only if libusb is available
  */
@@ -94,7 +92,7 @@ static int fifisdr_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode,
 static int fifisdr_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
 static int fifisdr_get_level(RIG *rig, vfo_t vfo, setting_t level,
                              value_t *val);
-static int fifisdr_get_ext_level(RIG *rig, vfo_t vfo, token_t token,
+static int fifisdr_get_ext_level(RIG *rig, vfo_t vfo, hamlib_token_t token,
                                  value_t *val);
 
 
@@ -124,7 +122,7 @@ struct fifisdr_priv_instance_data
 
 
 /** FiFi-SDR receiver description. */
-const struct rig_caps fifisdr_caps =
+struct rig_caps fifisdr_caps =
 {
     RIG_MODEL(RIG_MODEL_FIFISDR),
     .model_name = "FiFi-SDR",
@@ -278,12 +276,12 @@ static int fifisdr_usb_write(RIG *rig,
                              unsigned char *bytes, int size)
 {
     int ret;
-    libusb_device_handle *udh = rig->state.rigport.handle;
+    libusb_device_handle *udh = RIGPORT(rig)->handle;
 
     ret = libusb_control_transfer(udh,
                                   LIBUSB_REQUEST_TYPE_VENDOR | LIBUSB_RECIPIENT_DEVICE | LIBUSB_ENDPOINT_OUT,
                                   request, value, index,
-                                  bytes, size, rig->state.rigport.timeout);
+                                  bytes, size, RIGPORT(rig)->timeout);
 
     if (ret != size)
     {
@@ -305,12 +303,12 @@ static int fifisdr_usb_read(RIG *rig,
                             unsigned char *bytes, int size)
 {
     int ret;
-    libusb_device_handle *udh = rig->state.rigport.handle;
+    libusb_device_handle *udh = RIGPORT(rig)->handle;
 
     ret = libusb_control_transfer(udh,
                                   LIBUSB_REQUEST_TYPE_VENDOR | LIBUSB_RECIPIENT_DEVICE | LIBUSB_ENDPOINT_IN,
                                   request, value, index,
-                                  bytes, size, rig->state.rigport.timeout);
+                                  bytes, size, RIGPORT(rig)->timeout);
 
     if (ret != size)
     {
@@ -328,19 +326,19 @@ static int fifisdr_usb_read(RIG *rig,
 
 int fifisdr_init(RIG *rig)
 {
-    hamlib_port_t *rp = &rig->state.rigport;
+    hamlib_port_t *rp = RIGPORT(rig);
     struct fifisdr_priv_instance_data *priv;
 
-    rig->state.priv = (struct fifisdr_priv_instance_data *)calloc(sizeof(
-                          struct fifisdr_priv_instance_data), 1);
+    STATE(rig)->priv = (struct fifisdr_priv_instance_data *)calloc(sizeof(
+                           struct fifisdr_priv_instance_data), 1);
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         /* whoops! memory shortage! */
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     priv->multiplier = 4;
 
@@ -367,12 +365,12 @@ int fifisdr_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
@@ -386,7 +384,7 @@ int fifisdr_open(RIG *rig)
     struct fifisdr_priv_instance_data *priv;
 
 
-    priv = (struct fifisdr_priv_instance_data *)rig->state.priv;
+    priv = (struct fifisdr_priv_instance_data *)STATE(rig)->priv;
 
     /* The VCO is a multiple of the RX frequency. Typically 4 */
     ret = fifisdr_usb_read(rig, REQUEST_FIFISDR_READ, 0,
@@ -426,8 +424,9 @@ const char *fifisdr_get_info(RIG *rig)
 
 int fifisdr_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-    struct fifisdr_priv_instance_data *priv = (struct fifisdr_priv_instance_data *)
-            rig->state.priv;
+    const struct fifisdr_priv_instance_data *priv = (struct
+            fifisdr_priv_instance_data *)
+            STATE(rig)->priv;
     int ret;
     double mhz;
     uint32_t freq1121;
@@ -452,8 +451,9 @@ int fifisdr_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
 int fifisdr_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    struct fifisdr_priv_instance_data *priv = (struct fifisdr_priv_instance_data *)
-            rig->state.priv;
+    const struct fifisdr_priv_instance_data *priv = (struct
+            fifisdr_priv_instance_data *)
+            STATE(rig)->priv;
     int ret;
     uint32_t freq1121;
 
@@ -807,7 +807,7 @@ static int fifisdr_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
 
 
-static int fifisdr_get_ext_level(RIG *rig, vfo_t vfo, token_t token,
+static int fifisdr_get_ext_level(RIG *rig, vfo_t vfo, hamlib_token_t token,
                                  value_t *val)
 {
     int ret = RIG_OK;
