@@ -24,7 +24,6 @@
  * https://sites.google.com/site/rshfiqtransceiver/home/technical-data/interface-commands
  *
  */
-#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,21 +45,22 @@ static int rshfiq_open(RIG *rig)
     int flag;
     char versionstr[20];
     char stopset[2];
+    hamlib_port_t *rp = RIGPORT(rig);
     stopset[0] = '\r';
     stopset[1] = '\n';
 
     rig_debug(RIG_DEBUG_TRACE, "%s: Port = %s\n", __func__,
-              rig->state.rigport.pathname);
-    rig->state.rigport.timeout = 2000;
-    rig->state.rigport.retry = 1;
-    retval = serial_open(&rig->state.rigport);
+              rp->pathname);
+    rp->timeout = 2000;
+    rp->retry = 1;
+    retval = serial_open(rp);
 
     if (retval != RIG_OK)
     {
         return retval;
     }
 
-    retval = ser_get_dtr(&rig->state.rigport, &flag);
+    retval = ser_get_dtr(rp, &flag);
 
     if (retval == RIG_OK)
     {
@@ -74,7 +74,7 @@ static int rshfiq_open(RIG *rig)
     if (flag == 0)
     {
         flag = 1; // Set DTR
-        retval = ser_set_dtr(&rig->state.rigport, flag);
+        retval = ser_set_dtr(rp, flag);
 
         if (retval == RIG_OK)
         {
@@ -89,10 +89,10 @@ static int rshfiq_open(RIG *rig)
     for (int init_retry_count = 0; (init_retry_count < RSHFIQ_INIT_RETRY)
             && (retval == -RIG_ETIMEOUT); init_retry_count++)
     {
-        rig_flush(&rig->state.rigport);
+        rig_flush(rp);
         SNPRINTF(versionstr, sizeof(versionstr), "*w\r");
         rig_debug(RIG_DEBUG_TRACE, "%s: cmdstr = %s\n", __func__, versionstr);
-        retval = write_block(&rig->state.rigport, (unsigned char *) versionstr,
+        retval = write_block(rp, (unsigned char *) versionstr,
                              strlen(versionstr));
 
         if (retval != RIG_OK)
@@ -100,7 +100,7 @@ static int rshfiq_open(RIG *rig)
             return retval;
         }
 
-        retval = read_string(&rig->state.rigport, (unsigned char *) versionstr, 20,
+        retval = read_string(rp, (unsigned char *) versionstr, 20,
                              stopset, 2, 0, 1);
     }
 
@@ -109,7 +109,7 @@ static int rshfiq_open(RIG *rig)
         return retval;
     }
 
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
     versionstr[retval] = 0;
     rig_debug(RIG_DEBUG_TRACE, "%s: Rigversion = %s\n", __func__, versionstr);
@@ -151,16 +151,17 @@ static int rshfiq_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     char fstr[9];
     char cmdstr[15];
     int retval;
+    hamlib_port_t *rp = RIGPORT(rig);
 
     SNPRINTF(fstr, sizeof(fstr), "%lu", (unsigned long int)(freq));
     rig_debug(RIG_DEBUG_TRACE, "%s called: %s %s\n", __func__,
               rig_strvfo(vfo), fstr);
 
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
     SNPRINTF(cmdstr, sizeof(cmdstr), "*f%lu\r", (unsigned long int)(freq));
 
-    retval = write_block(&rig->state.rigport, (unsigned char *) cmdstr,
+    retval = write_block(rp, (unsigned char *) cmdstr,
                          strlen(cmdstr));
 
     if (retval != RIG_OK)
@@ -175,7 +176,9 @@ static int rshfiq_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
     char cmdstr[15];
     char stopset[2];
     int retval;
-    rig_flush(&rig->state.rigport);
+    hamlib_port_t *rp = RIGPORT(rig);
+
+    rig_flush(rp);
 
     stopset[0] = '\r';
     stopset[1] = '\n';
@@ -184,7 +187,7 @@ static int rshfiq_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: cmdstr = %s\n", __func__, cmdstr);
 
-    retval = write_block(&rig->state.rigport, (unsigned char *) cmdstr,
+    retval = write_block(rp, (unsigned char *) cmdstr,
                          strlen(cmdstr));
 
     if (retval != RIG_OK)
@@ -192,7 +195,7 @@ static int rshfiq_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
         return retval;
     }
 
-    retval = read_string(&rig->state.rigport, (unsigned char *) cmdstr, 9,
+    retval = read_string(rp, (unsigned char *) cmdstr, 9,
                          stopset, 2, 0, 1);
 
     if (retval <= 0)
@@ -234,19 +237,21 @@ static int rshfiq_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 
     rig_debug(RIG_DEBUG_TRACE, "%s: cmdstr = %s\n", __func__, cmdstr);
 
-    retval = write_block(&rig->state.rigport, (unsigned char *) cmdstr,
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmdstr,
                          strlen(cmdstr));
     return retval;
 }
 
 static int rshfiq_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
+    // cppcheck-suppress syntaxError
     rig_debug(RIG_DEBUG_VERBOSE, "%s called. level type =%"PRIll"\n", __func__,
               level);
 
     char cmdstr[15];
     char stopset[2];
     int retval;
+    hamlib_port_t *rp = RIGPORT(rig);
 
     if (!val)
     {
@@ -263,13 +268,13 @@ static int rshfiq_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
             return -RIG_ENAVAIL;
         }
 
-        rig_flush(&rig->state.rigport);
+        rig_flush(rp);
 
         SNPRINTF(cmdstr, sizeof(cmdstr), "*L\r");
 
         rig_debug(RIG_DEBUG_TRACE, "RIG_LEVEL_RFPOWER_METER command=%s\n", cmdstr);
 
-        retval = write_block(&rig->state.rigport, (unsigned char *) cmdstr,
+        retval = write_block(rp, (unsigned char *) cmdstr,
                              strlen(cmdstr));
 
         if (retval != RIG_OK)
@@ -280,7 +285,7 @@ static int rshfiq_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         stopset[0] = '\r';
         stopset[1] = '\n';
 
-        retval = read_string(&rig->state.rigport, (unsigned char *) cmdstr, 9,
+        retval = read_string(rp, (unsigned char *) cmdstr, 9,
                              stopset, 2, 0, 1);
 
         rig_debug(RIG_DEBUG_TRACE, "RIG_LEVEL_RFPOWER_METER reply=%s\n", cmdstr);
@@ -299,17 +304,16 @@ static int rshfiq_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         rig_debug(RIG_DEBUG_TRACE, "RIG_LEVEL_RFPOWER_METER val=%f\n", val->f);
 
         return RIG_OK;
-        break;
 
     case RIG_LEVEL_TEMP_METER:
 
-        rig_flush(&rig->state.rigport);
+        rig_flush(rp);
 
         SNPRINTF(cmdstr, sizeof(cmdstr), "*T\r");
 
         rig_debug(RIG_DEBUG_TRACE, "RIG_LEVEL_TEMP_METER command=%s\n", cmdstr);
 
-        retval = write_block(&rig->state.rigport, (unsigned char *) cmdstr,
+        retval = write_block(rp, (unsigned char *) cmdstr,
                              strlen(cmdstr));
 
         if (retval != RIG_OK)
@@ -320,7 +324,7 @@ static int rshfiq_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         stopset[0] = '\r';
         stopset[1] = '\n';
 
-        retval = read_string(&rig->state.rigport, (unsigned char *) cmdstr, 9,
+        retval = read_string(rp, (unsigned char *) cmdstr, 9,
                              stopset, 2, 0, 1);
 
         rig_debug(RIG_DEBUG_TRACE, "RIG_LEVEL_TEMP_METER reply=%s\n", cmdstr);
@@ -338,14 +342,11 @@ static int rshfiq_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         rig_debug(RIG_DEBUG_TRACE, "RIG_LEVEL_TEMP_METER val=%g\n", val->f);
 
         return RIG_OK;
-        break;
-        break;
 
     default:
         rig_debug(RIG_DEBUG_VERBOSE, "%s: Unrecognized RIG_LEVEL_* enum: %"PRIll"\n",
                   __func__, level);
         return -RIG_EDOM;
-        break;
     }
 }
 
@@ -356,7 +357,7 @@ static int rshfiq_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 }
 
 
-const struct rig_caps rshfiq_caps =
+struct rig_caps rshfiq_caps =
 {
     RIG_MODEL(RIG_MODEL_RSHFIQ),
     .model_name =     "RS-HFIQ",
