@@ -45,8 +45,9 @@ struct usrp_priv_data {
 
 int usrp_init(RIG *rig)
 {
-	rig->state.priv = (struct usrp_priv_data*)malloc(sizeof(struct usrp_priv_data));
-	if (!rig->state.priv) {
+    // cppcheck-suppress leakReturnValNotUsed
+	STATE(rig)->priv = static_cast<struct usrp_priv_data*>malloc(sizeof(struct usrp_priv_data));
+	if (!STATE(rig)->priv) {
 		/* whoops! memory shortage! */
 		return -RIG_ENOMEM;
 	}
@@ -59,16 +60,16 @@ int usrp_cleanup(RIG *rig)
 	if (!rig)
 		return -RIG_EINVAL;
 
-	if (rig->state.priv)
-		free(rig->state.priv);
-	rig->state.priv = NULL;
+	if (STATE(rig)->priv)
+		free(STATE(rig)->priv);
+	STATE(rig)->priv = NULL;
 
 	return RIG_OK;
 }
 
 int usrp_open(RIG *rig)
 {
-	struct usrp_priv_data *priv = (struct usrp_priv_data*)rig->state.priv;
+	struct usrp_priv_data *priv = static_cast<struct usrp_priv_data*>STATE(rig)->priv;
 
 	int which_board = 0;
 	int decim = 125;
@@ -82,7 +83,13 @@ int usrp_open(RIG *rig)
 
 int usrp_close(RIG *rig)
 {
-	struct usrp_priv_data *priv = (struct usrp_priv_data*)rig->state.priv;
+	struct usrp_priv_data *priv = static_cast<struct usrp_priv_data*>STATE(rig)->priv;
+
+    if (!priv)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: priv == NULL?\n", __func__);
+        return -RIG_EARG;
+    }
 
 	delete priv->urx;
 
@@ -90,11 +97,17 @@ int usrp_close(RIG *rig)
 }
 
 /*
- * Assumes rig!=NULL, rig->state.priv!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL
  */
-int usrp_set_conf(RIG *rig, token_t token, const char *val)
+int usrp_set_conf(RIG *rig, hamlib_token_t token, const char *val)
 {
-	struct usrp_priv_data *priv = (struct usrp_priv_data*)rig->state.priv;
+	struct usrp_priv_data *priv = static_cast<struct usrp_priv_data*>STATE(rig)->priv;
+
+    if (!priv)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: priv == NULL?\n", __func__);
+        return -RIG_EARG;
+    }
 
 	switch(token) {
 		case TOK_IFMIXFREQ:
@@ -108,12 +121,18 @@ int usrp_set_conf(RIG *rig, token_t token, const char *val)
 
 /*
  * assumes rig!=NULL,
- * Assumes rig!=NULL, rig->state.priv!=NULL
+ * Assumes rig!=NULL, STATE(rig)->priv!=NULL
  *  and val points to a buffer big enough to hold the conf value.
  */
-int usrp_get_conf(RIG *rig, token_t token, char *val)
+int usrp_get_conf(RIG *rig, hamlib_token_t token, char *val)
 {
-	struct usrp_priv_data *priv = (struct usrp_priv_data*)rig->state.priv;
+	const struct usrp_priv_data *priv = static_cast<struct usrp_priv_data*>STATE(rig)->priv;
+
+    if (!priv)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: priv == NULL?\n", __func__);
+        return -RIG_EARG;
+    }
 
 	switch(token) {
 		case TOK_IFMIXFREQ:
@@ -129,9 +148,15 @@ int usrp_get_conf(RIG *rig, token_t token, char *val)
 
 int usrp_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-	struct usrp_priv_data *priv = (struct usrp_priv_data*)rig->state.priv;
+	const struct usrp_priv_data *priv = static_cast<struct usrp_priv_data*>STATE(rig)->priv;
 	int chan = 0;
 
+    if (!priv)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: priv == NULL?\n", __func__);
+        return -RIG_EARG;
+    }
+
 	if (!priv->urx->set_rx_freq (chan, freq))
 		return -RIG_EPROTO;
 
@@ -141,9 +166,15 @@ int usrp_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
 int usrp_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-	struct usrp_priv_data *priv = (struct usrp_priv_data*)rig->state.priv;
+	const struct usrp_priv_data *priv = static_cast<struct usrp_priv_data*>STATE(rig)->priv;
 	int chan = 0;
 
+    if (!priv)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: priv == NULL?\n", __func__);
+        return -RIG_EARG;
+    }
+
 	*freq = priv->urx->rx_freq (chan);
 
 	return RIG_OK;
