@@ -19,8 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include <hamlib/rig.h>
@@ -45,14 +43,14 @@
  *
  */
 
-const struct rig_caps hf235_caps =
+struct rig_caps hf235_caps =
 {
     RIG_MODEL(RIG_MODEL_HF235),
     .model_name = "HF-235",
     .mfg_name =  "Lowe",
     .version =  BACKEND_VER ".0",
     .copyright =  "LGPL",
-    .status =  RIG_STATUS_BETA,        /* and only basic support */
+    .status =  RIG_STATUS_STABLE,        /* and only basic support */
     .rig_type =  RIG_TYPE_RECEIVER,
     .ptt_type =  RIG_PTT_NONE,
     .dcd_type =  RIG_DCD_NONE,
