@@ -19,16 +19,14 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
 #include <ctype.h>
 
 #include "hamlib/rig.h"
+#include "misc.h"
 #include "serial.h"
-#include "cal.h"
 #include "register.h"
 #include "idx_builtin.h"
 
@@ -142,7 +140,7 @@ MessageAide:  DB   "H",0Dh,0Ah
 
 static void prm80_force_cache_timeout(RIG *rig)
 {
-    struct prm80_priv_data *priv = (struct prm80_priv_data *)rig->state.priv;
+    struct prm80_priv_data *priv = (struct prm80_priv_data *)STATE(rig)->priv;
 
     rig_force_cache_timeout(&priv->status_tv);
 }
@@ -155,7 +153,6 @@ static int read_prompt_and_send(hamlib_port_t *rigport,
                                 int space_after_delim)
 {
     char buf[BUFSZ];
-    char spacebuf[4];
     int buflen, retval;
 
     /* no data wanted? flush it anyway by reading it */
@@ -185,6 +182,7 @@ static int read_prompt_and_send(hamlib_port_t *rigport,
     // Read one (dummy) space character after the colon
     if (space_after_delim)
     {
+        char spacebuf[4];
         retval = read_block(rigport, (unsigned char *) spacebuf, 1);
 
         if (retval < 0 && retval != -RIG_ETIMEOUT)
@@ -247,13 +245,13 @@ static int prm80_transaction(RIG *rig, const char *cmd,
                              const char *arg1, int wait_prompt)
 {
     int retval;
-    struct rig_state *rs = &rig->state;
+    hamlib_port_t *rp = RIGPORT(rig);
 
     // Get rid of possible prompt sent by the rig
-    rig_flush(&rs->rigport);
+    rig_flush(rp);
 
     // Start with the command
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, strlen(cmd));
+    retval = write_block(rp, (unsigned char *) cmd, strlen(cmd));
 
     if (retval != RIG_OK)
     {
@@ -262,7 +260,7 @@ static int prm80_transaction(RIG *rig, const char *cmd,
 
     if (arg1 != NULL)
     {
-        retval = read_colon_prompt_and_send(&rs->rigport, NULL, NULL, arg1);
+        retval = read_colon_prompt_and_send(rp, NULL, NULL, arg1);
 
         if (retval < 0)
         {
@@ -272,7 +270,7 @@ static int prm80_transaction(RIG *rig, const char *cmd,
 
     if (wait_prompt)
     {
-        prm80_wait_for_prompt(&rs->rigport);
+        prm80_wait_for_prompt(rp);
     }
 
     return RIG_OK;
@@ -285,9 +283,9 @@ int prm80_init(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    rig->state.priv = (void *)calloc(1, sizeof(struct prm80_priv_data));
+    STATE(rig)->priv = (void *)calloc(1, sizeof(struct prm80_priv_data));
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         /* whoops! memory shortage! */
         return -RIG_ENOMEM;
@@ -303,8 +301,8 @@ int prm80_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    free(rig->state.priv);
-    rig->state.priv = NULL;
+    free(STATE(rig)->priv);
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
@@ -376,7 +374,7 @@ static freq_t pll_value_to_rx_freq(unsigned pll_value)
  */
 int prm80_set_rx_tx_freq(RIG *rig, freq_t rx_freq, freq_t tx_freq)
 {
-    struct rig_state *rs = &rig->state;
+    hamlib_port_t *rp = RIGPORT(rig);
     char rx_freq_buf[BUFSZ];
     char tx_freq_buf[BUFSZ];
     int rc;
@@ -399,7 +397,7 @@ int prm80_set_rx_tx_freq(RIG *rig, freq_t rx_freq, freq_t tx_freq)
     }
 
     // There's a second line to process after prm80_transaction()
-    rc = read_colon_prompt_and_send(&rs->rigport, NULL, NULL, tx_freq_buf);
+    rc = read_colon_prompt_and_send(rp, NULL, NULL, tx_freq_buf);
 
     if (rc != RIG_OK)
     {
@@ -410,7 +408,7 @@ int prm80_set_rx_tx_freq(RIG *rig, freq_t rx_freq, freq_t tx_freq)
 
     // NB: the [R] command does not update the checksum of the RAM!
 
-    prm80_wait_for_prompt(&rs->rigport);
+    prm80_wait_for_prompt(rp);
 
     return rc;
 }
@@ -420,7 +418,7 @@ int prm80_set_rx_tx_freq(RIG *rig, freq_t rx_freq, freq_t tx_freq)
  */
 int prm80_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-    struct prm80_priv_data *priv = (struct prm80_priv_data *)rig->state.priv;
+    struct prm80_priv_data *priv = (struct prm80_priv_data *)STATE(rig)->priv;
     freq_t tx_freq;
     int rc;
 
@@ -450,7 +448,7 @@ int prm80_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
  */
 int prm80_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
 {
-    struct prm80_priv_data *priv = (struct prm80_priv_data *)rig->state.priv;
+    struct prm80_priv_data *priv = (struct prm80_priv_data *)STATE(rig)->priv;
     freq_t rx_freq;
     int rc;
 
@@ -473,7 +471,7 @@ int prm80_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
  */
 int prm80_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    struct prm80_priv_data *priv = (struct prm80_priv_data *)rig->state.priv;
+    struct prm80_priv_data *priv = (struct prm80_priv_data *)STATE(rig)->priv;
     int ret;
     channel_t chan;
 
@@ -500,7 +498,7 @@ int prm80_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
  */
 int prm80_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
 {
-    struct prm80_priv_data *priv = (struct prm80_priv_data *)rig->state.priv;
+    struct prm80_priv_data *priv = (struct prm80_priv_data *)STATE(rig)->priv;
 
     priv->split = split;
 
@@ -512,7 +510,7 @@ int prm80_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
  */
 int prm80_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 {
-    struct prm80_priv_data *priv = (struct prm80_priv_data *)rig->state.priv;
+    const struct prm80_priv_data *priv = (struct prm80_priv_data *)STATE(rig)->priv;
 
     *split = priv->split;
     *tx_vfo = RIG_VFO_CURR;
@@ -525,7 +523,7 @@ int prm80_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
  */
 int prm80_get_split_freq(RIG *rig, vfo_t vfo, freq_t *tx_freq)
 {
-    struct prm80_priv_data *priv = (struct prm80_priv_data *)rig->state.priv;
+    struct prm80_priv_data *priv = (struct prm80_priv_data *)STATE(rig)->priv;
     int ret;
     channel_t chan;
 
@@ -654,10 +652,7 @@ static int prm80_do_read_system_state(hamlib_port_t *rigport, char *statebuf)
         return ret;
     }
 
-    if (ret >= 0)
-    {
-        statebuf[ret] = '\0';
-    }
+    statebuf[ret] = '\0';
 
     if (ret < CMD_E_RSP_LEN)
     {
@@ -699,12 +694,12 @@ static int prm80_do_read_system_state(hamlib_port_t *rigport, char *statebuf)
  */
 static int prm80_read_system_state(RIG *rig, char *statebuf)
 {
-    struct prm80_priv_data *priv = (struct prm80_priv_data *)rig->state.priv;
+    struct prm80_priv_data *priv = (struct prm80_priv_data *)STATE(rig)->priv;
     int ret = RIG_OK;
 
     if (rig_check_cache_timeout(&priv->status_tv, PRM80_CACHE_TIMEOUT))
     {
-        ret = prm80_do_read_system_state(&rig->state.rigport, statebuf);
+        ret = prm80_do_read_system_state(RIGPORT(rig), statebuf);
 
         if (ret == RIG_OK)
         {
@@ -728,7 +723,7 @@ static int prm80_read_system_state(RIG *rig, char *statebuf)
  */
 int prm80_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
 {
-    struct prm80_priv_data *priv = (struct prm80_priv_data *)rig->state.priv;
+    const struct prm80_priv_data *priv = (struct prm80_priv_data *)STATE(rig)->priv;
     char statebuf[BUFSZ];
     int ret, chanstate, mode_byte, lock_byte;
 
@@ -826,8 +821,8 @@ int prm80_get_channel(RIG *rig, vfo_t vfo, channel_t *chan, int read_only)
  */
 int prm80_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
 {
-    struct prm80_priv_data *priv = (struct prm80_priv_data *)rig->state.priv;
-    struct rig_state *rs = &rig->state;
+    struct prm80_priv_data *priv = (struct prm80_priv_data *)STATE(rig)->priv;
+    hamlib_port_t *rp = RIGPORT(rig);
     char buf[BUFSZ];
     int ret, chanstate;
     freq_t tx_freq;
@@ -864,7 +859,7 @@ int prm80_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
         SNPRINTF(buf, sizeof(buf), "%04X", rx_freq_to_pll_value(chan->freq));
 
         // "PLL value to load : $"
-        ret = read_dollar_prompt_and_send(&rs->rigport, NULL, NULL, buf);
+        ret = read_dollar_prompt_and_send(rp, NULL, NULL, buf);
 
         if (ret != RIG_OK)
         {
@@ -888,7 +883,7 @@ int prm80_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
         SNPRINTF(buf, sizeof(buf), "%02X", chanstate);
 
         // "Channel state : $"
-        ret = read_dollar_prompt_and_send(&rs->rigport, NULL, NULL, buf);
+        ret = read_dollar_prompt_and_send(rp, NULL, NULL, buf);
 
         if (ret != RIG_OK)
         {
@@ -898,42 +893,42 @@ int prm80_set_channel(RIG *rig, vfo_t vfo, const channel_t *chan)
         // Determine if prompt came back (CRLF'>') or have to
         // handle the possible query from the rig:
         // "This channel number doesn't exist. Add new channel (Y/N) ? "
-        ret = read_block(&rs->rigport, (unsigned char *) buf, 3);
+        ret = read_block(rp, (unsigned char *) buf, 3);
 
         if (ret < 0)
         {
-            RETURNFUNC(ret);
+            return ret;
         }
 
         if (ret == 3 && buf[2] == 'T')
         {
             // Read the question
-            ret = read_string(&rs->rigport, (unsigned char *) buf, sizeof(buf), "?", 1, 0,
+            ret = read_string(rp, (unsigned char *) buf, sizeof(buf), "?", 1, 0,
                               1);
 
             if (ret < 0)
             {
-                RETURNFUNC(ret);
+                return ret;
             }
 
             // Read extra space
-            ret = read_block(&rs->rigport, (unsigned char *) buf, 1);
+            ret = read_block(rp, (unsigned char *) buf, 1);
 
             if (ret < 0)
             {
-                RETURNFUNC(ret);
+                return ret;
             }
 
             // Send confirmation
-            ret = write_block(&rs->rigport, (unsigned char *) "Y", 1);
+            ret = write_block(rp, (unsigned char *) "Y", 1);
 
             if (ret < 0)
             {
-                RETURNFUNC(ret);
+                return ret;
             }
         }
 
-        prm80_wait_for_prompt(&rs->rigport);
+        prm80_wait_for_prompt(rp);
     }
     else
     {
@@ -1108,10 +1103,12 @@ int prm80_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 /*
  * get_level RIG_LEVEL_RAWSTR
  */
+// cppcheck-suppress unusedFunction
 static int prm80_get_rawstr_RAM(RIG *rig, value_t *val)
 {
     char buf[BUFSZ];
-    struct rig_state *rs = &rig->state;
+    struct rig_state *rs = STATE(rig);
+    hamlib_port_t *rp = RIGPORT(rig);
     int ret, i;
 
     /* [U] = Print 80c552 internal RAM. */
@@ -1125,7 +1122,7 @@ static int prm80_get_rawstr_RAM(RIG *rig, value_t *val)
     }
 
     // Read CRLF
-    ret = read_string(&rs->rigport, buf, BUFSZ, "\n", 1, 0, 1);
+    ret = read_string(rp, buf, BUFSZ, "\n", 1, 0, 1);
 
     if (ret < 0)
     {
@@ -1141,7 +1138,7 @@ static int prm80_get_rawstr_RAM(RIG *rig, value_t *val)
 
     for (i = 0; i < (RSSI_HOLD_ADDR / 16) + 1; i++)
     {
-        ret = read_string(&rs->rigport, buf, BUFSZ, "\n", 1, 0, 1);
+        ret = read_string(rp, buf, BUFSZ, "\n", 1, 0, 1);
 
         if (ret < 0)
         {
@@ -1157,10 +1154,10 @@ static int prm80_get_rawstr_RAM(RIG *rig, value_t *val)
     // discard the remaining content of RAM print
     for (i = 0; i < (16 - RSSI_HOLD_ADDR / 16) - 1; i++)
     {
-        read_string(&rs->rigport, buf, BUFSZ, "\n", 1, 0, 1);
+        read_string(rp, buf, BUFSZ, "\n", 1, 0, 1);
     }
 
-    prm80_wait_for_prompt(&rs->rigport);
+    prm80_wait_for_prompt(rp);
 
     return RIG_OK;
 }
@@ -1265,22 +1262,22 @@ int prm80_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 const char *prm80_get_info(RIG *rig)
 {
     static char s_buf[BUFSZ];
-    struct rig_state *rs = &rig->state;
+    hamlib_port_t *rp = RIGPORT(rig);
     char *p;
     int ret;
 
     // Get rid of possible prompt sent by the rig
-    rig_flush(&rs->rigport);
+    rig_flush(rp);
 
     /* [V] = Print firmware version. */
-    ret = write_block(&rs->rigport, (unsigned char *) "V", 1);
+    ret = write_block(rp, (unsigned char *) "V", 1);
 
     if (ret < 0)
     {
         return NULL;
     }
 
-    ret = read_string(&rs->rigport, (unsigned char *) s_buf, BUFSZ, ">", 1, 0, 1);
+    ret = read_string(rp, (unsigned char *) s_buf, BUFSZ, ">", 1, 0, 1);
 
     if (ret < 0)
     {
