@@ -25,8 +25,8 @@
  * Looks like the GP2000 could be reused in other rigs so
  * we implement that and then the XK2100 uses this interface
  */
-#include <hamlib/config.h>
 
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>     /* String function definitions */
@@ -34,7 +34,6 @@
 #include "hamlib/rig.h"
 #include "serial.h"
 #include "misc.h"
-#include "register.h"
 #include "num_stdio.h"
 
 #include "gp2000.h"
@@ -53,25 +52,23 @@
 
 /*
  * gp2000
- * We assume that rig!=NULL, rig->state!= NULL, data!=NULL, data_len!=NULL
+ * We assume that rig!=NULL, STATE(rig)!= NULL, data!=NULL, data_len!=NULL
  */
 int
 gp2000_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
                    int *data_len)
 {
     int retval;
-    struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: len=%d,cmd=%s\n", __func__, cmd_len,
               cmd);
 
-    rs = &rig->state;
-
-    rig_flush(&rs->rigport);
+    rig_flush(rp);
 
     rig_debug(RIG_DEBUG_VERBOSE, "gp2000_transaction: len=%d,cmd=%s\n",
               cmd_len, cmd);
-    retval = write_block(&rs->rigport, (unsigned char *) cmd, cmd_len);
+    retval = write_block(rp, (unsigned char *) cmd, cmd_len);
 
     if (retval != RIG_OK)
     {
@@ -85,7 +82,7 @@ gp2000_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
         return RIG_OK;
     }
 
-    retval = read_string(&rs->rigport, (unsigned char *) data, RESPSZ,
+    retval = read_string(rp, (unsigned char *) data, RESPSZ,
                          CR, 1, 0, 1);
 
     if (retval < 0)
