@@ -19,13 +19,10 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 
 #include <hamlib/rig.h>
 #include "idx_builtin.h"
-#include "tentec.h"
 #include "tt550.h"
 
 
@@ -63,7 +60,7 @@
  *
  * TODO:
  */
-const struct rig_caps tt550_caps =
+struct rig_caps tt550_caps =
 {
     RIG_MODEL(RIG_MODEL_TT550),
     .model_name = "TT-550",
@@ -93,7 +90,6 @@ const struct rig_caps tt550_caps =
     .has_get_parm = RIG_PARM_NONE,
     .has_set_parm = RIG_PARM_NONE,
     .level_gran = {
-        // cppcheck-suppress *
         [LVL_RAWSTR] = {.min = {.i = 0}, .max = {.i = 65535}},
     },
     .parm_gran = {},
