@@ -19,17 +19,13 @@
  *
  */
 
-#include <hamlib/config.h>
-
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
 #include "hamlib/rig.h"
-#include "bandplan.h"
 #include "serial.h"
-#include "misc.h"
 #include "num_stdio.h"
-#include "token.h"
 
 #include "rx331.h"
 
@@ -71,8 +67,8 @@ static const struct confparams rx331_cfg_params[] =
 
 static int rx331_init(RIG *rig);
 static int rx331_cleanup(RIG *rig);
-static int rx331_set_conf(RIG *rig, token_t token, const char *val);
-static int rx331_get_conf(RIG *rig, token_t token, char *val);
+static int rx331_set_conf(RIG *rig, hamlib_token_t token, const char *val);
+static int rx331_get_conf(RIG *rig, hamlib_token_t token, char *val);
 static int rx331_open(RIG *rig);
 static int rx331_close(RIG *rig);
 static int rx331_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
@@ -92,7 +88,7 @@ static const char *rx331_get_info(RIG *rig);
  *
  * TODO: from/to memory
  */
-const struct rig_caps rx331_caps =
+struct rig_caps rx331_caps =
 {
     RIG_MODEL(RIG_MODEL_RX331),
     .model_name = "RX-331",
@@ -236,7 +232,7 @@ const struct rig_caps rx331_caps =
 /*
  * rx331_transaction
  * read exactly data_len bytes
- * We assume that rig!=NULL, rig->state!= NULL, data!=NULL, data_len!=NULL
+ * We assume that rig!=NULL, STATE(rig)!= NULL, data!=NULL, data_len!=NULL
  * Otherwise, you'll get a nice seg fault. You've been warned!
  */
 static int rx331_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
@@ -246,15 +242,13 @@ static int rx331_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
     int retval;
     char str[BUFSZ];
     char fmt[16];
-    struct rig_state *rs;
-    struct rx331_priv_data *priv = (struct rx331_priv_data *)rig->state.priv;
+    hamlib_port_t *rp = RIGPORT(rig);
+    const struct rx331_priv_data *priv = (struct rx331_priv_data *)STATE(rig)->priv;
 
-    rs = &rig->state;
-
-    rig_flush(&rs->rigport);
+    rig_flush(rp);
 
     num_snprintf(str, BUFSZ, "$%u%s", priv->receiver_id, cmd);
-    retval = write_block(&rs->rigport, (unsigned char *) str, strlen(str));
+    retval = write_block(rp, (unsigned char *) str, strlen(str));
 
     if (retval != RIG_OK)
     {
@@ -267,7 +261,7 @@ static int rx331_transaction(RIG *rig, const char *cmd, int cmd_len, char *data,
         return RIG_OK;
     }
 
-    retval = read_string(&rs->rigport, (unsigned char *) data, BUFSZ, EOM, 1, 0, 1);
+    retval = read_string(rp, (unsigned char *) data, BUFSZ, EOM, 1, 0, 1);
 
     if (retval < 0)
     {
@@ -295,16 +289,16 @@ int rx331_init(RIG *rig)
 {
     struct rx331_priv_data *priv;
 
-    rig->state.priv = (struct rx331_priv_data *)calloc(1, sizeof(
-                          struct rx331_priv_data));
+    STATE(rig)->priv = (struct rx331_priv_data *)calloc(1, sizeof(
+                           struct rx331_priv_data));
 
-    if (!rig->state.priv)
+    if (!STATE(rig)->priv)
     {
         /* whoops! memory shortage! */
         return -RIG_ENOMEM;
     }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     memset(priv, 0, sizeof(struct rx331_priv_data));
 
@@ -317,19 +311,19 @@ int rx331_init(RIG *rig)
  */
 int rx331_cleanup(RIG *rig)
 {
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
 
-int rx331_set_conf(RIG *rig, token_t token, const char *val)
+int rx331_set_conf(RIG *rig, hamlib_token_t token, const char *val)
 {
-    struct rx331_priv_data *priv = (struct rx331_priv_data *)rig->state.priv;
+    struct rx331_priv_data *priv = (struct rx331_priv_data *)STATE(rig)->priv;
 
     switch (token)
     {
@@ -344,9 +338,9 @@ int rx331_set_conf(RIG *rig, token_t token, const char *val)
     return RIG_OK;
 }
 
-int rx331_get_conf2(RIG *rig, token_t token, char *val, int val_len)
+int rx331_get_conf2(RIG *rig, hamlib_token_t token, char *val, int val_len)
 {
-    struct rx331_priv_data *priv = (struct rx331_priv_data *)rig->state.priv;
+    const struct rx331_priv_data *priv = (struct rx331_priv_data *)STATE(rig)->priv;
 
     switch (token)
     {
@@ -361,11 +355,12 @@ int rx331_get_conf2(RIG *rig, token_t token, char *val, int val_len)
     return RIG_OK;
 }
 
-int rx331_get_conf(RIG *rig, token_t token, char *val)
+int rx331_get_conf(RIG *rig, hamlib_token_t token, char *val)
 {
     return rx331_get_conf2(rig, token, val, 128);
 }
 
+// cppcheck-suppress constParameterCallback
 int rx331_open(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -381,6 +376,7 @@ int rx331_open(RIG *rig)
 /*
  * rig_close
  */
+// cppcheck-suppress constParameterCallback
 int rx331_close(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -395,16 +391,15 @@ int rx331_close(RIG *rig)
 
 int rx331_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-    struct rx331_priv_data *priv = (struct rx331_priv_data *)rig->state.priv;
+    const struct rx331_priv_data *priv = (struct rx331_priv_data *)STATE(rig)->priv;
 
-    struct rig_state *rs = &rig->state;
     int freq_len, retval;
     char freqbuf[16];
 
     freq_len = num_snprintf(freqbuf, sizeof(freqbuf), "$%uF%.6f" EOM,
                             priv->receiver_id, freq / 1e6);
 
-    retval = write_block(&rs->rigport, (unsigned char *) freqbuf, freq_len);
+    retval = write_block(RIGPORT(rig), (unsigned char *) freqbuf, freq_len);
 
     return retval;
 }
@@ -444,8 +439,7 @@ int rx331_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
  */
 int rx331_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
-    struct rx331_priv_data *priv = (struct rx331_priv_data *)rig->state.priv;
-    struct rig_state *rs = &rig->state;
+    const struct rx331_priv_data *priv = (struct rx331_priv_data *)STATE(rig)->priv;
     char dmode;
     int mdbuf_len, retval;
     char mdbuf[32];
@@ -496,7 +490,7 @@ int rx331_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
                                  dmode);
     }
 
-    retval = write_block(&rs->rigport, (unsigned char *) mdbuf, mdbuf_len);
+    retval = write_block(RIGPORT(rig), (unsigned char *) mdbuf, mdbuf_len);
 
     return retval;
 }
@@ -566,8 +560,7 @@ int rx331_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
  */
 int rx331_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
-    struct rx331_priv_data *priv = (struct rx331_priv_data *)rig->state.priv;
-    struct rig_state *rs = &rig->state;
+    const struct rx331_priv_data *priv = (struct rx331_priv_data *)STATE(rig)->priv;
     int retval = RIG_OK;
     char cmdbuf[32];
 
@@ -639,7 +632,7 @@ int rx331_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         return -RIG_EINVAL;
     }
 
-    retval = write_block(&rs->rigport, (unsigned char *) cmdbuf, strlen(cmdbuf));
+    retval = write_block(RIGPORT(rig), (unsigned char *) cmdbuf, strlen(cmdbuf));
     return retval;
 }
 
