@@ -19,14 +19,12 @@
  *
  */
 
-#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <string.h>  /* String function definitions */
 
 #include "hamlib/rig.h"
 #include "serial.h"
-#include "misc.h"
 
 #include "uniden_digital.h"
 
@@ -48,7 +46,7 @@
  * use the address returned from one of the commands.  If you decide
  * the latter method, the order is slightly confusing but, I have it
  * well documented within DSctl.  The latter method is also as much
- * as 30% faster then using the Uniden software or "Get Next
+ * as 30% faster than using the Uniden software or "Get Next
  * Location" command.
  */
 
@@ -74,7 +72,7 @@ uniden_id_string_list[] =
 /**
  * uniden_transaction
  * uniden_digital_transaction
- * Assumes rig!=NULL rig->state!=NULL rig->caps!=NULL
+ * Assumes rig!=NULL STATE(rig)!=NULL rig->caps!=NULL
  *
  * cmdstr - Command to be sent to the rig. Cmdstr can also be NULL, indicating
  *          that only a reply is needed (nothing will be send).
@@ -99,21 +97,22 @@ uniden_digital_transaction(RIG *rig, const char *cmdstr, int cmd_len,
                            char *data, size_t *datasize)
 {
     struct rig_state *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
     int retval;
     int retry_read = 0;
     char replybuf[BUFSZ];
     size_t reply_len = BUFSZ;
 
-    rs = &rig->state;
+    rs = STATE(rig);
     rs->transaction_active = 1;
 
 transaction_write:
 
-    rig_flush(&rs->rigport);
+    rig_flush(rp);
 
     if (cmdstr)
     {
-        retval = write_block(&rs->rigport, (unsigned char *) cmdstr, strlen(cmdstr));
+        retval = write_block(rp, (unsigned char *) cmdstr, strlen(cmdstr));
 
         if (retval != RIG_OK)
         {
@@ -133,12 +132,12 @@ transaction_write:
     }
 
     memset(data, 0, *datasize);
-    retval = read_string(&rs->rigport, (unsigned char *) data, *datasize, EOM,
+    retval = read_string(rp, (unsigned char *) data, *datasize, EOM,
                          strlen(EOM), 0, 1);
 
     if (retval < 0)
     {
-        if (retry_read++ < rig->state.rigport.retry)
+        if (retry_read++ < rp->retry)
         {
             goto transaction_write;
         }
@@ -156,7 +155,7 @@ transaction_write:
      * ie: STS command will not return either "\r" or "\n"! */
     /*if (strchr(EOM, data[strlen(data)-1])==NULL) {
         rig_debug(RIG_DEBUG_ERR, "%s: Command is not correctly terminated '%s'\n", __func__, data);
-        if (retry_read++ < rig->state.rigport.retry)
+        if (retry_read++ < rp->retry)
             goto transaction_write;
         retval = -RIG_EPROTO;
         goto transaction_quit;
@@ -247,7 +246,7 @@ transaction_write:
          */
         rig_debug(RIG_DEBUG_ERR, "%s: Unexpected reply '%s'\n", __func__, data);
 
-        if (retry_read++ < rig->state.rigport.retry)
+        if (retry_read++ < rp->retry)
         {
             goto transaction_write;
         }
@@ -295,7 +294,7 @@ const char *uniden_digital_get_info(RIG *rig)
      * STS command returns 3 lines including system, truck, freq info
      *
      * XXX indicates the BCD996T returns some non-printable ascii chars
-     * within it's comma separated fields. See pg 30-32 of BCD996T_Protocol.pdf.
+     * within its comma separated fields. See pg 30-32 of BCD996T_Protocol.pdf.
      * These chars cause abnomalies on stdout! */
 
     /* FIXME: Strip or replace non-printable chars return from STS command!
