@@ -44,8 +44,6 @@
  * - the many "fixme" stuff around
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>     /* String function definitions */
 #include <stdbool.h>
@@ -102,6 +100,7 @@ enum ft817_native_cmd_e
     FT817_NATIVE_CAT_PWR_ON,
     FT817_NATIVE_CAT_PWR_OFF,
     FT817_NATIVE_CAT_EEPROM_READ,
+    FT817_NATIVE_CAT_EEPROM_WRITE,
     FT817_NATIVE_CAT_GET_TX_METERING,
     FT817_NATIVE_SIZE       /* end marker */
 };
@@ -129,6 +128,7 @@ struct ft817_priv_data
     /* Digi mode is not part of regular fm_status response.
      * So keep track of it in a separate variable. */
     unsigned char dig_mode;
+    float swr;
 };
 
 static int ft817_init(RIG *rig);
@@ -211,6 +211,7 @@ static const yaesu_cmd_set_t ncmd[] =
     { 1, { 0x00, 0x00, 0x00, 0x00, 0x0f } }, /* pwr on */
     { 1, { 0x00, 0x00, 0x00, 0x00, 0x8f } }, /* pwr off */
     { 0, { 0x00, 0x00, 0x00, 0x00, 0xbb } }, /* eeprom read */
+    { 0, { 0x00, 0x00, 0x00, 0x00, 0xbc } }, /* eeprom write */
     { 1, { 0x00, 0x00, 0x00, 0x00, 0xbd } }, /* get TX metering levels (PWR, SWR, MOD, ALC) */
 };
 
@@ -224,13 +225,13 @@ enum ft817_digi
 };
 
 #define FT817_ALL_RX_MODES      (RIG_MODE_AM|RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_PKTFM|\
-                                 RIG_MODE_USB|RIG_MODE_LSB|RIG_MODE_RTTY|RIG_MODE_FM|RIG_MODE_PKTUSB)
+                                 RIG_MODE_USB|RIG_MODE_LSB|RIG_MODE_RTTY|RIG_MODE_FM|RIG_MODE_PKTUSB|RIG_MODE_PKTLSB|RIG_MODE_PSK|RIG_MODE_PSKR)
 #define FT817_SSB_CW_RX_MODES   (RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_USB|RIG_MODE_LSB|RIG_MODE_RTTY)
 #define FT817_CWN_RX_MODES      (RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_RTTY)
 #define FT817_AM_FM_RX_MODES    (RIG_MODE_AM|RIG_MODE_FM|RIG_MODE_PKTFM)
 
 #define FT817_OTHER_TX_MODES    (RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_USB|\
-                                 RIG_MODE_LSB|RIG_MODE_RTTY|RIG_MODE_FM|RIG_MODE_PKTUSB)
+                                 RIG_MODE_LSB|RIG_MODE_RTTY|RIG_MODE_FM|RIG_MODE_PKTUSB|RIG_MODE_PKTLSB|RIG_MODE_PSK|RIG_MODE_PSKR)
 #define FT817_AM_TX_MODES       (RIG_MODE_AM)
 
 #define FT817_VFO_ALL           (RIG_VFO_A|RIG_VFO_B)
@@ -261,15 +262,15 @@ enum ft817_digi
 // Thanks to Olivier Schmitt sc.olivier@gmail.com for these tables
 #define FT817_PWR_CAL { 9, \
                 { \
-                    { 0x00, 0 }, \
-                    { 0x01, 10 }, \
-                    { 0x02, 14 }, \
-                    { 0x03, 20 }, \
-                    { 0x04, 34 }, \
-                    { 0x05, 50 }, \
-                    { 0x06, 66 }, \
-                    { 0x07, 82 }, \
-                    { 0x08, 100 } \
+                    { 0x00, 0.0f }, \
+                    { 0x01, 0.5f }, \
+                    { 0x02, 0.75f }, \
+                    { 0x03, 1.0f }, \
+                    { 0x04, 1.7f }, \
+                    { 0x05, 2.5f }, \
+                    { 0x06, 3.3f }, \
+                    { 0x07, 4.1f }, \
+                    { 0x08, 5.0f } \
                 } }
 
 #define FT817_ALC_CAL { 6, \
@@ -282,19 +283,184 @@ enum ft817_digi
                     { 0x05, 100 } \
                 } }
 
-#define FT817_SWR_CAL { 2, \
+// SWR values from Christian WA4YA, DL4YA
+#define FT817_SWR_CAL { 16, \
                 { \
-                    { 0, 0 }, \
-                    { 15, 100 } \
+                    { 0, 1.0f }, \
+                    { 1, 1.4f }, \
+                    { 2, 1.8f }, \
+                    { 3, 2.13f }, \
+                    { 4, 2.25f }, \
+                    { 5, 3.7f }, \
+                    { 6, 6.0f }, \
+                    { 7, 7.0f }, \
+                    { 8, 8.0f }, \
+                    { 9, 9.0f }, \
+                    { 10, 10.0f }, \
+                    { 11, 10.0f }, \
+                    { 12, 10.0f }, \
+                    { 13, 10.0f }, \
+                    { 14, 10.0f }, \
+                    { 15, 10.0f } \
                 } }
 
 
-const struct rig_caps ft817_caps =
+struct rig_caps ft817_caps =
 {
     RIG_MODEL(RIG_MODEL_FT817),
     .model_name =          "FT-817",
     .mfg_name =            "Yaesu",
-    .version =             "20220419.0",
+    .version =             "20241117.0",
+    .copyright =           "LGPL",
+    .status =              RIG_STATUS_STABLE,
+    .rig_type =            RIG_TYPE_TRANSCEIVER,
+    .ptt_type =            RIG_PTT_RIG,
+    .dcd_type =            RIG_DCD_RIG,
+    .port_type =           RIG_PORT_SERIAL,
+    .serial_rate_min =     4800,
+    .serial_rate_max =     38400,
+    .serial_data_bits =    8,
+    .serial_stop_bits =    2,
+    .serial_parity =       RIG_PARITY_NONE,
+    .serial_handshake =    RIG_HANDSHAKE_NONE,
+    .write_delay =         FT817_WRITE_DELAY,
+    .post_write_delay =    FT817_POST_WRITE_DELAY,
+    .timeout =             FT817_TIMEOUT,
+    .retry =               5,
+    .has_get_func =        RIG_FUNC_NONE,
+    .has_set_func =        RIG_FUNC_LOCK | RIG_FUNC_TONE | RIG_FUNC_TSQL | RIG_FUNC_CSQL | RIG_FUNC_RIT,
+    .has_get_level =
+    RIG_LEVEL_STRENGTH | RIG_LEVEL_RAWSTR | RIG_LEVEL_RFPOWER |
+    RIG_LEVEL_ALC | RIG_LEVEL_SWR | RIG_LEVEL_RFPOWER_METER_WATTS,
+    .has_set_level =       RIG_LEVEL_BAND_SELECT,
+    .has_get_parm =        RIG_PARM_NONE,
+    .has_set_parm =        RIG_PARM_NONE,
+    .level_gran =
+    {
+#include "level_gran_yaesu.h"
+    },
+    .parm_gran =           {},
+    .ctcss_list =          common_ctcss_list,
+    .dcs_list =            common_dcs_list,   /* only 104 out of 106 supported */
+    .preamp =              { RIG_DBLST_END, },
+    .attenuator =          { RIG_DBLST_END, },
+    .max_rit =             Hz(9990),
+    .max_xit =             Hz(0),
+    .max_ifshift =         Hz(0),
+    .vfo_ops =             RIG_OP_TOGGLE,
+    .targetable_vfo =      0,
+    .transceive =          RIG_TRN_OFF,
+    .bank_qty =            0,
+    .chan_desc_sz =        0,
+    .chan_list =           { RIG_CHAN_END, },
+
+    .rx_range_list1 =  {
+        {kHz(100), MHz(56), FT817_ALL_RX_MODES,  -1, -1, FT817_VFO_ALL, FT817_ANTS},
+        {MHz(76), MHz(108), RIG_MODE_WFM,        -1, -1, FT817_VFO_ALL, FT817_ANTS},
+        {MHz(118), MHz(164), FT817_ALL_RX_MODES, -1, -1, FT817_VFO_ALL, FT817_ANTS},
+        {MHz(420), MHz(470), FT817_ALL_RX_MODES, -1, -1, FT817_VFO_ALL, FT817_ANTS},
+        RIG_FRNG_END,
+    },
+    .tx_range_list1 =  {
+        FRQ_RNG_HF(1, FT817_OTHER_TX_MODES, W(0.5), W(5), FT817_VFO_ALL, FT817_ANTS),
+        FRQ_RNG_HF(1, FT817_AM_TX_MODES, W(0.5), W(1.5), FT817_VFO_ALL, FT817_ANTS),
+
+        FRQ_RNG_6m(1, FT817_OTHER_TX_MODES, W(0.5), W(5), FT817_VFO_ALL, FT817_ANTS),
+        FRQ_RNG_6m(1, FT817_AM_TX_MODES, W(0.5), W(1.5), FT817_VFO_ALL, FT817_ANTS),
+
+        FRQ_RNG_2m(1, FT817_OTHER_TX_MODES, W(0.5), W(5), FT817_VFO_ALL, FT817_ANTS),
+        FRQ_RNG_2m(1, FT817_AM_TX_MODES, W(0.5), W(1.5), FT817_VFO_ALL, FT817_ANTS),
+
+        FRQ_RNG_70cm(1, FT817_OTHER_TX_MODES, W(0.5), W(5), FT817_VFO_ALL, FT817_ANTS),
+        FRQ_RNG_70cm(1, FT817_AM_TX_MODES, W(0.5), W(1.5), FT817_VFO_ALL, FT817_ANTS),
+
+        RIG_FRNG_END,
+    },
+
+
+    .rx_range_list2 =  {
+        {kHz(100), MHz(56), FT817_ALL_RX_MODES,  -1, -1, FT817_VFO_ALL, FT817_ANTS},
+        {MHz(76), MHz(108), RIG_MODE_WFM,        -1, -1, FT817_VFO_ALL, FT817_ANTS},
+        {MHz(118), MHz(164), FT817_ALL_RX_MODES, -1, -1, FT817_VFO_ALL, FT817_ANTS},
+        {MHz(420), MHz(470), FT817_ALL_RX_MODES, -1, -1, FT817_VFO_ALL, FT817_ANTS},
+        RIG_FRNG_END,
+    },
+
+    .tx_range_list2 =  {
+        FRQ_RNG_HF(2, FT817_OTHER_TX_MODES, W(0.5), W(5), FT817_VFO_ALL, FT817_ANTS),
+        FRQ_RNG_HF(2, FT817_AM_TX_MODES, W(0.5), W(1.5), FT817_VFO_ALL, FT817_ANTS),
+        /* FIXME: 60 meters in US version */
+
+        FRQ_RNG_6m(2, FT817_OTHER_TX_MODES, W(0.5), W(5), FT817_VFO_ALL, FT817_ANTS),
+        FRQ_RNG_6m(2, FT817_AM_TX_MODES, W(0.5), W(1.5), FT817_VFO_ALL, FT817_ANTS),
+
+        FRQ_RNG_2m(2, FT817_OTHER_TX_MODES, W(0.5), W(5), FT817_VFO_ALL, FT817_ANTS),
+        FRQ_RNG_2m(2, FT817_AM_TX_MODES, W(0.5), W(1.5), FT817_VFO_ALL, FT817_ANTS),
+
+        FRQ_RNG_70cm(2, FT817_OTHER_TX_MODES, W(0.5), W(5), FT817_VFO_ALL, FT817_ANTS),
+        FRQ_RNG_70cm(2, FT817_AM_TX_MODES, W(0.5), W(1.5), FT817_VFO_ALL, FT817_ANTS),
+
+        RIG_FRNG_END,
+    },
+
+    .tuning_steps =  {
+        {FT817_SSB_CW_RX_MODES, Hz(10)},
+        {FT817_AM_FM_RX_MODES | RIG_MODE_WFM, Hz(100)},
+        RIG_TS_END,
+    },
+
+    .filters = {
+        {FT817_SSB_CW_RX_MODES, kHz(2.2)},  /* normal passband */
+        {FT817_CWN_RX_MODES, 500},          /* CW and RTTY narrow */
+        {RIG_MODE_AM, kHz(6)},              /* AM normal */
+        {RIG_MODE_FM | RIG_MODE_PKTFM, kHz(9)},
+        {RIG_MODE_WFM, kHz(15)},
+        RIG_FLT_END,
+    },
+
+    .str_cal =          FT817_STR_CAL,
+    .swr_cal =          FT817_SWR_CAL,
+    .alc_cal =          FT817_ALC_CAL,
+    .rfpower_meter_cal = FT817_PWR_CAL,
+
+    .rig_init =         ft817_init,
+    .rig_cleanup =      ft817_cleanup,
+    .rig_open =         ft817_open,
+    .rig_close =        ft817_close,
+    .get_vfo =          ft817_get_vfo,
+    .set_vfo =          ft817_set_vfo,
+    .set_freq =         ft817_set_freq,
+    .get_freq =         ft817_get_freq,
+    .set_mode =         ft817_set_mode,
+    .get_mode =         ft817_get_mode,
+    .set_ptt =          ft817_set_ptt,
+    .get_ptt =          ft817_get_ptt,
+    .get_dcd =          ft817_get_dcd,
+    .set_rptr_shift =   ft817_set_rptr_shift,
+    .set_rptr_offs =    ft817_set_rptr_offs,
+    .set_split_vfo =    ft817_set_split_vfo,
+    .get_split_vfo =    ft817_get_split_vfo,
+    .set_rit =          ft817_set_rit,
+    .set_dcs_code =     ft817_set_dcs_code,
+    .set_ctcss_tone =   ft817_set_ctcss_tone,
+    .set_dcs_sql =      ft817_set_dcs_sql,
+    .set_ctcss_sql =    ft817_set_ctcss_sql,
+    .power2mW =         ft817_power2mW,
+    .mW2power =         ft817_mW2power,
+    .set_powerstat =    ft817_set_powerstat,
+    .get_ant =          ft817_get_ant,
+    .get_level =        ft817_get_level,
+    .set_func =         ft817_set_func,
+    .vfo_op =           ft817_vfo_op,
+    .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
+};
+
+struct rig_caps q900_caps =
+{
+    RIG_MODEL(RIG_MODEL_Q900),
+    .model_name =          "Q900",
+    .mfg_name =            "Guohe",
+    .version =             "20241117.0",
     .copyright =           "LGPL",
     .status =              RIG_STATUS_STABLE,
     .rig_type =            RIG_TYPE_TRANSCEIVER,
@@ -439,12 +605,12 @@ const struct rig_caps ft817_caps =
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
-const struct rig_caps ft818_caps =
+struct rig_caps ft818_caps =
 {
     RIG_MODEL(RIG_MODEL_FT818),
     .model_name =          "FT-818",
     .mfg_name =            "Yaesu",
-    .version =             "20220419.0",
+    .version =             "20221117.0",
     .copyright =           "LGPL",
     .status =              RIG_STATUS_STABLE,
     .rig_type =            RIG_TYPE_TRANSCEIVER,
@@ -600,14 +766,19 @@ const struct rig_caps ft818_caps =
 
 static int ft817_init(RIG *rig)
 {
+    struct ft817_priv_data *p;
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called, version %s\n", __func__,
               rig->caps->version);
 
-    if ((rig->state.priv = calloc(1, sizeof(struct ft817_priv_data))) == NULL)
+    if ((STATE(rig)->priv = calloc(1, sizeof(struct ft817_priv_data))) == NULL)
     {
         return -RIG_ENOMEM;
     }
 
+    p = (struct ft817_priv_data *) STATE(rig)->priv;
+
+    p->swr = 10;
+
     return RIG_OK;
 }
 
@@ -615,9 +786,9 @@ static int ft817_cleanup(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
-    free(rig->state.priv);
+    free(STATE(rig)->priv);
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
@@ -625,6 +796,8 @@ static int ft817_cleanup(RIG *rig)
 static int ft817_open(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
+    hl_usleep(1500 *
+              1000); // rig needs a bit to allow commands to come through on startup
 
     return RIG_OK;
 }
@@ -638,7 +811,8 @@ static int ft817_close(RIG *rig)
 
 /* ---------------------------------------------------------------------- */
 
-static inline long timediff(struct timeval *tv1, struct timeval *tv2)
+static inline long timediff(const struct timeval *tv1,
+                            const struct timeval *tv2)
 {
     struct timeval tv;
 
@@ -676,6 +850,7 @@ static int check_cache_timeout(struct timeval *tv)
 static int ft817_read_eeprom(RIG *rig, unsigned short addr, unsigned char *out)
 {
     unsigned char data[YAESU_CMD_LENGTH];
+    hamlib_port_t *rp = RIGPORT(rig);
     int n;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
@@ -683,11 +858,11 @@ static int ft817_read_eeprom(RIG *rig, unsigned short addr, unsigned char *out)
            YAESU_CMD_LENGTH);
 
     data[0] = addr >> 8;
-    data[1] = addr & 0xfe;
+    data[1] = addr & 0xff;
 
-    write_block(&rig->state.rigport, data, YAESU_CMD_LENGTH);
+    write_block(rp, data, YAESU_CMD_LENGTH);
 
-    if ((n = read_block(&rig->state.rigport, data, 2)) < 0)
+    if ((n = read_block(rp, data, 2)) < 0)
     {
         return n;
     }
@@ -697,19 +872,31 @@ static int ft817_read_eeprom(RIG *rig, unsigned short addr, unsigned char *out)
         return -RIG_EIO;
     }
 
-    *out = data[addr % 2];
+    if (addr == 0x55) // for some reason VFO returns high byte
+    {
+        *out = data[0];
+    }
+    else
+    {
+        *out = data[addr % 2];
+    }
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s: data[0]=%02x, data[1]=%02x, out=%02x\n",
+              __func__, data[0], data[1], *out);
+
+    memcpy(out, data, 2);
     return RIG_OK;
 }
 
 static int ft817_get_status(RIG *rig, int status)
 {
-    struct ft817_priv_data *p = (struct ft817_priv_data *) rig->state.priv;
+    struct ft817_priv_data *p = (struct ft817_priv_data *) STATE(rig)->priv;
+    hamlib_port_t *rp = RIGPORT(rig);
     struct timeval *tv;
     unsigned char *data;
     int len;
     int n;
-    int retries = rig->state.rigport.retry;
+    int retries = rp->retry;
     unsigned char result[2];
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
@@ -749,10 +936,9 @@ static int ft817_get_status(RIG *rig, int status)
 
     do
     {
-        rig_flush(&rig->state.rigport);
-        write_block(&rig->state.rigport, ncmd[status].nseq,
-                    YAESU_CMD_LENGTH);
-        n = read_block(&rig->state.rigport, data, len);
+        rig_flush(rp);
+        write_block(rp, ncmd[status].nseq, YAESU_CMD_LENGTH);
+        n = read_block(rp, data, len);
     }
     while (retries-- && n < 0);
 
@@ -778,16 +964,16 @@ static int ft817_get_status(RIG *rig, int status)
          * getting the frequency. */
         switch (p->fm_status[4] & 0x7f)
         {
-            unsigned char dig_mode;
+            unsigned char dig_mode[2];
 
         case 0x0a:
-            if ((n = ft817_read_eeprom(rig, 0x0065, &dig_mode)) < 0)
+            if ((n = ft817_read_eeprom(rig, 0x0065, dig_mode)) < 0)
             {
                 return n;
             }
 
             /* Top 3 bit define the digi mode */
-            p->dig_mode = dig_mode >> 5;
+            p->dig_mode = dig_mode[0] >> 5;
 
         default:
             break;
@@ -799,9 +985,9 @@ static int ft817_get_status(RIG *rig, int status)
         /* FT-817 returns 2 bytes with 4 nibbles.
          * Extract raw values here;
          * convert to float when they are requested. */
-        p->swr_level = result[0] & 0xF;
-        p->pwr_level = result[0] >> 4;
-        p->alc_level = result[1] & 0xF;
+        p->swr_level = (result[1] & 0xF0) >> 4;
+        p->pwr_level = (result[0] & 0xF0) >> 4;
+        p->alc_level = result[0] & 0x0F;
         p->mod_level = result[1] >> 4;
         rig_debug(RIG_DEBUG_TRACE, "%s: swr: %d, pwr %d, alc %d, mod %d\n",
                   __func__,
@@ -821,18 +1007,19 @@ static int ft817_get_status(RIG *rig, int status)
 
 static int ft817_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    struct ft817_priv_data *p = (struct ft817_priv_data *) rig->state.priv;
+    struct ft817_priv_data *p = (struct ft817_priv_data *) STATE(rig)->priv;
     freq_t f1 = 0, f2 = 0;
-    int retries = rig->state.rigport.retry +
+    struct rig_cache *cachep = CACHE(rig);
+    int retries = RIGPORT(rig)->retry +
                   1; // +1 because, because 2 steps are needed even in best scenario
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called, vfo=%s, ptt=%d, split=%d\n", __func__,
-              rig_strvfo(vfo), rig->state.cache.ptt, rig->state.cache.split);
+              rig_strvfo(vfo), cachep->ptt, cachep->split);
 
     // we can't query VFOB while in transmit and split mode
-    if (rig->state.cache.ptt && vfo == RIG_VFO_B && rig->state.cache.split)
+    if (cachep->ptt && vfo == RIG_VFO_B && cachep->split)
     {
-        *freq = rig->state.cache.freqMainB;
+        *freq = cachep->freqMainB;
         return RIG_OK;
     }
 
@@ -873,7 +1060,7 @@ static int ft817_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
 static int ft817_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-    struct ft817_priv_data *p = (struct ft817_priv_data *) rig->state.priv;
+    struct ft817_priv_data *p = (struct ft817_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -922,9 +1109,9 @@ static int ft817_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
         {
         case FT817_DIGI_RTTY: *mode = RIG_MODE_RTTYR; break;
 
-        case FT817_DIGI_PSK_L: *mode = RIG_MODE_PKTLSB; break;
+        case FT817_DIGI_PSK_L: *mode = RIG_MODE_PSKR; break;
 
-        case FT817_DIGI_PSK_U: *mode = RIG_MODE_PKTUSB; break;
+        case FT817_DIGI_PSK_U: *mode = RIG_MODE_PSK; break;
 
         case FT817_DIGI_USER_L: *mode = RIG_MODE_PKTLSB; break;
 
@@ -959,7 +1146,7 @@ static int ft817_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 static int ft817_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split,
                                vfo_t *tx_vfo)
 {
-    struct ft817_priv_data *p = (struct ft817_priv_data *) rig->state.priv;
+    const struct ft817_priv_data *p = (struct ft817_priv_data *) STATE(rig)->priv;
     ptt_t ptt;
     int n;
 
@@ -976,21 +1163,23 @@ static int ft817_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split,
     if (ptt == RIG_PTT_OFF)
     {
         // TX status not valid when in RX
-        unsigned char c;
+        unsigned char c[2];
 
         /* Get split status from EEPROM */
-        n = ft817_read_eeprom(rig, 0x7a, &c);
+        n = ft817_read_eeprom(rig, 0x7a, c);
 
         if (n != RIG_OK)
         {
             return n;
         }
 
-        *split = (c & 0x80) ? RIG_SPLIT_ON : RIG_SPLIT_OFF;
+        *split = (c[0] & 0x80) ? RIG_SPLIT_ON : RIG_SPLIT_OFF;
+        *tx_vfo = RIG_VFO_A;
     }
     else
     {
         *split = (p->tx_status & 0x20) ? RIG_SPLIT_ON : RIG_SPLIT_OFF;
+        *tx_vfo = RIG_VFO_B;
     }
 
     return RIG_OK;
@@ -998,7 +1187,7 @@ static int ft817_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split,
 
 static int ft817_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
-    struct ft817_priv_data *p = (struct ft817_priv_data *) rig->state.priv;
+    struct ft817_priv_data *p = (struct ft817_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -1012,7 +1201,8 @@ static int ft817_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
         }
     }
 
-    *ptt = ((p->tx_status & 0x80) == 0);
+    *ptt = p->tx_status  != 0xff;
+
 
     return RIG_OK;
 }
@@ -1020,7 +1210,7 @@ static int ft817_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 static int ft817_get_tx_level(RIG *rig, value_t *val, unsigned char *tx_level,
                               const cal_table_float_t *cal)
 {
-    struct ft817_priv_data *p = (struct ft817_priv_data *) rig->state.priv;
+    struct ft817_priv_data *p = (struct ft817_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -1046,8 +1236,9 @@ static int ft817_get_tx_level(RIG *rig, value_t *val, unsigned char *tx_level,
 
         if (ptt == RIG_PTT_OFF)
         {
-            rig_debug(RIG_DEBUG_VERBOSE, "%s: rig not keyed\n", __func__);
-            return -RIG_ERJCTED; //Or return OK?
+
+            val->f = p->swr;
+            return RIG_OK;
         }
 
         n = ft817_get_status(rig, FT817_NATIVE_CAT_GET_TX_METERING);
@@ -1058,7 +1249,8 @@ static int ft817_get_tx_level(RIG *rig, value_t *val, unsigned char *tx_level,
         }
     }
 
-    val->f = rig_raw2val_float(*tx_level, cal);
+    p->swr = val->f = rig_raw2val_float(*tx_level, cal);
+
     rig_debug(RIG_DEBUG_VERBOSE, "%s: level %f\n", __func__, val->f);
 
     return RIG_OK;
@@ -1067,7 +1259,7 @@ static int ft817_get_tx_level(RIG *rig, value_t *val, unsigned char *tx_level,
 /* frontend will always use RAWSTR+cal_table */
 static int ft817_get_smeter_level(RIG *rig, value_t *val)
 {
-    struct ft817_priv_data *p = (struct ft817_priv_data *) rig->state.priv;
+    struct ft817_priv_data *p = (struct ft817_priv_data *) STATE(rig)->priv;
     int n;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
@@ -1108,7 +1300,7 @@ static int ft817_get_smeter_level(RIG *rig, value_t *val)
 
 static int ft817_get_raw_smeter_level(RIG *rig, value_t *val)
 {
-    struct ft817_priv_data *p = (struct ft817_priv_data *) rig->state.priv;
+    struct ft817_priv_data *p = (struct ft817_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -1130,7 +1322,7 @@ static int ft817_get_raw_smeter_level(RIG *rig, value_t *val)
 
 static int ft817_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
-    struct ft817_priv_data *p = (struct ft817_priv_data *) rig->state.priv;
+    struct ft817_priv_data *p = (struct ft817_priv_data *) STATE(rig)->priv;
 
     switch (level)
     {
@@ -1152,6 +1344,10 @@ static int ft817_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     case RIG_LEVEL_SWR:
         return ft817_get_tx_level(rig, val, &p->swr_level, &rig->caps->swr_cal);
 
+    case RIG_LEVEL_RFPOWER_METER_WATTS:
+        return ft817_get_tx_level(rig, val, &p->pwr_level,
+                                  &rig->caps->rfpower_meter_cal);
+
     default:
         return -RIG_EINVAL;
     }
@@ -1161,7 +1357,7 @@ static int ft817_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
 static int ft817_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {
-    struct ft817_priv_data *p = (struct ft817_priv_data *) rig->state.priv;
+    struct ft817_priv_data *p = (struct ft817_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -1194,10 +1390,10 @@ static int ft818_817_get_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t *option,
     /* The FT818/817 has no RIG_TARGETABLE_ALL
      * so rig.c switched the active VFO to the one requested */
     int ret;
-    unsigned char eeprom_band, eeprom_ant;
+    unsigned char eeprom_band[2], eeprom_ant[2];
 
     /* Read eeprom for current 'band' for both VFO's */
-    ret = ft817_read_eeprom(rig, 0x59, &eeprom_band);
+    ret = ft817_read_eeprom(rig, 0x59, eeprom_band);
 
     if (ret != RIG_OK)
     {
@@ -1207,7 +1403,7 @@ static int ft818_817_get_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t *option,
     /* Read eeprom for antenna selection per band.
      * The FT818/817 stores antenna per band not per VFO!
      * So changing antenna will change for both VFO's */
-    ret = ft817_read_eeprom(rig, 0x7A, &eeprom_ant);
+    ret = ft817_read_eeprom(rig, 0x7A, eeprom_ant);
 
     if (ret != RIG_OK)
     {
@@ -1217,18 +1413,18 @@ static int ft818_817_get_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t *option,
     /* if CURR then get real VFO before parsing EEPROM */
     if (vfo == RIG_VFO_CURR)
     {
-        vfo = rig->state.current_vfo;
+        vfo = STATE(rig)->current_vfo;
     }
 
     /* band info is 4 bit per VFO, for A lower nibble, B is upper nible */
     switch (vfo)
     {
     case RIG_VFO_A:
-        eeprom_band &= 0xF;
+        eeprom_band[0] &= 0xF;
         break;
 
     case RIG_VFO_B:
-        eeprom_band = eeprom_band >> 4;
+        eeprom_band[0] = eeprom_band[0] >> 4;
         break;
 
     default:
@@ -1245,9 +1441,9 @@ static int ft818_817_get_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t *option,
      * So to make the code simple: if we have a 817 and 2 or higher band then
      * add 1 to the value to align it on the 818 mapping.
      */
-    if (is817 && eeprom_band >= 2)
+    if (is817 && eeprom_band[0] >= 2)
     {
-        eeprom_band++;
+        eeprom_band[0]++;
     }
 
     /* The 817/818 does not have a antenna selection per VFO but per band.
@@ -1256,7 +1452,7 @@ static int ft818_817_get_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t *option,
      */
 
 
-    switch (eeprom_band)
+    switch (eeprom_band[0])
     {
     case 0:  /* 160M */
     case 1:  /*  80M */
@@ -1269,37 +1465,37 @@ static int ft818_817_get_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t *option,
     case 8:  /*  12M */
     case 9:  /*  10M */
         /* All HF use the same antenna setting, bit 0 */
-        eeprom_ant &= 1 << 0;
+        eeprom_ant[0] &= 1 << 0;
         break;
 
     case 0xA:  /* 6m, bit 1 */
-        eeprom_ant &= 1 << 1;
+        eeprom_ant[0] &= 1 << 1;
         break;
 
     case 0xB:  /* FM BCB 76Mhz - 108Mhz, bit 2 */
-        eeprom_ant &= 1 << 2;
+        eeprom_ant[0] &= 1 << 2;
         break;
 
     case 0xC:  /* Airband, bit 3 */
-        eeprom_ant &= 1 << 3;
+        eeprom_ant[0] &= 1 << 3;
         break;
 
     case 0xD:  /* 2M, bit 4 */
-        eeprom_ant &= 1 << 4;
+        eeprom_ant[0] &= 1 << 4;
         break;
 
     case 0xE:  /* 70cm / UHF, bit 5 */
-        eeprom_ant &= 1 << 5;
+        eeprom_ant[0] &= 1 << 5;
         break;
 
     case 0xF: /* Free-tuning?, bit 6 */
-        eeprom_ant &= 1 << 6;
+        eeprom_ant[0] &= 1 << 6;
         break;
     }
 
     /* We have no split TX/RX capability per VFO.
      * So only set ant_curr and leave rx/tx set to unknown. */
-    *ant_curr = eeprom_ant ? FT817_ANT_REAR : FT817_ANT_FRONT;
+    *ant_curr = eeprom_ant[0] ? FT817_ANT_REAR : FT817_ANT_FRONT;
 
     return RIG_OK;
 }
@@ -1324,26 +1520,31 @@ static int ft818_get_ant(RIG *rig, vfo_t vfo, ant_t ant, value_t *option,
 int ft817_read_ack(RIG *rig)
 {
     unsigned char dummy;
+    hamlib_port_t *rp = RIGPORT(rig);
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
-    if (rig->state.rigport.post_write_delay == 0)
+    if (rp->post_write_delay == 0)
     {
-        if (read_block(&rig->state.rigport, &dummy, 1) < 0)
+        if (read_block(rp, &dummy, 1) < 0)
         {
             rig_debug(RIG_DEBUG_ERR, "%s: error reading ack\n", __func__);
             rig_debug(RIG_DEBUG_ERR, "%s: adjusting post_write_delay to avoid ack\n",
                       __func__);
-            rig->state.rigport.post_write_delay =
+            rp->post_write_delay =
                 10; // arbitrary choice right now of max 100 cmds/sec
             return RIG_OK; // let it continue without checking for ack now
         }
 
-        rig_debug(RIG_DEBUG_TRACE, "%s: ack received (%d)\n", __func__, dummy);
+        rig_debug(RIG_DEBUG_TRACE, "%s: ack value=0x%x\n", __func__, dummy);
+
+#if 0 // don't know of any reject codes -- none documented
 
         if (dummy != 0)
         {
             return -RIG_ERJCTED;
         }
+
+#endif
     }
 
     return RIG_OK;
@@ -1355,6 +1556,7 @@ int ft817_read_ack(RIG *rig)
  */
 static int ft817_send_cmd(RIG *rig, int index)
 {
+    hamlib_port_t *rp = RIGPORT(rig);
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
     if (ncmd[index].ncomp == 0)
@@ -1363,15 +1565,15 @@ static int ft817_send_cmd(RIG *rig, int index)
         return -RIG_EINTERNAL;
     }
 
-    rig_flush(&rig->state.rigport);
-    write_block(&rig->state.rigport, ncmd[index].nseq, YAESU_CMD_LENGTH);
+    rig_flush(rp);
+    write_block(rp, ncmd[index].nseq, YAESU_CMD_LENGTH);
     return ft817_read_ack(rig);
 }
 
 /*
  * The same for incomplete commands.
  */
-static int ft817_send_icmd(RIG *rig, int index, unsigned char *data)
+static int ft817_send_icmd(RIG *rig, int index, const unsigned char *data)
 {
     unsigned char cmd[YAESU_CMD_LENGTH];
 
@@ -1386,23 +1588,23 @@ static int ft817_send_icmd(RIG *rig, int index, unsigned char *data)
     cmd[YAESU_CMD_LENGTH - 1] = ncmd[index].nseq[YAESU_CMD_LENGTH - 1];
     memcpy(cmd, data, YAESU_CMD_LENGTH - 1);
 
-    write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
+    write_block(RIGPORT(rig), cmd, YAESU_CMD_LENGTH);
     return ft817_read_ack(rig);
 }
 
 /* ---------------------------------------------------------------------- */
 static int ft817_get_vfo(RIG *rig, vfo_t *vfo)
 {
-    unsigned char c;
+    unsigned char c[2];
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
-    if (ft817_read_eeprom(rig, 0x55, &c) < 0)   /* get vfo status */
+    if (ft817_read_eeprom(rig, 0x55, c) < 0)   /* get vfo status */
     {
         return -RIG_EPROTO;
     }
 
-    if ((c & 0x1) == 0)
+    if ((c[0] & 0x1) == 0)
     {
         *vfo = RIG_VFO_A;
     }
@@ -1419,7 +1621,7 @@ static int ft817_set_vfo(RIG *rig, vfo_t vfo)
     vfo_t curvfo;
     int retval;
 
-    rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
+    rig_debug(RIG_DEBUG_VERBOSE, "%s: called vfo=%s\n", __func__, rig_strvfo(vfo));
 
     retval =  ft817_get_vfo(rig, &curvfo);
 
@@ -1435,7 +1637,11 @@ static int ft817_set_vfo(RIG *rig, vfo_t vfo)
         return RIG_OK;
     }
 
-    return ft817_send_cmd(rig, FT817_NATIVE_CAT_SET_VFOAB);
+    retval = ft817_send_cmd(rig, FT817_NATIVE_CAT_SET_VFOAB);
+    hl_usleep(50 *
+              1000); // can take a little while for vfo swap to happen -- otherwise we get errors trying to read eeprom to quickly
+
+    return retval;
 }
 
 static int ft817_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
@@ -1446,10 +1652,11 @@ static int ft817_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     rig_debug(RIG_DEBUG_VERBOSE, "ft817: requested freq = %"PRIfreq" Hz\n", freq);
 
     /* fill in the frequency */
-    to_bcd_be(data, (freq + 5) / 10, 8);
+    /* changed to truncate the freq for gpredict compatibility */
+    to_bcd_be(data, (freq + 0) / 10, 8);
 
     rig_force_cache_timeout(
-        &((struct ft817_priv_data *)rig->state.priv)->fm_status_tv);
+        &((struct ft817_priv_data *)STATE(rig)->priv)->fm_status_tv);
 
     retval = ft817_send_icmd(rig, FT817_NATIVE_CAT_SET_FREQ, data);
     hl_usleep(50 * 1000); // FT817 needs a little time after setting freq
@@ -1484,9 +1691,73 @@ static int ft817_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
     case RIG_MODE_RTTY:
     case RIG_MODE_PKTUSB:
-        /* user has to have correct DIG mode setup on rig */
+    case RIG_MODE_PKTLSB:
+    case RIG_MODE_PSK:
+    case RIG_MODE_PSKR:
+    {
+        // first we get our dig mode to see if it needs changing
+        unsigned char data[YAESU_CMD_LENGTH];
+        unsigned char digmode[2];
+        int ret = ft817_read_eeprom(rig, 0x65, digmode);
+
+        if (ret != RIG_OK)
+        {
+            return ret;
+        }
+
+        rig_debug(RIG_DEBUG_VERBOSE, "%s: digmode=0x%02x%02x\n", __func__, digmode[0],
+                  digmode[1]);
+        digmode[0] = digmode[0] >> 5; // shift 5 bits
+
+        // check if we're already in the mode and return if so
+        // the memory check was failing when in FM mode -- still showing digmode
+        if (STATE(rig)->current_mode == mode)
+        {
+            if (digmode[0] == 0x00 &&  mode == RIG_MODE_RTTY) { return RIG_OK; }
+            else if (digmode[0] == 0x01 &&  mode == RIG_MODE_PSKR) { return RIG_OK; }
+            else if (digmode[0] == 0x02 &&  mode == RIG_MODE_PSK) { return RIG_OK; }
+            else if (digmode[0] == 0x03 &&  mode == RIG_MODE_PKTLSB) { return RIG_OK; }
+            else if (digmode[0] == 0x04 &&  mode == RIG_MODE_PKTUSB) { return RIG_OK; }
+        }
+
+        memcpy(data, ncmd[FT817_NATIVE_CAT_EEPROM_WRITE].nseq, YAESU_CMD_LENGTH);
+
+        data[0] = 0x00;
+        data[1] = 0x65;
+
+        if (mode == RIG_MODE_RTTY) { data[2] = 0; }
+
+        if (mode == RIG_MODE_PSKR) { data[2] = 1 << 5; }
+
+        if (mode == RIG_MODE_PSK) { data[2] = 2 << 5; }
+
+        if (mode == RIG_MODE_PKTLSB) { data[2] = 3 << 5; }
+
+        if (mode == RIG_MODE_PKTUSB) { data[2] = 4 << 5; }
+
+        // data[3] should be the original value at address 0x66,
+        // i.e. "DCS INV" / digmode[1]. This is so we don't end
+        // up overwriting this setting by mistake.
+        data[3] = digmode[1];
+
         index = FT817_NATIVE_CAT_SET_MODE_DIG;
-        break;
+        ret = ft817_send_cmd(rig, index);
+
+        if (ret != RIG_OK)
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: ft817_send_cmd: %s\n", __func__, rigerror(ret));
+        }
+
+        index = FT817_NATIVE_CAT_EEPROM_WRITE;
+        ret = ft817_send_icmd(rig, index, data);
+
+        if (ret != RIG_OK)
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: ft817_send_icmd: %s\n", __func__, rigerror(ret));
+        }
+
+        return RIG_OK;
+    }
 
     case RIG_MODE_FM:
         index = FT817_NATIVE_CAT_SET_MODE_FM;
@@ -1509,7 +1780,7 @@ static int ft817_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     /*      return -RIG_EINVAL; */
 
     rig_force_cache_timeout(
-        &((struct ft817_priv_data *)rig->state.priv)->fm_status_tv);
+        &((struct ft817_priv_data *)STATE(rig)->priv)->fm_status_tv);
 
     return ft817_send_cmd(rig, index);
 }
@@ -1518,7 +1789,7 @@ static int ft817_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
     int index;
     ptt_t ptt_response = -1;
-    int retries = rig->state.rigport.retry;
+    int retries = RIGPORT(rig)->retry;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -1831,10 +2102,10 @@ int ft817_set_powerstat(RIG *rig, powerstat_t status)
 
     case RIG_POWER_ON:
         // send 5 bytes first, snooze a bit, then PWR_ON
-        write_block(&rig->state.rigport,
+        write_block(RIGPORT(rig),
                     ncmd[FT817_NATIVE_CAT_PWR_WAKE].nseq, YAESU_CMD_LENGTH);
         hl_usleep(200 * 1000);
-        write_block(&rig->state.rigport, ncmd[FT817_NATIVE_CAT_PWR_ON].nseq,
+        write_block(RIGPORT(rig), ncmd[FT817_NATIVE_CAT_PWR_ON].nseq,
                     YAESU_CMD_LENGTH);
         return RIG_OK;
 
@@ -1854,7 +2125,7 @@ static int ft817_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 
     case RIG_OP_TOGGLE:
         rig_force_cache_timeout(&((struct ft817_priv_data *)
-                                  rig->state.priv)->fm_status_tv);
+                                  STATE(rig)->priv)->fm_status_tv);
         n = ft817_send_cmd(rig, FT817_NATIVE_CAT_SET_VFOAB);
         hl_usleep(100 * 1000); // rig needs a little time to do this
         return n;
@@ -1896,7 +2167,7 @@ static int ft817_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
         return n;
     }
 
-    rig->state.cache.split = split;
+    CACHE(rig)->split = split;
 
     return RIG_OK;
 
