@@ -50,8 +50,6 @@
  * doesn't work from front panel either.
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <string.h>     /* String function definitions */
 
@@ -67,6 +65,8 @@
 #include "misc.h"
 #include "tones.h"
 #include "bandplan.h"
+#include "cal.h"
+
 
 enum ft857_native_cmd_e
 {
@@ -227,6 +227,20 @@ enum ft857_digi
     FT857_DIGI_USER_U,
 };
 
+
+#define FT857_PWR_CAL { 9, \
+            { \
+                { 0x00, 0.0f }, \
+                { 0x01, 10.0f }, \
+                { 0x02, 15.0f }, \
+                { 0x03, 20.0f }, \
+                { 0x04, 34.0f }, \
+                { 0x05, 50.0f }, \
+                { 0x06, 66.0f }, \
+                { 0x07, 82.f }, \
+                { 0x08, 100.0f } \
+            } }
+
 #define FT857_ALL_RX_MODES      (RIG_MODE_AM|RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_USB|\
                                  RIG_MODE_LSB|RIG_MODE_RTTY|RIG_MODE_FM|RIG_MODE_PKTUSB)
 #define FT857_SSB_CW_RX_MODES   (RIG_MODE_CW|RIG_MODE_CWR|RIG_MODE_USB|RIG_MODE_LSB)
@@ -239,9 +253,9 @@ enum ft857_digi
 #define FT857_VFO_ALL           (RIG_VFO_A|RIG_VFO_B)
 #define FT857_ANTS              0
 
-static int ft857_send_icmd(RIG *rig, int index, unsigned char *data);
+static int ft857_send_icmd(RIG *rig, int index, const unsigned char *data);
 
-const struct rig_caps ft857_caps =
+struct rig_caps ft857_caps =
 {
     RIG_MODEL(RIG_MODEL_FT857),
     .model_name =     "FT-857",
@@ -265,7 +279,7 @@ const struct rig_caps ft857_caps =
     .retry =      0,
     .has_get_func =       RIG_FUNC_NONE,
     .has_set_func =   RIG_FUNC_LOCK | RIG_FUNC_TONE | RIG_FUNC_TSQL | RIG_FUNC_CSQL | RIG_FUNC_RIT,
-    .has_get_level =  RIG_LEVEL_STRENGTH | RIG_LEVEL_RFPOWER,
+    .has_get_level =  RIG_LEVEL_STRENGTH | RIG_LEVEL_RFPOWER | RIG_LEVEL_RFPOWER_METER_WATTS,
     .has_set_level =  RIG_LEVEL_BAND_SELECT,
     .has_get_parm =   RIG_PARM_NONE,
     .has_set_parm =   RIG_PARM_NONE,
@@ -356,6 +370,7 @@ const struct rig_caps ft857_caps =
 //        {RIG_MODE_WFM, kHz(230)}, /* ?? */
         RIG_FLT_END,
     },
+    .rfpower_meter_cal = FT857_PWR_CAL,
 
     .rig_init =       ft857_init,
     .rig_cleanup =    ft857_cleanup,
@@ -395,7 +410,7 @@ int ft857_init(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
-    if ((rig->state.priv = calloc(1, sizeof(struct ft857_priv_data))) == NULL)
+    if ((STATE(rig)->priv = calloc(1, sizeof(struct ft857_priv_data))) == NULL)
     {
         return -RIG_ENOMEM;
     }
@@ -407,12 +422,12 @@ int ft857_cleanup(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
@@ -433,7 +448,8 @@ int ft857_close(RIG *rig)
 
 /* ---------------------------------------------------------------------- */
 
-static inline long timediff(struct timeval *tv1, struct timeval *tv2)
+static inline long timediff(const struct timeval *tv1,
+                            const struct timeval *tv2)
 {
     struct timeval tv;
 
@@ -471,6 +487,7 @@ static int check_cache_timeout(struct timeval *tv)
 static int ft857_read_eeprom(RIG *rig, unsigned short addr, unsigned char *out)
 {
     unsigned char data[YAESU_CMD_LENGTH];
+    hamlib_port_t *rp = RIGPORT(rig);
     int n;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
@@ -480,9 +497,9 @@ static int ft857_read_eeprom(RIG *rig, unsigned short addr, unsigned char *out)
     data[0] = addr >> 8;
     data[1] = addr & 0xfe;
 
-    write_block(&rig->state.rigport, data, YAESU_CMD_LENGTH);
+    write_block(rp, data, YAESU_CMD_LENGTH);
 
-    if ((n = read_block(&rig->state.rigport, data, 2)) < 0)
+    if ((n = read_block(rp, data, 2)) < 0)
     {
         return n;
     }
@@ -499,7 +516,8 @@ static int ft857_read_eeprom(RIG *rig, unsigned short addr, unsigned char *out)
 
 static int ft857_get_status(RIG *rig, int status)
 {
-    struct ft857_priv_data *p = (struct ft857_priv_data *) rig->state.priv;
+    struct ft857_priv_data *p = (struct ft857_priv_data *) STATE(rig)->priv;
+    hamlib_port_t *rp = RIGPORT(rig);
     struct timeval *tv;
     unsigned char *data;
     int len;
@@ -532,12 +550,11 @@ static int ft857_get_status(RIG *rig, int status)
         return -RIG_EINTERNAL;
     }
 
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
-    write_block(&rig->state.rigport, ncmd[status].nseq,
-                YAESU_CMD_LENGTH);
+    write_block(rp, ncmd[status].nseq, YAESU_CMD_LENGTH);
 
-    if ((n = read_block(&rig->state.rigport, data, len)) < 0)
+    if ((n = read_block(rp, data, len)) < 0)
     {
         return n;
     }
@@ -576,14 +593,14 @@ static int ft857_send_cmd(RIG *rig, int index)
         return -RIG_EINTERNAL;
     }
 
-    write_block(&rig->state.rigport, ncmd[index].nseq, YAESU_CMD_LENGTH);
+    write_block(RIGPORT(rig), ncmd[index].nseq, YAESU_CMD_LENGTH);
     return ft817_read_ack(rig);
 }
 
 /*
  * The same for incomplete commands.
  */
-static int ft857_send_icmd(RIG *rig, int index, unsigned char *data)
+static int ft857_send_icmd(RIG *rig, int index, const unsigned char *data)
 {
     unsigned char cmd[YAESU_CMD_LENGTH];
 
@@ -598,7 +615,7 @@ static int ft857_send_icmd(RIG *rig, int index, unsigned char *data)
     cmd[YAESU_CMD_LENGTH - 1] = ncmd[index].nseq[YAESU_CMD_LENGTH - 1];
     memcpy(cmd, data, YAESU_CMD_LENGTH - 1);
 
-    write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
+    write_block(RIGPORT(rig), cmd, YAESU_CMD_LENGTH);
     return ft817_read_ack(rig);
 }
 
@@ -612,16 +629,17 @@ int ft857_get_vfo(RIG *rig, vfo_t *vfo)
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
-    // Some 857's cannnot read so we'll just return the cached value if we've seen an error
+    // Some 857's cannot read so we'll just return the cached value if we've seen an error
     if (ignore)
     {
-        *vfo = rig->state.cache.vfo;
+        *vfo = CACHE(rig)->vfo;
         return RIG_OK;
     }
+
     if (ft857_read_eeprom(rig, 0x0068, &c) < 0)   /* get vfo status */
     {
         ignore = 1;
-        *vfo = rig->state.cache.vfo;
+        *vfo = CACHE(rig)->vfo;
         return RIG_OK;
     }
 
@@ -633,16 +651,10 @@ int ft857_get_vfo(RIG *rig, vfo_t *vfo)
 int ft857_set_vfo(RIG *rig, vfo_t vfo)
 {
     vfo_t curvfo;
-    int retval =  ft857_get_vfo(rig, &curvfo);
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
-    if (retval != RIG_OK)
-    {
-        rig_debug(RIG_DEBUG_ERR, "%s: error get_vfo '%s'\n", __func__,
-                  rigerror(retval));
-        return retval;
-    }
+    ft857_get_vfo(rig, &curvfo); // retval is always RIG_OK so ignore it
 
     if (curvfo == vfo)
     {
@@ -654,7 +666,7 @@ int ft857_set_vfo(RIG *rig, vfo_t vfo)
 
 int ft857_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    struct ft857_priv_data *p = (struct ft857_priv_data *) rig->state.priv;
+    struct ft857_priv_data *p = (struct ft857_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
@@ -673,7 +685,8 @@ int ft857_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
     return -RIG_OK;
 }
 
-static void get_mode(RIG *rig, struct ft857_priv_data *priv, rmode_t *mode,
+static void get_mode(RIG *rig, const struct ft857_priv_data *priv,
+                     rmode_t *mode,
                      pbwidth_t *width)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
@@ -746,7 +759,7 @@ static void get_mode(RIG *rig, struct ft857_priv_data *priv, rmode_t *mode,
 
 int ft857_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-    struct ft857_priv_data *p = (struct ft857_priv_data *) rig->state.priv;
+    struct ft857_priv_data *p = (struct ft857_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
@@ -783,7 +796,7 @@ int ft857_get_split_freq_mode(RIG *rig, vfo_t vfo, freq_t *freq, rmode_t *mode,
 
     if (RIG_OK == retcode)
     {
-        get_mode(rig, (struct ft857_priv_data *)rig->state.priv, mode, width);
+        get_mode(rig, (struct ft857_priv_data *)STATE(rig)->priv, mode, width);
     }
 
     ft857_send_cmd(rig, FT857_NATIVE_CAT_SET_VFOAB); /* always try and
@@ -793,7 +806,7 @@ int ft857_get_split_freq_mode(RIG *rig, vfo_t vfo, freq_t *freq, rmode_t *mode,
 
 int ft857_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 {
-    struct ft857_priv_data *p = (struct ft857_priv_data *) rig->state.priv;
+    struct ft857_priv_data *p = (struct ft857_priv_data *) STATE(rig)->priv;
     int n;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
@@ -826,7 +839,7 @@ int ft857_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 
 int ft857_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
-    struct ft857_priv_data *p = (struct ft857_priv_data *) rig->state.priv;
+    struct ft857_priv_data *p = (struct ft857_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
@@ -845,9 +858,10 @@ int ft857_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
     return RIG_OK;
 }
 
-static int ft857_get_pometer_level(RIG *rig, value_t *val)
+static int ft857_get_pometer_level(RIG *rig, value_t *val,
+                                   const cal_table_float_t *cal, float divider)
 {
-    struct ft857_priv_data *p = (struct ft857_priv_data *) rig->state.priv;
+    struct ft857_priv_data *p = (struct ft857_priv_data *) STATE(rig)->priv;
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
     if (check_cache_timeout(&p->tx_status_tv))
@@ -865,7 +879,7 @@ static int ft857_get_pometer_level(RIG *rig, value_t *val)
     {
         rig_debug(RIG_DEBUG_TRACE, "%s: bars=%d\n", __func__, p->tx_status & 0x0F);
         // does rig have 10 bars or 15?
-        val->f = (p->tx_status & 0x0F) / 10.0;
+        val->f = rig_raw2val_float(p->tx_status & 0x0F, cal) / divider;
     }
     else
     {
@@ -877,7 +891,7 @@ static int ft857_get_pometer_level(RIG *rig, value_t *val)
 
 static int ft857_get_smeter_level(RIG *rig, value_t *val)
 {
-    struct ft857_priv_data *p = (struct ft857_priv_data *) rig->state.priv;
+    struct ft857_priv_data *p = (struct ft857_priv_data *) STATE(rig)->priv;
     int n;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
@@ -899,6 +913,10 @@ static int ft857_get_smeter_level(RIG *rig, value_t *val)
 int ft857_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
+    freq_t freq;
+    rmode_t mode;
+    pbwidth_t width;
+    int freq_ms, mode_ms, width_ms;
 
     switch (level)
     {
@@ -906,7 +924,20 @@ int ft857_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         return ft857_get_smeter_level(rig, val);
 
     case RIG_LEVEL_RFPOWER:
-        return ft857_get_pometer_level(rig, val);
+    case RIG_LEVEL_RFPOWER_METER_WATTS:
+        rig_get_cache(rig, vfo, &freq, &freq_ms, &mode, &mode_ms, &width,
+                      &width_ms);
+
+        if (144000000.0f >= freq && 148000000.0f <= freq)
+        {
+            return ft857_get_pometer_level(rig, val, &rig->caps->rfpower_meter_cal, 2.0);
+        }
+        else if (420000000.0f >= freq && 450000000.0f <= freq)
+        {
+            return ft857_get_pometer_level(rig, val, &rig->caps->rfpower_meter_cal, 5.0);
+        }
+
+        return ft857_get_pometer_level(rig, val, &rig->caps->rfpower_meter_cal, 1.0);
 
     default:
         return -RIG_EINVAL;
@@ -917,7 +948,7 @@ int ft857_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
 int ft857_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {
-    struct ft857_priv_data *p = (struct ft857_priv_data *) rig->state.priv;
+    struct ft857_priv_data *p = (struct ft857_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called \n", __func__);
 
@@ -947,7 +978,6 @@ int ft857_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 int ft857_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
     unsigned char data[YAESU_CMD_LENGTH - 1];
-    int retval;
     int i;
     ptt_t ptt = RIG_PTT_ON;
 
@@ -958,7 +988,7 @@ int ft857_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     // cannot set freq while PTT is on
     for (i = 0; i < 10 && ptt == RIG_PTT_ON; ++i)
     {
-        retval = ft857_get_ptt(rig, vfo, &ptt);
+        int retval = ft857_get_ptt(rig, vfo, &ptt);
 
         if (retval != RIG_OK) { return retval; }
 
@@ -969,7 +999,7 @@ int ft857_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     to_bcd_be(data, (freq + 5) / 10, 8);
 
     rig_force_cache_timeout(&((struct ft857_priv_data *)
-                              rig->state.priv)->fm_status_tv);
+                              STATE(rig)->priv)->fm_status_tv);
 
     return ft857_send_icmd(rig, FT857_NATIVE_CAT_SET_FREQ, data);
 }
@@ -1033,7 +1063,7 @@ int ft857_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     }
 
     rig_force_cache_timeout(&((struct ft857_priv_data *)
-                              rig->state.priv)->fm_status_tv);
+                              STATE(rig)->priv)->fm_status_tv);
 
     return ft857_send_cmd(rig, index);
 }
@@ -1047,7 +1077,7 @@ int ft857_set_split_freq_mode(RIG *rig, vfo_t vfo, freq_t freq, rmode_t mode,
 
     retcode = rig_set_split_vfo(rig, RIG_VFO_A, RIG_SPLIT_ON, RIG_VFO_B);
 
-    if (retcode != RIG_OK) { RETURNFUNC(retcode); }
+    if (retcode != RIG_OK) { return retcode; }
 
 
     retcode = ft857_send_cmd(rig, FT857_NATIVE_CAT_SET_VFOAB);
@@ -1092,7 +1122,7 @@ int ft857_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
     n = ft857_send_cmd(rig, index);
 
     rig_force_cache_timeout(&((struct ft857_priv_data *)
-                              rig->state.priv)->tx_status_tv);
+                              STATE(rig)->priv)->tx_status_tv);
 
     if (n < 0 && n != -RIG_ERJCTED)
     {
@@ -1127,7 +1157,7 @@ int ft857_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
     if (ptt == RIG_PTT_OFF) { hl_usleep(200 * 1000); } // FT857 takes a bit to come out of PTT
 
     rig_force_cache_timeout(&((struct ft857_priv_data *)
-                              rig->state.priv)->tx_status_tv);
+                              STATE(rig)->priv)->tx_status_tv);
 
     if (n < 0 && n != -RIG_ERJCTED)
     {
