@@ -243,9 +243,9 @@ enum ft897_digi
 #define FT897_AM_TX_MODES       (RIG_MODE_AM)
 
 #define FT897_VFO_ALL           (RIG_VFO_A|RIG_VFO_B)
-#define FT897_ANTS              0
+#define FT897_ANTS              RIG_ANT_CURR
 
-const struct rig_caps ft897_caps =
+struct rig_caps ft897_caps =
 {
     RIG_MODEL(RIG_MODEL_FT897),
     .model_name =     "FT-897",
@@ -393,7 +393,7 @@ const struct rig_caps ft897_caps =
     .hamlib_check_rig_caps = HAMLIB_CHECK_RIG_CAPS
 };
 
-const struct rig_caps ft897d_caps =
+struct rig_caps ft897d_caps =
 {
     RIG_MODEL(RIG_MODEL_FT897D),
     .model_name =     "FT-897D",
@@ -545,7 +545,7 @@ int ft897_init(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
-    if ((rig->state.priv = calloc(1, sizeof(struct ft897_priv_data))) == NULL)
+    if ((STATE(rig)->priv = calloc(1, sizeof(struct ft897_priv_data))) == NULL)
     {
         return -RIG_ENOMEM;
     }
@@ -557,12 +557,12 @@ int ft897_cleanup(RIG *rig)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
@@ -583,7 +583,8 @@ int ft897_close(RIG *rig)
 
 /* ---------------------------------------------------------------------- */
 
-static inline long timediff(struct timeval *tv1, struct timeval *tv2)
+static inline long timediff(const struct timeval *tv1,
+                            const struct timeval *tv2)
 {
     struct timeval tv;
 
@@ -622,6 +623,7 @@ static int ft897_read_eeprom(RIG *rig, unsigned short addr, unsigned char *out)
 {
     unsigned char data[YAESU_CMD_LENGTH];
     int n;
+    hamlib_port_t *rp = RIGPORT(rig);
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
     memcpy(data, (char *)ncmd[FT897_NATIVE_CAT_EEPROM_READ].nseq,
@@ -630,9 +632,9 @@ static int ft897_read_eeprom(RIG *rig, unsigned short addr, unsigned char *out)
     data[0] = addr >> 8;
     data[1] = addr & 0xfe;
 
-    write_block(&rig->state.rigport, data, YAESU_CMD_LENGTH);
+    write_block(rp, data, YAESU_CMD_LENGTH);
 
-    if ((n = read_block(&rig->state.rigport, data, 2)) < 0)
+    if ((n = read_block(rp, data, 2)) < 0)
     {
         return n;
     }
@@ -649,7 +651,8 @@ static int ft897_read_eeprom(RIG *rig, unsigned short addr, unsigned char *out)
 
 static int ft897_get_status(RIG *rig, int status)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
+    hamlib_port_t *rp = RIGPORT(rig);
     struct timeval *tv;
     unsigned char *data;
     int len;
@@ -689,12 +692,11 @@ static int ft897_get_status(RIG *rig, int status)
         return -RIG_EINTERNAL;
     }
 
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
-    write_block(&rig->state.rigport, ncmd[status].nseq,
-                YAESU_CMD_LENGTH);
+    write_block(rp, ncmd[status].nseq, YAESU_CMD_LENGTH);
 
-    if ((n = read_block(&rig->state.rigport, data, len)) < 0)
+    if ((n = read_block(rp, data, len)) < 0)
     {
         return n;
     }
@@ -723,7 +725,7 @@ static int ft897_get_status(RIG *rig, int status)
 
 int ft897_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -744,7 +746,7 @@ int ft897_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
 int ft897_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -828,7 +830,7 @@ int ft897_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
 int ft897_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -849,7 +851,7 @@ int ft897_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 
 static int ft897_get_pometer_level(RIG *rig, value_t *val)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -878,7 +880,7 @@ static int ft897_get_pometer_level(RIG *rig, value_t *val)
 
 static int ft897_get_swr_level(RIG *rig, value_t *val)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -907,7 +909,7 @@ static int ft897_get_swr_level(RIG *rig, value_t *val)
 
 static int ft897_get_smeter_level(RIG *rig, value_t *val)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
     int n;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
@@ -927,7 +929,7 @@ static int ft897_get_smeter_level(RIG *rig, value_t *val)
 
 static int ft897_get_rawstr_level(RIG *rig, value_t *val)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -948,7 +950,7 @@ static int ft897_get_rawstr_level(RIG *rig, value_t *val)
 
 static int ft897_get_alc_level(RIG *rig, value_t *val)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -1012,7 +1014,7 @@ int ft897_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
 int ft897_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
 
@@ -1053,14 +1055,14 @@ static int ft897_send_cmd(RIG *rig, int index)
         return -RIG_EINTERNAL;
     }
 
-    write_block(&rig->state.rigport, ncmd[index].nseq, YAESU_CMD_LENGTH);
+    write_block(RIGPORT(rig), ncmd[index].nseq, YAESU_CMD_LENGTH);
     return ft817_read_ack(rig);
 }
 
 /*
  * The same for incomplete commands.
  */
-static int ft897_send_icmd(RIG *rig, int index, unsigned char *data)
+static int ft897_send_icmd(RIG *rig, int index, const unsigned char *data)
 {
     unsigned char cmd[YAESU_CMD_LENGTH];
 
@@ -1075,7 +1077,7 @@ static int ft897_send_icmd(RIG *rig, int index, unsigned char *data)
     cmd[YAESU_CMD_LENGTH - 1] = ncmd[index].nseq[YAESU_CMD_LENGTH - 1];
     memcpy(cmd, data, YAESU_CMD_LENGTH - 1);
 
-    write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
+    write_block(RIGPORT(rig), cmd, YAESU_CMD_LENGTH);
     return ft817_read_ack(rig);
 }
 
@@ -1095,7 +1097,7 @@ int ft897_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 
     /*invalidate frequency cache*/
     rig_force_cache_timeout(&((struct ft897_priv_data *)
-                              rig->state.priv)->fm_status_tv);
+                              STATE(rig)->priv)->fm_status_tv);
 
     return ft897_send_icmd(rig, FT897_NATIVE_CAT_SET_FREQ, data);
 }
@@ -1155,7 +1157,7 @@ int ft897_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     }
 
     rig_force_cache_timeout(&((struct ft897_priv_data *)
-                              rig->state.priv)->fm_status_tv);
+                              STATE(rig)->priv)->fm_status_tv);
 
     return ft897_send_cmd(rig, index);
 }
@@ -1183,7 +1185,7 @@ int ft897_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
     n = ft897_send_cmd(rig, index);
 
     rig_force_cache_timeout(&((struct ft897_priv_data *)
-                              rig->state.priv)->tx_status_tv);
+                              STATE(rig)->priv)->tx_status_tv);
 
     if (n < 0 && n != -RIG_ERJCTED)
     {
@@ -1203,7 +1205,7 @@ int ft897_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
     {
     case RIG_OP_TOGGLE:
         rig_force_cache_timeout(&((struct ft897_priv_data *)
-                                  rig->state.priv)->tx_status_tv);
+                                  STATE(rig)->priv)->tx_status_tv);
         index = FT897_NATIVE_CAT_SET_VFOAB;
         break;
 
@@ -1244,7 +1246,7 @@ int ft897_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
     n = ft897_send_cmd(rig, index);
 
     rig_force_cache_timeout(&((struct ft897_priv_data *)
-                              rig->state.priv)->tx_status_tv);
+                              STATE(rig)->priv)->tx_status_tv);
 
     if (n < 0 && n != -RIG_ERJCTED)
     {
@@ -1256,7 +1258,7 @@ int ft897_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo)
 
 int ft897_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo)
 {
-    struct ft897_priv_data *p = (struct ft897_priv_data *) rig->state.priv;
+    struct ft897_priv_data *p = (struct ft897_priv_data *) STATE(rig)->priv;
     int n;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s: called\n", __func__);
