@@ -54,8 +54,6 @@
  */
 
 
-#include <hamlib/config.h>
-
 // cppcheck-suppress *
 #include <stdlib.h>
 
@@ -124,7 +122,7 @@ static int  check_tuning_step(RIG *rig, vfo_t vfo, rmode_t mode,
  * vr5000 rigs capabilities.
  */
 
-const struct rig_caps vr5000_caps =
+struct rig_caps vr5000_caps =
 {
     RIG_MODEL(RIG_MODEL_VR5000),
     .model_name =         "VR-5000",
@@ -248,10 +246,10 @@ struct vr5000_priv_data
 
 int vr5000_init(RIG *rig)
 {
-    rig->state.priv = (struct vr5000_priv_data *) calloc(1,
-                      sizeof(struct vr5000_priv_data));
+    STATE(rig)->priv = (struct vr5000_priv_data *) calloc(1,
+                       sizeof(struct vr5000_priv_data));
 
-    if (!rig->state.priv) { return -RIG_ENOMEM; }
+    if (!STATE(rig)->priv) { return -RIG_ENOMEM; }
 
     return RIG_OK;
 }
@@ -264,12 +262,12 @@ int vr5000_cleanup(RIG *rig)
         return -RIG_EINVAL;
     }
 
-    if (rig->state.priv)
+    if (STATE(rig)->priv)
     {
-        free(rig->state.priv);
+        free(STATE(rig)->priv);
     }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
 
     return RIG_OK;
 }
@@ -280,14 +278,15 @@ int vr5000_cleanup(RIG *rig)
  */
 int vr5000_open(RIG *rig)
 {
-    struct vr5000_priv_data *priv = rig->state.priv;
-    unsigned char cmd[YAESU_CMD_LENGTH]   = { 0x00, 0x00, 0x00, 0x00, 0x00};
-    unsigned char b_off[YAESU_CMD_LENGTH] = { 0x00, 0x00, 0x00, 0x00, 0x31};
+    struct vr5000_priv_data *priv = STATE(rig)->priv;
+    hamlib_port_t *rp = RIGPORT(rig);
+    const unsigned char cmd[YAESU_CMD_LENGTH]   = { 0x00, 0x00, 0x00, 0x00, 0x00};
+    const unsigned char b_off[YAESU_CMD_LENGTH] = { 0x00, 0x00, 0x00, 0x00, 0x31};
 
     int retval;
 
     /* CAT write command on */
-    retval =  write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
+    retval =  write_block(rp, cmd, YAESU_CMD_LENGTH);
 
     if (retval != RIG_OK)
     {
@@ -295,7 +294,7 @@ int vr5000_open(RIG *rig)
     }
 
     /* disable RIG_VFO_B  (only on display) */
-    retval =  write_block(&rig->state.rigport, b_off, YAESU_CMD_LENGTH);
+    retval =  write_block(rp, b_off, YAESU_CMD_LENGTH);
 
     if (retval != RIG_OK)
     {
@@ -324,15 +323,15 @@ int vr5000_open(RIG *rig)
 
 int vr5000_close(RIG *rig)
 {
-    unsigned char cmd[YAESU_CMD_LENGTH] = { 0x00, 0x00, 0x00, 0x00, 0x80};
+    const unsigned char cmd[YAESU_CMD_LENGTH] = { 0x00, 0x00, 0x00, 0x00, 0x80};
 
-    return write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
+    return write_block(RIGPORT(rig), cmd, YAESU_CMD_LENGTH);
 }
 
 
 int vr5000_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-    struct vr5000_priv_data *priv = rig->state.priv;
+    struct vr5000_priv_data *priv = STATE(rig)->priv;
 
     return set_vr5000(rig, vfo, freq, priv->curr_mode, priv->curr_width,
                       priv->curr_ts);
@@ -342,7 +341,7 @@ int vr5000_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 int vr5000_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
 
-    struct vr5000_priv_data *priv = rig->state.priv;
+    const struct vr5000_priv_data *priv = STATE(rig)->priv;
     *freq = priv->curr_freq;
 
     return RIG_OK;
@@ -351,7 +350,7 @@ int vr5000_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
 int vr5000_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
-    struct vr5000_priv_data *priv = rig->state.priv;
+    struct vr5000_priv_data *priv = STATE(rig)->priv;
 
     if (check_tuning_step(rig, vfo, mode, priv->curr_ts) != RIG_OK)
     {
@@ -365,7 +364,7 @@ int vr5000_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
 int vr5000_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-    struct vr5000_priv_data *priv = rig->state.priv;
+    const struct vr5000_priv_data *priv = STATE(rig)->priv;
     *mode = priv->curr_mode;
     *width = priv->curr_width;
 
@@ -375,7 +374,7 @@ int vr5000_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
 int vr5000_set_ts(RIG *rig, vfo_t vfo, shortfreq_t ts)
 {
-    struct vr5000_priv_data *priv = rig->state.priv;
+    struct vr5000_priv_data *priv = STATE(rig)->priv;
     int retval;
 
     retval = check_tuning_step(rig, vfo, priv->curr_mode, ts);
@@ -393,7 +392,7 @@ int vr5000_set_ts(RIG *rig, vfo_t vfo, shortfreq_t ts)
 
 int vr5000_get_ts(RIG *rig, vfo_t vfo, shortfreq_t *ts)
 {
-    struct vr5000_priv_data *priv = rig->state.priv;
+    const struct vr5000_priv_data *priv = STATE(rig)->priv;
     *ts = priv->curr_ts;
 
     return RIG_OK;
@@ -404,16 +403,17 @@ int vr5000_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
     unsigned char cmd[YAESU_CMD_LENGTH] = { 0x00, 0x00, 0x00, 0x00, 0xe7};
     int retval;
+    hamlib_port_t *rp = RIGPORT(rig);
 
     if (level != RIG_LEVEL_RAWSTR)
     {
         return -RIG_EINVAL;
     }
 
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
     /* send READ STATUS(Meter only) cmd to rig  */
-    retval = write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
+    retval = write_block(rp, cmd, YAESU_CMD_LENGTH);
 
     if (retval < 0)
     {
@@ -421,7 +421,7 @@ int vr5000_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     }
 
     /* read back the 1 byte */
-    retval = read_block(&rig->state.rigport, cmd, 1);
+    retval = read_block(rp, cmd, 1);
 
     if (retval < 1)
     {
@@ -434,7 +434,6 @@ int vr5000_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     val->i = cmd[0] & 0x3f;
     rig_debug(RIG_DEBUG_ERR, "Read(%x) RawValue(%x): \n", cmd[0], val->i);
 
-
     return RIG_OK;
 }
 
@@ -443,11 +442,12 @@ int vr5000_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {
     unsigned char cmd[YAESU_CMD_LENGTH] = { 0x00, 0x00, 0x00, 0x00, 0xe7};
     int retval;
+    hamlib_port_t *rp = RIGPORT(rig);
 
-    rig_flush(&rig->state.rigport);
+    rig_flush(rp);
 
     /* send READ STATUS(Meter only) cmd to rig  */
-    retval = write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
+    retval = write_block(rp, cmd, YAESU_CMD_LENGTH);
 
     if (retval < 0)
     {
@@ -455,7 +455,7 @@ int vr5000_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
     }
 
     /* read back the 1 byte */
-    retval = read_block(&rig->state.rigport, cmd, 1);
+    retval = read_block(rp, cmd, 1);
 
     if (retval < 1)
     {
@@ -523,7 +523,7 @@ int mode2rig(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 void correct_frequency(RIG *rig, vfo_t vfo, freq_t curr_freq, freq_t *freq)
 {
 
-    struct vr5000_priv_data *priv = rig->state.priv;
+    const struct vr5000_priv_data *priv = STATE(rig)->priv;
     shortfreq_t ts = priv->curr_ts;
     unsigned long long correct_freq = (unsigned long long)curr_freq;
 
@@ -572,7 +572,8 @@ void correct_frequency(RIG *rig, vfo_t vfo, freq_t curr_freq, freq_t *freq)
 int set_vr5000(RIG *rig, vfo_t vfo, freq_t freq, rmode_t mode, pbwidth_t width,
                shortfreq_t ts)
 {
-    struct vr5000_priv_data *priv = rig->state.priv;
+    struct vr5000_priv_data *priv = STATE(rig)->priv;
+    hamlib_port_t *rp = RIGPORT(rig);
     unsigned char cmd_mode_ts[YAESU_CMD_LENGTH] = { 0x00, 0x00, 0x00, 0x00, 0x07};
     unsigned char cmd_freq[YAESU_CMD_LENGTH]    = { 0x00, 0x00, 0x00, 0x00, 0x01};
     static const unsigned char steps[] =
@@ -615,8 +616,7 @@ int set_vr5000(RIG *rig, vfo_t vfo, freq_t freq, rmode_t mode, pbwidth_t width,
     /* fill in m2 */
     cmd_mode_ts[1] = steps[i];
 
-    retval =  write_block(&rig->state.rigport, cmd_mode_ts,
-                          YAESU_CMD_LENGTH);
+    retval =  write_block(rp, cmd_mode_ts, YAESU_CMD_LENGTH);
 
     if (retval != RIG_OK)
     {
@@ -635,7 +635,7 @@ int set_vr5000(RIG *rig, vfo_t vfo, freq_t freq, rmode_t mode, pbwidth_t width,
     cmd_freq[3] = frq & 0xff;
 
     /* frequency set */
-    return write_block(&rig->state.rigport, cmd_freq, YAESU_CMD_LENGTH);
+    return write_block(rp, cmd_freq, YAESU_CMD_LENGTH);
 }
 
 
