@@ -28,14 +28,11 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
 #include "hamlib/rig.h"
-#include "bandplan.h"
 #include "serial.h"
 #include "misc.h"
 #include "yaesu.h"
@@ -210,7 +207,7 @@ struct vx1700_priv_data
         .width   = 1,   \
 }
 
-const struct rig_caps vx1700_caps =
+struct rig_caps vx1700_caps =
 {
     RIG_MODEL(RIG_MODEL_VX1700),
     .model_name =  "VX-1700",
@@ -240,7 +237,6 @@ const struct rig_caps vx1700_caps =
     .has_get_parm =  RIG_PARM_NONE,
     .has_set_parm =  RIG_PARM_NONE,
     .level_gran =  {
-        // cppcheck-suppress *
         [LVL_RFPOWER] = { .min = { .i = 0 }, .max = { .i = 2 } },
     },
     .parm_gran =  {},
@@ -340,7 +336,7 @@ static int vx1700_do_transaction(RIG *rig,
                                  const unsigned char cmd[YAESU_CMD_LENGTH],
                                  unsigned char *retbuf, size_t retbuf_len)
 {
-    struct rig_state    *rs;
+    hamlib_port_t *rp = RIGPORT(rig);
     unsigned char   default_retbuf[1];
     int         retval;
 
@@ -350,15 +346,14 @@ static int vx1700_do_transaction(RIG *rig,
         retbuf_len = sizeof(default_retbuf);
     }
 
-    rs = &rig->state;
     memset(retbuf, 0, retbuf_len);
 
-    rig_flush(&rs->rigport);
-    retval = write_block(&rs->rigport, cmd, YAESU_CMD_LENGTH);
+    rig_flush(rp);
+    retval = write_block(rp, cmd, YAESU_CMD_LENGTH);
 
     if (retval != RIG_OK) { return retval; }
 
-    retval = read_block(&rs->rigport, retbuf, retbuf_len);
+    retval = read_block(rp, retbuf, retbuf_len);
 
     if (retval != retbuf_len)
     {
@@ -403,7 +398,7 @@ static int vx1700_do_transaction(RIG *rig,
  *              ci      Command index of the ncmd table
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 static int vx1700_do_static_cmd(RIG *rig, unsigned char ci)
 {
@@ -430,7 +425,7 @@ static int vx1700_do_static_cmd(RIG *rig, unsigned char ci)
  *              p1-p4   Command parameters
  *
  * Returns:     RIG_OK if all called functions are successful,
- *              otherwise returns error from called functiion
+ *              otherwise returns error from called function
  */
 static int vx1700_do_dynamic_cmd(RIG *rig, unsigned char ci,
                                  unsigned char p1, unsigned char p2,
@@ -713,11 +708,11 @@ static int vx1700_init(RIG *rig)
 
     rig_debug(RIG_DEBUG_TRACE, "%s\n", __func__);
 
-    rig->state.priv = calloc(1, sizeof(struct vx1700_priv_data));
+    STATE(rig)->priv = calloc(1, sizeof(struct vx1700_priv_data));
 
-    if (rig->state.priv == NULL) { return -RIG_ENOMEM; }
+    if (STATE(rig)->priv == NULL) { return -RIG_ENOMEM; }
 
-    priv = rig->state.priv;
+    priv = STATE(rig)->priv;
 
     priv->ch = 1;
     return RIG_OK;
@@ -725,8 +720,8 @@ static int vx1700_init(RIG *rig)
 
 static int vx1700_open(RIG *rig)
 {
-    struct vx1700_priv_data *priv = (struct vx1700_priv_data *)rig->state.priv;
-    struct rig_state        *state = &rig->state;
+    struct vx1700_priv_data *priv = (struct vx1700_priv_data *)STATE(rig)->priv;
+    struct rig_state        *state = STATE(rig);
     int             ret;
 
     rig_debug(RIG_DEBUG_TRACE, "%s\n", __func__);
@@ -748,9 +743,9 @@ static int vx1700_cleanup(RIG *rig)
 {
     rig_debug(RIG_DEBUG_TRACE, "%s\n", __func__);
 
-    if (rig->state.priv != NULL) { free(rig->state.priv); }
+    if (STATE(rig)->priv != NULL) { free(STATE(rig)->priv); }
 
-    rig->state.priv = NULL;
+    STATE(rig)->priv = NULL;
     return RIG_OK;
 }
 
@@ -763,7 +758,8 @@ static const char *vx1700_get_info(RIG *rig)
 
 static int vx1700_set_vfo(RIG *rig, vfo_t vfo)
 {
-    struct vx1700_priv_data *priv = (struct vx1700_priv_data *)rig->state.priv;
+    const struct vx1700_priv_data *priv = (struct vx1700_priv_data *)
+                                          STATE(rig)->priv;
 
     rig_debug(RIG_DEBUG_TRACE, "%s, vfo=%s\n", __func__, rig_strvfo(vfo));
 
@@ -816,7 +812,7 @@ static int vx1700_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq)
     rig_debug(RIG_DEBUG_TRACE, "%s: freq=%f\n", __func__, tx_freq);
     int err = rig_set_split_vfo(rig, RIG_VFO_A, RIG_SPLIT_ON, RIG_VFO_B);
 
-    if (err != RIG_OK) { RETURNFUNC(err); }
+    if (err != RIG_OK) { return err; }
 
     return vx1700_do_freq_cmd(rig, VX1700_NATIVE_TX_FREQ_SET, tx_freq);
 }
@@ -1129,8 +1125,8 @@ static int vx1700_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
 static int vx1700_set_mem(RIG *rig, vfo_t vfo, int ch)
 {
-    struct vx1700_priv_data *priv = (struct vx1700_priv_data *)rig->state.priv;
-    struct rig_state *state = &rig->state;
+    struct vx1700_priv_data *priv = (struct vx1700_priv_data *)STATE(rig)->priv;
+    const struct rig_state *state = STATE(rig);
 
     if (! vx1700_channel_is_ok(ch)) { return -RIG_EINVAL; }
 
@@ -1152,8 +1148,8 @@ static int vx1700_set_mem(RIG *rig, vfo_t vfo, int ch)
 
 static int vx1700_get_mem(RIG *rig, vfo_t vfo, int *ch)
 {
-    struct vx1700_priv_data *priv = (struct vx1700_priv_data *)rig->state.priv;
-    struct rig_state        *state = &rig->state;
+    struct vx1700_priv_data *priv = (struct vx1700_priv_data *)STATE(rig)->priv;
+    const struct rig_state        *state = STATE(rig);
     unsigned char       channel = 0;
 
     if (vfo == RIG_VFO_CURR) { vfo = state->current_vfo; }
@@ -1182,7 +1178,8 @@ static int vx1700_get_mem(RIG *rig, vfo_t vfo, int *ch)
 
 static int vx1700_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 {
-    struct vx1700_priv_data *priv = (struct vx1700_priv_data *)rig->state.priv;
+    const struct vx1700_priv_data *priv = (struct vx1700_priv_data *)
+                                          STATE(rig)->priv;
 
     (void) rig;
     (void) vfo;
