@@ -20,7 +20,6 @@
  *
  */
 
-#include <hamlib/config.h>
 
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
@@ -72,7 +71,7 @@
  */
 #define CHKPPRET(a) \
     do { int _retval = a; if (_retval != RIG_OK) \
-        {par_unlock (&rot->state.rotport);return _retval; }} while(0)
+        {par_unlock (ROTPORT(rot));return _retval; }} while(0)
 
 static int ars_init(ROT *rot);
 static int ars_cleanup(ROT *rot);
@@ -92,8 +91,8 @@ static void *handle_set_position(void *);
 
 static int ars_clear_ctrl_pin(ROT *rot, unsigned char pin)
 {
-    hamlib_port_t *pport = &rot->state.rotport;
-    struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
+    hamlib_port_t *pport = ROTPORT(rot);
+    struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
 
     priv->pp_control &= ~pin;
 
@@ -102,8 +101,8 @@ static int ars_clear_ctrl_pin(ROT *rot, unsigned char pin)
 
 static int ars_set_ctrl_pin(ROT *rot, unsigned char pin)
 {
-    hamlib_port_t *pport = &rot->state.rotport;
-    struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
+    hamlib_port_t *pport = ROTPORT(rot);
+    struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
 
     priv->pp_control |= pin;
 
@@ -112,8 +111,8 @@ static int ars_set_ctrl_pin(ROT *rot, unsigned char pin)
 
 static int ars_clear_data_pin(ROT *rot, unsigned char pin)
 {
-    hamlib_port_t *pport = &rot->state.rotport;
-    struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
+    hamlib_port_t *pport = ROTPORT(rot);
+    struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
 
     priv->pp_data &= ~pin;
 
@@ -122,8 +121,8 @@ static int ars_clear_data_pin(ROT *rot, unsigned char pin)
 
 static int ars_set_data_pin(ROT *rot, unsigned char pin)
 {
-    hamlib_port_t *pport = &rot->state.rotport;
-    struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
+    hamlib_port_t *pport = ROTPORT(rot);
+    struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
 
     priv->pp_data |= pin;
 
@@ -147,16 +146,16 @@ ars_init(ROT *rot)
         return -RIG_EINVAL;
     }
 
-    rot->state.priv = (struct ars_priv_data *)calloc(1,
-                      sizeof(struct ars_priv_data));
+    ROTSTATE(rot)->priv = (struct ars_priv_data *)calloc(1,
+                          sizeof(struct ars_priv_data));
 
-    if (!rot->state.priv)
+    if (!ROTSTATE(rot)->priv)
     {
         /* whoops! memory shortage! */
         return -RIG_ENOMEM;
     }
 
-    priv = rot->state.priv;
+    priv = ROTSTATE(rot)->priv;
 
     priv->pp_control = 0;
     priv->pp_data = 0;
@@ -178,10 +177,10 @@ ars_cleanup(ROT *rot)
         return -RIG_EINVAL;
     }
 
-    if (rot->state.priv)
+    if (ROTSTATE(rot)->priv)
     {
-        free(rot->state.priv);
-        rot->state.priv = NULL;
+        free(ROTSTATE(rot)->priv);
+        ROTSTATE(rot)->priv = NULL;
     }
 
     return RIG_OK;
@@ -195,7 +194,7 @@ ars_open(ROT *rot)
 
 #ifdef HAVE_PTHREAD
     {
-        struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
+        struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
         pthread_attr_t attr;
         int retcode;
 
@@ -221,7 +220,7 @@ int
 ars_close(ROT *rot)
 {
 #ifdef HAVE_PTHREAD
-    struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
+    struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
 
     pthread_cancel(priv->thread);
 #endif
@@ -235,8 +234,8 @@ ars_close(ROT *rot)
 int
 ars_stop(ROT *rot)
 {
-    struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
-    hamlib_port_t *pport = &rot->state.rotport;
+    struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
+    hamlib_port_t *pport = ROTPORT(rot);
 
     rig_debug(RIG_DEBUG_TRACE, "%s called, brake was %s\n", __func__,
               priv->brake_off ? "OFF" : "ON");
@@ -265,8 +264,8 @@ ars_stop(ROT *rot)
 int
 ars_move(ROT *rot, int direction, int speed)
 {
-    struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
-    hamlib_port_t *pport = &rot->state.rotport;
+    struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
+    hamlib_port_t *pport = ROTPORT(rot);
     int need_settle_delay = 0;
 
     rig_debug(RIG_DEBUG_TRACE, "%s called%s%s%s%s%s\n", __func__,
@@ -426,7 +425,7 @@ static int angle_in_range(float angle, float angle_base, float range)
 static void *handle_set_position(void *arg)
 {
     ROT *rot = (ROT *) arg;
-    struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
+    struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
     int retcode;
 
     while (1)
@@ -584,7 +583,7 @@ int
 ars_set_position(ROT *rot, azimuth_t az, elevation_t el)
 {
 #ifdef HAVE_PTHREAD
-    struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
+    struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
 
     /* will be picked by handle_set_position() next polling tick */
     priv->target_az = az;
@@ -607,9 +606,9 @@ static int comparunsigned(const void *a, const void *b)
 int
 ars_get_position(ROT *rot, azimuth_t *az, elevation_t *el)
 {
-    struct ars_priv_data *priv = (struct ars_priv_data *)rot->state.priv;
-    struct rot_state *rs = &rot->state;
-    hamlib_port_t *pport = &rs->rotport;
+    const struct ars_priv_data *priv = (struct ars_priv_data *)ROTSTATE(rot)->priv;
+    struct rot_state *rs = ROTSTATE(rot);
+    hamlib_port_t *pport = ROTPORT(rot);
     int i, num_sample;
     unsigned az_samples[NUM_SAMPLES], az_value;
     unsigned el_samples[NUM_SAMPLES], el_value;
