@@ -19,7 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <string.h>  /* String function definitions */
@@ -27,10 +26,6 @@
 
 #include "hamlib/rotator.h"
 #include "serial.h"
-#include "misc.h"
-#include "register.h"
-
-#include "gs232a.h"
 
 #define EOM "\r"
 #define REPLY_EOM "\r"
@@ -57,19 +52,17 @@ static int
 gs232_transaction(ROT *rot, const char *cmdstr,
                   char *data, size_t data_len)
 {
-    struct rot_state *rs;
+    hamlib_port_t *rotp = ROTPORT(rot);
     int retval;
     int retry_read = 0;
 
-    rs = &rot->state;
-
 transaction_write:
 
-    rig_flush(&rs->rotport);
+    rig_flush(rotp);
 
     if (cmdstr)
     {
-        retval = write_block(&rs->rotport, (unsigned char *) cmdstr, strlen(cmdstr));
+        retval = write_block(rotp, (unsigned char *) cmdstr, strlen(cmdstr));
 
         if (retval != RIG_OK)
         {
@@ -89,12 +82,12 @@ transaction_write:
     }
 
     memset(data, 0, data_len);
-    retval = read_string(&rs->rotport, (unsigned char *) data, data_len,
+    retval = read_string(rotp, (unsigned char *) data, data_len,
                          REPLY_EOM, strlen(REPLY_EOM), 0, 1);
 
     if (retval < 0)
     {
-        if (retry_read++ < rot->state.rotport.retry)
+        if (retry_read++ < rotp->retry)
         {
             goto transaction_write;
         }
@@ -110,7 +103,7 @@ transaction_write:
         rig_debug(RIG_DEBUG_ERR, "%s: Command is not correctly terminated '%s'\n",
                   __func__, data);
 
-        if (retry_read++ < rig->state.rotport.retry)
+        if (retry_read++ < rotp->retry)
         {
             goto transaction_write;
         }
@@ -144,7 +137,7 @@ static int
 gs232_wo_transaction(ROT *rot, const char *cmdstr,
                      char *data, size_t data_len)
 {
-    return write_block(&rot->state.rotport, (unsigned char *) cmdstr,
+    return write_block(ROTPORT(rot), (unsigned char *) cmdstr,
                        strlen(cmdstr));
 }
 
@@ -181,17 +174,37 @@ static int
 gs232_rot_get_position(ROT *rot, azimuth_t *az, elevation_t *el)
 {
     char posbuf[32];
+    // these really shouldn't be static but it's fixing faulty firmware -- see below
+    static int expected = 12;
+    static int expected_flag = 0;
     int retval;
 
     rig_debug(RIG_DEBUG_TRACE, "%s called\n", __func__);
 
-    retval = gs232_transaction(rot, "C2" EOM, posbuf, sizeof(posbuf));
+    if (expected_flag == 0)
+    {
+        ROTPORT(rot)->retry = 0;
+        expected_flag = 1;
+    }
 
-    if (retval != RIG_OK || strlen(posbuf) < 10)
+    retval = gs232_transaction(rot, "C2" EOM, posbuf, expected);
+
+    if (strlen(posbuf) < 10)
     {
         return retval;
     }
 
+    // AF6SA WRC - Wifi Rotator Controller does not provide EOM byte so we allow timeout
+    // Still returns 10 chars though
+    if (strlen(posbuf) == 10 && expected == 12)
+    {
+        rig_debug(RIG_DEBUG_WARN,
+                  "%s: rotor didn't send CR...assuming it won't in the future\n", __func__);
+        retval = RIG_OK;
+        expected = 11; // we won't expect the CR
+        ROTPORT(rot)->retry = 3;
+    }
+
     /* parse */
     if (sscanf(posbuf + 2, "%f", az) != 1)
     {
@@ -240,7 +253,7 @@ const struct rot_caps gs232_generic_rot_caps =
     ROT_MODEL(ROT_MODEL_GS232_GENERIC),
     .model_name =     "GS-232 Generic",
     .mfg_name =       "Various",
-    .version =        "20220109.0",
+    .version =        "20240921.0",
     .copyright =      "LGPL",
     .status =         RIG_STATUS_STABLE,
     .rot_type =       ROT_TYPE_AZEL,
@@ -254,7 +267,7 @@ const struct rot_caps gs232_generic_rot_caps =
     .write_delay =  0,
     .post_write_delay =  0,
     .timeout =  400,
-    .retry =  3,
+    .retry =  1,
 
     .min_az =     -180.0,
     .max_az =     450.0,  /* vary according to rotator type */
@@ -276,7 +289,7 @@ const struct rot_caps amsat_lvb_rot_caps =
     ROT_MODEL(ROT_MODEL_LVB),
     .model_name =     "LVB Tracker",
     .mfg_name =       "AMSAT",
-    .version =        "20220109.0",
+    .version =        "20240921.0",
     .copyright =      "LGPL",
     .status =         RIG_STATUS_STABLE,
     .rot_type =       ROT_TYPE_AZEL,
@@ -313,7 +326,7 @@ const struct rot_caps st2_rot_caps =
     ROT_MODEL(ROT_MODEL_ST2),
     .model_name =     "GS232/ST2",
     .mfg_name =       "FoxDelta",
-    .version =        "20220109.0",
+    .version =        "20240921.0",
     .copyright =      "LGPL",
     .status =         RIG_STATUS_STABLE,
     .rot_type =       ROT_TYPE_AZEL,
@@ -341,7 +354,7 @@ const struct rot_caps st2_rot_caps =
 
 /* ************************************************************************* */
 /*
- * F1TE Tracker, GS232 withtout position feedback
+ * F1TE Tracker, GS232 without position feedback
  *
  * http://www.f1te.org/index.php?option=com_content&view=article&id=19&Itemid=39
  */
@@ -351,7 +364,7 @@ const struct rot_caps f1tetracker_rot_caps =
     ROT_MODEL(ROT_MODEL_F1TETRACKER),
     .model_name =     "GS232/F1TE Tracker",
     .mfg_name =       "F1TE",
-    .version =        "20220109.0",
+    .version =        "20240921.0",
     .copyright =      "LGPL",
     .status =         RIG_STATUS_STABLE,
     .rot_type =       ROT_TYPE_AZEL,
