@@ -18,11 +18,9 @@
  *
  */
 
-#include <hamlib/config.h>
 
 #include <stdio.h>
 #include <string.h>
-#include <ctype.h>
 
 #include "hamlib/rotator.h"
 #include "serial.h"
@@ -165,20 +163,18 @@ static int
 rc2800_transaction(ROT *rot, const char *cmdstr,
                    char *data, size_t data_len)
 {
-    struct rot_state *rs;
+    hamlib_port_t *rotp = ROTPORT(rot);
     int retval;
     int retry_read = 0;
     char replybuf[BUFSZ];
 
-    rs = &rot->state;
-
 transaction_write:
 
-    rig_flush(&rs->rotport);
+    rig_flush(rotp);
 
     if (cmdstr)
     {
-        retval = write_block(&rs->rotport, (unsigned char *) cmdstr, strlen(cmdstr));
+        retval = write_block(rotp, (unsigned char *) cmdstr, strlen(cmdstr));
 
         if (retval != RIG_OK)
         {
@@ -199,7 +195,7 @@ transaction_write:
 
     /* then comes the answer */
     memset(data, 0, data_len);
-    retval = read_string(&rs->rotport, (unsigned char *) data, data_len, CR LF,
+    retval = read_string(rotp, (unsigned char *) data, data_len, CR LF,
                          strlen(CR LF), 0, 1);
 
     // some models seem to echo -- so we'll check and read again if echoed
@@ -207,7 +203,7 @@ transaction_write:
     if (cmdstr && strncmp(data, cmdstr, strlen(data) - 1) == 0)
     {
         memset(data, 0, data_len);
-        retval = read_string(&rs->rotport, (unsigned char *) data, data_len, CR LF,
+        retval = read_string(rotp, (unsigned char *) data, data_len, CR LF,
                              strlen(CR LF), 0, 1);
     }
 
@@ -215,13 +211,13 @@ transaction_write:
     if (strlen(data) == 1)
     {
         memset(data, 0, data_len);
-        retval = read_string(&rs->rotport, (unsigned char *) data, data_len, CR LF,
+        retval = read_string(rotp, (unsigned char *) data, data_len, CR LF,
                              strlen(CR LF), 0, 1);
     }
 
     if (retval < 0)
     {
-        if (retry_read++ < rot->state.rotport.retry)
+        if (retry_read++ < rotp->retry)
         {
             goto transaction_write;
         }
