@@ -19,7 +19,6 @@
  *
  */
 
-#include <hamlib/config.h>
 
 #include <stdlib.h>
 #include <string.h>  /* String function definitions */
@@ -30,7 +29,6 @@
 #include <num_stdio.h>
 
 #include "serial.h"
-#include "misc.h"
 #include "register.h"
 
 #include "meade.h"
@@ -98,20 +96,18 @@ struct meade_priv_data
 static int meade_transaction(ROT *rot, const char *cmdstr,
                              char *data, size_t *data_len, size_t expected_return_length)
 {
-    struct rot_state *rs;
+    hamlib_port_t *rotp = ROTPORT(rot);
     int return_value;
     int retry_read = 0;
 
-    rs = &rot->state;
-
     while (1)
     {
 transaction:
-        rig_flush(&rs->rotport);
+        rig_flush(rotp);
 
         if (cmdstr)
         {
-            return_value = write_block(&rs->rotport, (unsigned char *) cmdstr,
+            return_value = write_block(rotp, (unsigned char *) cmdstr,
                                        strlen(cmdstr));
 
             if (return_value != RIG_OK)
@@ -125,7 +121,7 @@ transaction:
            return value is expected, Strings end with '#' */
         if (data != NULL)
         {
-            return_value = read_string(&rs->rotport, (unsigned char *) data,
+            return_value = read_string(rotp, (unsigned char *) data,
                                        expected_return_length + 1,
                                        "\r\n", strlen("\r\n"), 0, 1);
 
@@ -136,7 +132,7 @@ transaction:
             }
             else
             {
-                if (retry_read++ >= rot->state.rotport.retry)
+                if (retry_read++ >= rotp->retry)
                 {
                     rig_debug(RIG_DEBUG_ERR, "%s: read_string error %s\n", __func__,
                               rigerror(return_value));
@@ -163,19 +159,19 @@ static int meade_init(ROT *rot)
 {
     struct meade_priv_data *priv;
 
-    rot->state.priv = (struct meade_priv_data *)
-                      calloc(1, sizeof(struct meade_priv_data));
+    ROTSTATE(rot)->priv = (struct meade_priv_data *)
+                          calloc(1, sizeof(struct meade_priv_data));
 
-    if (!rot->state.priv)
+    if (!ROTSTATE(rot)->priv)
     {
         return -RIG_ENOMEM;
     }
 
-    priv = rot->state.priv;
+    priv = ROTSTATE(rot)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called version %s\n", __func__,
               rot->caps->version);
-    rot->state.rotport.type.rig = RIG_PORT_SERIAL;
+    ROTPORT(rot)->type.rig = RIG_PORT_SERIAL;
 
     priv->az = priv->el = 0;
 
@@ -191,12 +187,12 @@ static int meade_cleanup(ROT *rot)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
-    if (rot->state.priv)
+    if (ROTSTATE(rot)->priv)
     {
-        free(rot->state.priv);
+        free(ROTSTATE(rot)->priv);
     }
 
-    rot->state.priv = NULL;
+    ROTSTATE(rot)->priv = NULL;
 
     return RIG_OK;
 }
@@ -208,7 +204,7 @@ static int meade_open(ROT *rot)
 {
     char return_str[BUFSIZE];
     size_t return_str_size = 0;
-    struct meade_priv_data *priv = (struct meade_priv_data *)rot->state.priv;
+    struct meade_priv_data *priv = (struct meade_priv_data *)ROTSTATE(rot)->priv;
     int retval;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
@@ -261,7 +257,7 @@ static int meade_close(ROT *rot)
  */
 static int meade_set_position(ROT *rot, azimuth_t az, elevation_t el)
 {
-    struct meade_priv_data *priv = (struct meade_priv_data *)rot->state.priv;
+    struct meade_priv_data *priv = (struct meade_priv_data *)ROTSTATE(rot)->priv;
     char cmd_str[BUFSIZE];
     char return_str[BUFSIZE];
     size_t return_str_size;
@@ -367,7 +363,7 @@ static int meade_get_position(ROT *rot, azimuth_t *az, elevation_t *el)
  */
 static int meade_stop(ROT *rot)
 {
-    struct meade_priv_data *priv = (struct meade_priv_data *)rot->state.priv;
+    struct meade_priv_data *priv = (struct meade_priv_data *)ROTSTATE(rot)->priv;
     azimuth_t az;
     elevation_t el;
 
@@ -411,7 +407,8 @@ static int meade_reset(ROT *rot, rot_reset_t reset)
  */
 static int meade_move(ROT *rot, int direction, int speed)
 {
-    struct meade_priv_data *priv = (struct meade_priv_data *)rot->state.priv;
+    const struct meade_priv_data *priv = (struct meade_priv_data *)ROTSTATE(
+            rot)->priv;
 
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
     rig_debug(RIG_DEBUG_TRACE, "%s: Direction = %d, Speed = %d\n", __func__,
@@ -441,7 +438,8 @@ static int meade_move(ROT *rot, int direction, int speed)
 static const char *meade_get_info(ROT *rot)
 {
     static char buf[256]; // this is not thread-safe but not important either
-    struct meade_priv_data *priv = (struct meade_priv_data *)rot->state.priv;
+    const struct meade_priv_data *priv = (struct meade_priv_data *)ROTSTATE(
+            rot)->priv;
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
     SNPRINTF(buf, sizeof(buf),
@@ -497,9 +495,6 @@ const struct rot_caps meade_caps =
     .move =             meade_move,
 
     .get_info =         meade_get_info,
-
-    .get_conf =         rot_get_conf,
-    .set_conf =         rot_set_conf,
 };
 
 DECLARE_INITROT_BACKEND(meade)
