@@ -1,6 +1,14 @@
 // can run this using rigctl/rigctld and socat pty devices
 // gcc -o simyaesu simyaesu.c
-#define _XOPEN_SOURCE 600
+#define _XOPEN_SOURCE 700
+// since we are POSIX here we need this
+#if 0
+struct ip_mreq
+{
+    int dummy;
+};
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
@@ -62,6 +70,8 @@ getmyline(int fd, char *buf)
         if (c == ';') { return strlen(buf); }
     }
 
+    if (strlen(buf) == 0) { hl_usleep(10 * 1000); }
+
     return strlen(buf);
 }
 
@@ -143,7 +153,7 @@ int main(int argc, char *argv[])
         else if (strcmp(buf, "RM5;") == 0)
         {
             printf("%s\n", buf);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             pbuf = "RM5100000;";
             n = write(fd, pbuf, strlen(pbuf));
             //printf("n=%d\n", n);
@@ -153,7 +163,7 @@ int main(int argc, char *argv[])
         else if (strcmp(buf, "RM8;") == 0)
         {
             printf("%s\n", buf);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             pbuf = "RM8197000;";
             n = write(fd, pbuf, strlen(pbuf));
             //printf("n=%d\n", n);
@@ -163,7 +173,7 @@ int main(int argc, char *argv[])
         else if (strcmp(buf, "RM9;") == 0)
         {
             printf("%s\n", buf);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             pbuf = "RM9089000;";
             n = write(fd, pbuf, strlen(pbuf));
             //printf("n=%d\n", n);
@@ -174,7 +184,7 @@ int main(int argc, char *argv[])
         else if (strcmp(buf, "AN0;") == 0)
         {
             printf("%s\n", buf);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             pbuf = "AN030;";
             n = write(fd, pbuf, strlen(pbuf));
             //printf("n=%d\n", n);
@@ -205,7 +215,7 @@ int main(int argc, char *argv[])
         else if (strcmp(buf, "IF;") == 0)
         {
             printf("%s\n", buf);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             pbuf = "IF00107041000+000000200000;";
             n = write(fd, pbuf, strlen(pbuf));
             //printf("n=%d\n", n);
@@ -215,7 +225,7 @@ int main(int argc, char *argv[])
         else if (strcmp(buf, "ID;") == 0)
         {
             printf("%s\n", buf);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             int id = NC_RIGID_FT991;
             SNPRINTF(buf, sizeof(buf), "ID%03d;", id);
             n = write(fd, buf, strlen(buf));
@@ -226,7 +236,7 @@ int main(int argc, char *argv[])
         else if (strcmp(buf, "AI;") == 0)
         {
             printf("%s\n", buf);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             SNPRINTF(buf, sizeof(buf), "AI0;");
             n = write(fd, buf, strlen(buf));
             //printf("n=%d\n", n);
@@ -235,7 +245,7 @@ int main(int argc, char *argv[])
         }
         else if (strcmp(buf, "AI0;") == 0)
         {
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
         }
         else if (strcmp(buf, "AB;") == 0)
         {
@@ -249,7 +259,7 @@ int main(int argc, char *argv[])
             if (strcmp(buf, "AI;"))
             {
                 printf("%s\n", buf);
-                usleep(50 * 1000);
+                hl_usleep(50 * 1000);
                 n = fprintf(fp, "%s", "AI0;");
                 printf("n=%d\n", n);
 
@@ -261,15 +271,15 @@ int main(int argc, char *argv[])
         else if (strcmp(buf, "VS") == 0 && strlen(buf) > 3)
         {
             curr_vfo = buf[3] == '1' ? RIG_VFO_B : RIG_VFO_A;
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
         }
         else if (strcmp(buf, "VS;") == 0)
         {
             printf("%s\n", buf);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             pbuf = "VS0;";
 
-            if (curr_vfo == RIG_VFO_B || curr_vfo == RIG_VFO_SUB) { pbuf[2] = '1'; }
+            if (curr_vfo == RIG_VFO_B || curr_vfo == RIG_VFO_SUB) { pbuf = "VS1"; }
 
             n = write(fd, pbuf, strlen(pbuf));
             printf("%s\n", pbuf);
@@ -278,7 +288,7 @@ int main(int argc, char *argv[])
         }
         else if (strcmp(buf, "FT;") == 0)
         {
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             SNPRINTF(resp, sizeof(resp), "FT%c;", tx_vfo);
             printf(" FT response#1=%s, tx_vfo=%c\n", resp, tx_vfo);
             n = write(fd, resp, strlen(resp));
@@ -296,7 +306,7 @@ int main(int argc, char *argv[])
         }
         else if (strcmp(buf, "MD0;") == 0)
         {
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             SNPRINTF(resp, sizeof(resp), "MD0%c;", modeA);
             n = write(fd, resp, strlen(resp));
 
@@ -308,7 +318,7 @@ int main(int argc, char *argv[])
         }
         else if (strcmp(buf, "MD1;") == 0)
         {
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             SNPRINTF(resp, sizeof(resp), "MD1%c;", modeB);
             n = write(fd, resp, strlen(resp));
 
@@ -320,7 +330,7 @@ int main(int argc, char *argv[])
         }
         else if (strcmp(buf, "SM0;") == 0)
         {
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             SNPRINTF(resp, sizeof(resp), "SM0111;");
             n = write(fd, resp, strlen(resp));
 
@@ -328,7 +338,7 @@ int main(int argc, char *argv[])
         }
         else if (strcmp(buf, "TX;") == 0)
         {
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             SNPRINTF(resp, sizeof(resp), "TX%d;", ptt);
             n = write(fd, resp, strlen(resp));
 
@@ -336,7 +346,7 @@ int main(int argc, char *argv[])
         }
         else if (strncmp(buf, "TX", 2) == 0)
         {
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             ptt = buf[2] == '0' ? 0 : 1;
         }
         else if (strcmp(buf, "EX032;") == 0)
@@ -344,7 +354,7 @@ int main(int argc, char *argv[])
             static int ant = 0;
             ant = (ant + 1) % 3;
             printf("%s\n", buf);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             SNPRINTF(buf, sizeof(buf), "EX032%1d;", ant);
             n = write(fd, buf, strlen(buf));
             //printf("n=%d\n", n);
@@ -354,39 +364,39 @@ int main(int argc, char *argv[])
         else if (strcmp(buf, "NA0;") == 0)
         {
             SNPRINTF(buf, sizeof(buf), "NA00;");
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             n = write(fd, buf, strlen(buf));
             //printf("%s n=%d\n", buf, n);
         }
         else if (strcmp(buf, "RF0;") == 0)
         {
             SNPRINTF(buf, sizeof(buf), "RF0%d;", roofing_filter_main);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             n = write(fd, buf, strlen(buf));
         }
         else if (strcmp(buf, "RF1;") == 0)
         {
             SNPRINTF(buf, sizeof(buf), "RF1%d;", roofing_filter_sub);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             n = write(fd, buf, strlen(buf));
         }
         else if (strncmp(buf, "RF", 2) == 0)
         {
             SNPRINTF(buf, sizeof(buf), "RF%c%d;", buf[2],
                      buf[2] == 0 ? roofing_filter_main : roofing_filter_sub);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             n = write(fd, buf, strlen(buf));
         }
         else if (strcmp(buf, "SH0;") == 0)
         {
             SNPRINTF(buf, sizeof(buf), "SH%c%02d;", buf[2], width_main);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             n = write(fd, buf, strlen(buf));
         }
         else if (strcmp(buf, "SH1;") == 0)
         {
             SNPRINTF(buf, sizeof(buf), "SH%c%02d;", buf[2], width_sub);
-            usleep(50 * 1000);
+            hl_usleep(50 * 1000);
             n = write(fd, buf, strlen(buf));
         }
         else if (strncmp(buf, "SH", 2) == 0 && strlen(buf) > 4)
@@ -409,7 +419,7 @@ int main(int argc, char *argv[])
             SNPRINTF(buf, sizeof(buf), "EX039%d;", ex039);
             n = write(fd, buf, strlen(buf));
         }
-        else if (strncmp(buf, "EX039", 3) == 0)
+        else if (strncmp(buf, "EX039", 5) == 0)
         {
             sscanf(buf, "EX039%d", &ex039);
         }
