@@ -35,9 +35,8 @@
 #include <stdarg.h>
 #include <stdio.h>  /* Standard input/output definitions */
 #include <string.h> /* String function definitions */
-#include <fcntl.h>  /* File control definitions */
-#include <errno.h>  /* Error number definitions */
 #include <sys/types.h>
+#include <errno.h>
 
 #ifdef ANDROID
 #  include <android/log.h>
@@ -150,6 +149,19 @@ void HAMLIB_API rig_set_debug(enum rig_debug_level_e debug_level)
     rig_debug_level = debug_level;
 }
 
+/**
+ * \brief Get the current debug level.
+ *
+ * \param debug_level Equivalent to the `-v` option of the utilities.
+ *
+ * Allows for obtaining the current debug level
+ *
+ */
+void HAMLIB_API rig_get_debug(enum rig_debug_level_e *debug_level)
+{
+    *debug_level = rig_debug_level;
+}
+
 
 /**
  * \brief Test if a given debug level is active.
@@ -180,8 +192,6 @@ void HAMLIB_API rig_set_debug_time_stamp(int flag)
     rig_debug_time_stamp = flag;
 }
 
-//! @endcond
-
 
 /**
  * \brief Print debugging messages through `stderr` by default.
@@ -330,4 +340,31 @@ FILE *HAMLIB_API rig_set_debug_file(FILE *stream)
     return prev_stream;
 }
 
+/**
+ * \brief Change the output stream to a filename
+ *
+ * \param filename The filename to direct debugging output.
+ *
+ * \sa `FILE`(3)
+ */
+// cppcheck-suppress unusedFunction
+FILE *HAMLIB_API rig_set_debug_filename(char *filename)
+{
+    FILE *prev_stream = rig_debug_stream;
+    rig_debug(RIG_DEBUG_WARN, "%s: debug will stream to '%s'\n", __func__,
+              filename);
+    FILE *stream = fopen(filename, "w");
+
+    if (stream == NULL)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: error opening stream: %s\n", __func__,
+                  strerror(errno));
+        return NULL;
+    }
+
+    rig_debug_stream = stream;
+
+    return prev_stream;
+}
+
 /** @} */
