@@ -1,2 +1,2 @@
 /* This date time is from the last non-merge commit to Hamlib. */
-#define HAMLIBDATETIME "Apr 05 11:43:08Z 2023 SHA=6eecd3"
+#define HAMLIBDATETIME "2025-02-09T21:03:50Z SHA=870364"
