@@ -31,6 +31,7 @@
  * @{
  */
 
+#include <hamlib/rig.h>
 #include <hamlib/config.h>
 
 #include <stdio.h>   /* Standard input/output definitions */
@@ -50,12 +51,14 @@
 #include "usb_port.h"
 #include "network.h"
 #include "cm108.h"
-#include "gpio.h"
 #include "asyncpipe.h"
 
+#define HAMLIB_TRACE2 rig_debug(RIG_DEBUG_TRACE,"%s trace(%d)\n",  __FILE__, __LINE__)
+
 #if defined(WIN32) && defined(HAVE_WINDOWS_H)
 #include <windows.h>
 
+
 static void init_sync_data_pipe(hamlib_port_t *p)
 {
     p->sync_data_pipe = NULL;
@@ -249,8 +252,13 @@ int HAMLIB_API port_open(hamlib_port_t *p)
 
         if (status < 0)
         {
+#if defined(WIN32)
+//            rig_debug(RIG_DEBUG_ERR, "%s: serial_open(%s) status=%d, err=%s\n", __func__,
+//                      p->pathname, status, rigerror(status));
+#else
             rig_debug(RIG_DEBUG_ERR, "%s: serial_open(%s) status=%d, err=%s\n", __func__,
                       p->pathname, status, strerror(errno));
+#endif
             close_sync_data_pipe(p);
             return (status);
         }
@@ -493,12 +501,10 @@ static int port_read_sync_data(hamlib_port_t *p, void *buf, size_t count)
         switch (result)
         {
         case ERROR_SUCCESS:
-            HAMLIB_TRACE;
             // No error?
             break;
 
         case ERROR_IO_PENDING:
-            HAMLIB_TRACE;
             timeout.QuadPart = (p->timeout * -1000000LL);
 
             if ((result = SetWaitableTimer(hLocal, &timeout, 0, NULL, NULL, 0)) == 0)
@@ -511,7 +517,6 @@ static int port_read_sync_data(hamlib_port_t *p, void *buf, size_t count)
                 wait_result = WaitForMultipleObjects(3, event_handles, FALSE, p->timeout);
             }
 
-            HAMLIB_TRACE;
 
             switch (wait_result)
             {
@@ -559,10 +564,12 @@ static int port_read_sync_data(hamlib_port_t *p, void *buf, size_t count)
         {
         case ERROR_SUCCESS:
             // No error?
+            bytes_read = 0;
             break;
 
         case ERROR_IO_PENDING:
             // Shouldn't happen?
+            bytes_read = 0;
             return -RIG_ETIMEOUT;
 
         default:
@@ -732,9 +739,9 @@ static int port_wait_for_data_direct(hamlib_port_t *p)
     int fd = p->fd;
     struct timeval tv, tv_timeout;
     int result;
-
     tv_timeout.tv_sec = p->timeout / 1000;
     tv_timeout.tv_usec = (p->timeout % 1000) * 1000;
+    //rig_debug(RIG_DEBUG_CACHE, "%s(%d): timeout=%ld,%ld\n", __func__, __LINE__, tv_timeout.tv_sec, tv_timeout.tv_usec);
 
     tv = tv_timeout;    /* select may have updated it */
 
@@ -743,6 +750,7 @@ static int port_wait_for_data_direct(hamlib_port_t *p)
     efds = rfds;
 
     result = port_select(p, fd + 1, &rfds, NULL, &efds, &tv, 1);
+    //rig_debug(RIG_DEBUG_CACHE, "%s(%d): timeout=%ld,%ld\n", __func__, __LINE__, tv_timeout.tv_sec, tv_timeout.tv_usec);
 
     if (result == 0)
     {
@@ -788,6 +796,12 @@ int HAMLIB_API write_block_sync_error(hamlib_port_t *p,
     return async_pipe_write(p->sync_data_error_pipe, txbuffer, count, p->timeout);
 }
 
+int HAMLIB_API port_flush_sync_pipes(hamlib_port_t *p)
+{
+    // TODO: To be implemented for Windows
+    return RIG_OK;
+}
+
 #else
 
 /* POSIX */
@@ -830,11 +844,11 @@ static int port_read_sync_data_error_code(hamlib_port_t *p, int fd, int direct)
     ssize_t total_bytes_read = 0;
     ssize_t bytes_read;
     struct timeval tv_timeout;
-    int result;
     signed char data;
 
     do
     {
+        int result;
         tv_timeout.tv_sec = 0;
         tv_timeout.tv_usec = 0;
 
@@ -951,13 +965,24 @@ static int port_wait_for_data(hamlib_port_t *p, int direct)
 int HAMLIB_API write_block_sync(hamlib_port_t *p, const unsigned char *txbuffer,
                                 size_t count)
 {
+    int retval = RIG_OK;
 
     if (p->asyncio)
     {
-        return (int) write(p->fd_sync_write, txbuffer, count);
+        retval = write(p->fd_sync_write, txbuffer, count);
+    }
+    else
+    {
+        retval = write(p->fd, txbuffer, count);
     }
 
-    return (int) write(p->fd, txbuffer, count);
+    if (retval != count)
+    {
+        rig_debug(RIG_DEBUG_ERR, "%s: write failed: %s\n", __func__, strerror(errno));
+        retval = -RIG_EIO;
+    }
+
+    return retval;
 }
 
 int HAMLIB_API write_block_sync_error(hamlib_port_t *p,
@@ -971,6 +996,42 @@ int HAMLIB_API write_block_sync_error(hamlib_port_t *p,
     return (int) write(p->fd_sync_error_write, txbuffer, count);
 }
 
+int HAMLIB_API port_flush_sync_pipes(hamlib_port_t *p)
+{
+    unsigned char buf[1024];
+    int n;
+    int nbytes;
+
+    if (!p->asyncio)
+    {
+        return RIG_OK;
+    }
+
+    rig_debug(RIG_DEBUG_TRACE, "%s: flushing sync pipes\n", __func__);
+
+    nbytes = 0;
+
+    while ((n = read(p->fd_sync_read, buf, sizeof(buf))) > 0)
+    {
+        nbytes += n;
+    }
+
+    rig_debug(RIG_DEBUG_TRACE, "read flushed %d bytes from sync read pipe\n",
+              nbytes);
+
+    nbytes = 0;
+
+    while ((n = read(p->fd_sync_error_read, buf, sizeof(buf))) > 0)
+    {
+        nbytes += n;
+    }
+
+    rig_debug(RIG_DEBUG_TRACE, "read flushed %d bytes from sync error read pipe\n",
+              nbytes);
+
+    return RIG_OK;
+}
+
 #endif
 
 /**
@@ -1006,7 +1067,6 @@ int HAMLIB_API write_block(hamlib_port_t *p, const unsigned char *txbuffer,
                            size_t count)
 {
     int ret;
-    int method = 0;
 
     if (p->fd < 0)
     {
@@ -1043,7 +1103,6 @@ int HAMLIB_API write_block(hamlib_port_t *p, const unsigned char *txbuffer,
     if (p->write_delay > 0)
     {
         int i;
-        method = 1;
 
         for (i = 0; i < count; i++)
         {
@@ -1066,7 +1125,6 @@ int HAMLIB_API write_block(hamlib_port_t *p, const unsigned char *txbuffer,
     }
     else
     {
-        method = 2;
         ret = port_write(p, txbuffer, count);
 
         if (ret != count)
@@ -1082,13 +1140,13 @@ int HAMLIB_API write_block(hamlib_port_t *p, const unsigned char *txbuffer,
         }
     }
 
-    rig_debug(RIG_DEBUG_TRACE, "%s(): TX %d bytes, method=%d\n", __func__,
-              (int)count, method);
+    rig_debug(RIG_DEBUG_TRACE, "%s(): TX %d bytes\n", __func__,
+              (int)count);
     dump_hex((unsigned char *) txbuffer, count);
 
     if (p->post_write_delay > 0)
     {
-        method |= 4;
+#if 0
 #ifdef WANT_NON_ACTIVE_POST_WRITE_DELAY
 #define POST_WRITE_DELAY_TRSHLD 10
 
@@ -1100,6 +1158,7 @@ int HAMLIB_API write_block(hamlib_port_t *p, const unsigned char *txbuffer,
             p->post_write_date.tv_usec = tv.tv_usec;
         }
         else
+#endif
 #endif
             hl_usleep(p->post_write_delay * 1000); /* optional delay after last write */
 
@@ -1126,6 +1185,8 @@ static int read_block_generic(hamlib_port_t *p, unsigned char *rxbuffer,
     /* Store the time of the read loop start */
     gettimeofday(&start_time, NULL);
 
+    short timeout_retries = p->timeout_retry;
+
     while (count > 0)
     {
         int result;
@@ -1135,6 +1196,16 @@ static int read_block_generic(hamlib_port_t *p, unsigned char *rxbuffer,
 
         if (result == -RIG_ETIMEOUT)
         {
+            if (timeout_retries > 0)
+            {
+                timeout_retries--;
+                rig_debug(RIG_DEBUG_CACHE, "%s(%d): retrying read timeout %d/%d timeout=%dms\n",
+                          __func__, __LINE__,
+                          p->timeout_retry - timeout_retries, p->timeout_retry, p->timeout);
+                hl_usleep(10 * 1000);
+                continue;
+            }
+
             /* Record timeout time and calculate elapsed time */
             gettimeofday(&end_time, NULL);
             timersub(&end_time, &start_time, &elapsed_time);
@@ -1257,12 +1328,12 @@ static int read_string_generic(hamlib_port_t *p,
     int i = 0;
     static int minlen = 1; // dynamic minimum length of rig response data
 
-    if (!p->asyncio && !direct)
+    if (p != NULL && !p->asyncio && !direct)
     {
         return -RIG_EINTERNAL;
     }
 
-    rig_debug(RIG_DEBUG_TRACE, "%s called, rxmax=%d direct=%d, expected_len=%d\n",
+    rig_debug(RIG_DEBUG_CACHE, "%s called, rxmax=%d direct=%d, expected_len=%d\n",
               __func__,
               (int)rxmax, direct, expected_len);
 
@@ -1284,15 +1355,26 @@ static int read_string_generic(hamlib_port_t *p,
 
     memset(rxbuffer, 0, rxmax);
 
+    short timeout_retries = p->timeout_retry;
+
     while (total_count < rxmax - 1) // allow 1 byte for end-of-string
     {
         ssize_t rd_count = 0;
         int result;
-
         result = port_wait_for_data(p, direct);
 
         if (result == -RIG_ETIMEOUT)
         {
+            if (timeout_retries > 0)
+            {
+                timeout_retries--;
+                rig_debug(RIG_DEBUG_CACHE, "%s(%d): retrying read timeout %d/%d timeout=%d\n",
+                          __func__, __LINE__,
+                          p->timeout_retry - timeout_retries, p->timeout_retry, p->timeout);
+                hl_usleep(10 * 1000);
+                continue;
+            }
+
             // a timeout is a timeout no matter how many bytes
             //if (0 == total_count)
             {
@@ -1307,7 +1389,7 @@ static int read_string_generic(hamlib_port_t *p,
 
                 if (!flush_flag)
                 {
-                    rig_debug(RIG_DEBUG_WARN,
+                    rig_debug(RIG_DEBUG_CACHE,
                               "%s(): Timed out %d.%03d seconds after %d chars, direct=%d\n",
                               __func__,
                               (int)elapsed_time.tv_sec,
@@ -1348,17 +1430,34 @@ static int read_string_generic(hamlib_port_t *p,
             //rig_debug(RIG_DEBUG_ERR, "xs: avail=%d expected_len=%d, minlen=%d, direct=%d\n", __func__, avail, expected_len, minlen, direct);
 #endif
 #endif
+shortcut:
             rd_count = port_read_generic(p, &rxbuffer[total_count],
                                          expected_len == 1 ? 1 : minlen, direct);
-//            rig_debug(RIG_DEBUG_VERBOSE, "%s: read %d bytes\n", __func__, (int)rd_count);
+//            rig_debug(RIG_DEBUG_VERBOSE, "%s: read %d bytes tot=%d\n", __func__, (int)rd_count, total_count);
             minlen -= rd_count;
 
             if (errno == EAGAIN)
             {
                 hl_usleep(5 * 1000);
-                rig_debug(RIG_DEBUG_WARN, "%s: port_read is busy? direct=%d\n", __func__,
-                          direct);
+//                rig_debug(RIG_DEBUG_WARN, "%s: port_read is busy? direct=%d\n", __func__,
+//                          direct);
             }
+
+            // special read for FLRig
+            if (stopset != NULL && strcmp(stopset, "</methodResponse>") == 0)
+            {
+                if (strstr((char *)rxbuffer, stopset))
+                {
+                    HAMLIB_TRACE2;
+                }
+
+                else
+                {
+                    HAMLIB_TRACE2;
+                    goto shortcut;
+                }
+            }
+
         }
 
         while (++i < 10 && errno == EBUSY);   // 50ms should be enough
@@ -1382,11 +1481,6 @@ static int read_string_generic(hamlib_port_t *p,
 
         total_count += (int) rd_count;
 
-        if (rxbuffer[0] == ';' && total_count > 1)
-        {
-
-        }
-
         if (total_count == rxmax) { break; }
 
         if (stopset && memchr(stopset, rxbuffer[total_count - 1], stopset_len))
@@ -1405,7 +1499,7 @@ static int read_string_generic(hamlib_port_t *p,
 
     if (total_count > 1 && rxbuffer[0] == ';')
     {
-        while (rxbuffer[0] == ';' && rxbuffer[0] != 0 && total_count >  1)
+        while (rxbuffer[0] == ';' && total_count >  1)
         {
             memmove(rxbuffer, &rxbuffer[1], strlen((char *)rxbuffer) - 1);
             --total_count;
