@@ -19,6 +19,7 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
+/* SPDX-License-Identifier: LGPL-2.1-or-later */
 
 /**
  * \addtogroup rotator
@@ -65,6 +66,7 @@
 #include "network.h"
 #include "rot_conf.h"
 #include "token.h"
+#include "serial.h"
 
 
 #ifndef DOC_HIDDEN
@@ -87,7 +89,7 @@
 #  define DEFAULT_PARALLEL_PORT "/dev/parport0"
 #endif
 
-#define CHECK_ROT_ARG(r) (!(r) || !(r)->caps || !(r)->state.comm_state)
+#define CHECK_ROT_ARG(r) (!(r) || !(r)->caps || !(ROTSTATE(r)->comm_state))
 
 
 /*
@@ -218,6 +220,7 @@ ROT *HAMLIB_API rot_init(rot_model_t rot_model)
     ROT *rot;
     const struct rot_caps *caps;
     struct rot_state *rs;
+    hamlib_port_t *rotp, *rotp2;
 
     rot_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -255,38 +258,48 @@ ROT *HAMLIB_API rot_init(rot_model_t rot_model)
     /**
      * \todo Read the Preferences here!
      */
-    rs = &rot->state;
+    rs = ROTSTATE(rot);
+
+    //TODO Allocate new rotport[2]
+    // For now, use the embedded ones
+    rotp = ROTPORT(rot);
+    rotp2 = ROTPORT2(rot);
 
     rs->comm_state = 0;
-    rs->rotport.type.rig = caps->port_type; /* default from caps */
+    rotp->type.rig = rotp2->type.rig = caps->port_type; /* default from caps */
 
-    rs->rotport.write_delay = caps->write_delay;
-    rs->rotport.post_write_delay = caps->post_write_delay;
-    rs->rotport.timeout = caps->timeout;
-    rs->rotport.retry = caps->retry;
+    rotp->write_delay = rotp2->write_delay = caps->write_delay;
+    rotp->post_write_delay = rotp2->post_write_delay = caps->post_write_delay;
+    rotp->timeout = rotp2->timeout = caps->timeout;
+    rotp->retry = rotp2->retry = caps->retry;
 
     switch (caps->port_type)
     {
     case RIG_PORT_SERIAL:
-        strncpy(rs->rotport.pathname, DEFAULT_SERIAL_PORT, HAMLIB_FILPATHLEN - 1);
-        rs->rotport.parm.serial.rate = caps->serial_rate_max;   /* fastest ! */
-        rs->rotport.parm.serial.data_bits = caps->serial_data_bits;
-        rs->rotport.parm.serial.stop_bits = caps->serial_stop_bits;
-        rs->rotport.parm.serial.parity = caps->serial_parity;
-        rs->rotport.parm.serial.handshake = caps->serial_handshake;
+        strncpy(rotp->pathname, DEFAULT_SERIAL_PORT, HAMLIB_FILPATHLEN - 1);
+        rotp->parm.serial.rate = rotp2->parm.serial.rate =
+                                     caps->serial_rate_max;   /* fastest ! */
+        rotp->parm.serial.data_bits = rotp2->parm.serial.data_bits =
+                                          caps->serial_data_bits;
+        rotp->parm.serial.stop_bits = rotp2->parm.serial.stop_bits =
+                                          caps->serial_stop_bits;
+        rotp->parm.serial.parity = rotp2->parm.serial.parity =
+                                       caps->serial_parity;
+        rotp->parm.serial.handshake = rotp2->parm.serial.handshake =
+                                          caps->serial_handshake;
         break;
 
     case RIG_PORT_PARALLEL:
-        strncpy(rs->rotport.pathname, DEFAULT_PARALLEL_PORT, HAMLIB_FILPATHLEN - 1);
+        strncpy(rotp->pathname, DEFAULT_PARALLEL_PORT, HAMLIB_FILPATHLEN - 1);
         break;
 
     case RIG_PORT_NETWORK:
     case RIG_PORT_UDP_NETWORK:
-        strncpy(rs->rotport.pathname, "127.0.0.1:4533", HAMLIB_FILPATHLEN - 1);
+        strncpy(rotp->pathname, "127.0.0.1:4533", HAMLIB_FILPATHLEN - 1);
         break;
 
     default:
-        strncpy(rs->rotport.pathname, "", HAMLIB_FILPATHLEN - 1);
+        strncpy(rotp->pathname, "", HAMLIB_FILPATHLEN - 1);
     }
 
     rs->min_el = caps->min_el;
@@ -295,7 +308,7 @@ ROT *HAMLIB_API rot_init(rot_model_t rot_model)
     rs->max_az = caps->max_az;
     rs->current_speed = 50; // Set default speed to 50%
 
-    rs->rotport.fd = -1;
+    rotp->fd = -1;
 
     rs->has_get_func = caps->has_get_func;
     rs->has_set_func = caps->has_set_func;
@@ -332,8 +345,8 @@ ROT *HAMLIB_API rot_init(rot_model_t rot_model)
     // Now we have to copy our new rig state hamlib_port structure to the deprecated one
     // Clients built on older 4.X versions will use the old structure
     // Clients built on newer 4.5 versions will use the new structure
-    memcpy(&rot->state.rotport_deprecated, &rot->state.rotport,
-           sizeof(rot->state.rotport_deprecated));
+    memcpy(&rs->rotport_deprecated, rotp,
+           sizeof(rs->rotport_deprecated));
 
     return rot;
 }
@@ -360,8 +373,11 @@ int HAMLIB_API rot_open(ROT *rot)
 {
     const struct rot_caps *caps;
     struct rot_state *rs;
+    hamlib_port_t *rotp = ROTPORT(rot);
+    hamlib_port_t *rotp2 = ROTPORT2(rot);
     int status;
     int net1, net2, net3, net4, port;
+    deferred_config_item_t *item;
 
     rot_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -371,38 +387,78 @@ int HAMLIB_API rot_open(ROT *rot)
     }
 
     caps = rot->caps;
-    rs = &rot->state;
+    rs = ROTSTATE(rot);
 
     if (rs->comm_state)
     {
         return -RIG_EINVAL;
     }
 
-    rs->rotport.fd = -1;
+    rotp->fd = -1;
+    rotp2->fd = -1;
 
     // determine if we have a network address
-    if (sscanf(rs->rotport.pathname, "%d.%d.%d.%d:%d", &net1, &net2, &net3, &net4,
+    if (sscanf(rotp->pathname, "%d.%d.%d.%d:%d", &net1, &net2, &net3, &net4,
+               &port) == 5)
+    {
+        char *type = "TCP";
+
+        if (rot->caps->port_type == RIG_PORT_UDP_NETWORK)
+        {
+            rotp->type.rig = RIG_PORT_UDP_NETWORK;
+            type = "UDP";
+        }
+        else
+        {
+            rotp->type.rig = RIG_PORT_NETWORK;
+        }
+
+        rig_debug(RIG_DEBUG_TRACE, "%s: using network address %s:%s\n", __func__,
+                  rotp->pathname, type);
+    }
+
+    if (sscanf(rotp2->pathname, "%d.%d.%d.%d:%d", &net1, &net2, &net3, &net4,
                &port) == 5)
     {
         rig_debug(RIG_DEBUG_TRACE, "%s: using network address %s\n", __func__,
-                  rs->rotport.pathname);
-        rs->rotport.type.rig = RIG_PORT_NETWORK;
+                  rotp2->pathname);
+
+        if (rot->caps->port_type == RIG_PORT_UDP_NETWORK)
+        {
+            rotp->type.rig = RIG_PORT_UDP_NETWORK;
+        }
+        else
+        {
+            rotp->type.rig = RIG_PORT_NETWORK;
+        }
     }
 
-    switch (rs->rotport.type.rig)
+    switch (rotp->type.rig)
     {
     case RIG_PORT_SERIAL:
-        status = serial_open(&rs->rotport);
+        status = serial_open(rotp);
 
         if (status != 0)
         {
             return status;
         }
 
+        // RT21 has 2nd serial port elevation
+        // so if a 2nd pathname is provided we'll open it
+        if (rot->caps->rot_model == ROT_MODEL_RT21 && rotp2->pathname[0] != 0)
+        {
+            status = serial_open(rotp2);
+
+            if (status != 0)
+            {
+                return status;
+            }
+        }
+
         break;
 
     case RIG_PORT_PARALLEL:
-        status = par_open(&rs->rotport);
+        status = par_open(rotp);
 
         if (status < 0)
         {
@@ -412,27 +468,27 @@ int HAMLIB_API rot_open(ROT *rot)
         break;
 
     case RIG_PORT_DEVICE:
-        status = open(rs->rotport.pathname, O_RDWR, 0);
+        status = open(rotp->pathname, O_RDWR, 0);
 
         if (status < 0)
         {
             return -RIG_EIO;
         }
 
-        rs->rotport.fd = status;
+        rotp->fd = status;
 
         // RT21 has 2nd serial port elevation
         // so if a 2nd pathname is provided we'll open it
-        if (rot->caps->rot_model == ROT_MODEL_RT21 && rs->rotport2.pathname[0] != 0)
+        if (rot->caps->rot_model == ROT_MODEL_RT21 && rotp2->pathname[0] != 0)
         {
-            status = open(rs->rotport2.pathname, O_RDWR, 0);
+            status = open(rotp2->pathname, O_RDWR, 0);
 
             if (status < 0)
             {
                 return -RIG_EIO;
             }
 
-            rs->rotport2.fd = status;
+            rotp2->fd = status;
         }
 
         break;
@@ -440,7 +496,7 @@ int HAMLIB_API rot_open(ROT *rot)
 #if defined(HAVE_LIB_USB_H) || defined(HAMB_LIBUSB_1_0_LIBUSB_H)
 
     case RIG_PORT_USB:
-        status = usb_port_open(&rs->rotport);
+        status = usb_port_open(rotp);
 
         if (status < 0)
         {
@@ -457,7 +513,7 @@ int HAMLIB_API rot_open(ROT *rot)
     case RIG_PORT_NETWORK:
     case RIG_PORT_UDP_NETWORK:
         /* FIXME: default port */
-        status = network_open(&rs->rotport, 4533);
+        status = network_open(rotp, 4533);
 
         if (status < 0)
         {
@@ -472,8 +528,47 @@ int HAMLIB_API rot_open(ROT *rot)
 
     add_opened_rot(rot);
 
+    if (rotp->type.rig != RIG_PORT_NETWORK
+            && rotp->type.rig != RIG_PORT_UDP_NETWORK)
+    {
+        if (rotp->parm.serial.dtr_state == RIG_SIGNAL_ON)
+        {
+            ser_set_dtr(rotp, 1);
+        }
+        else
+        {
+            ser_set_dtr(rotp, 0);
+        }
+
+        if (rotp->parm.serial.rts_state == RIG_SIGNAL_ON)
+        {
+            ser_set_rts(rotp, 1);
+        }
+        else
+        {
+            ser_set_rts(rotp, 0);
+        }
+    }
+
     rs->comm_state = 1;
 
+    /*
+     * Now that the rotator port is officially opened, we can
+     *  send the deferred configuration info.
+     */
+    while ((item = rs->config_queue.first))
+    {
+        rs->config_queue.first = item->next;
+        status = rot_set_conf(rot, item->token, item->value);
+        free(item->value);
+        free(item);
+
+        if (status != RIG_OK)
+        {
+            return status;
+        }
+    }
+
     /*
      * Maybe the backend has something to initialize
      * In case of failure, just close down and report error code.
@@ -484,14 +579,14 @@ int HAMLIB_API rot_open(ROT *rot)
 
         if (status != RIG_OK)
         {
-            memcpy(&rot->state.rotport_deprecated, &rot->state.rotport,
-                   sizeof(rot->state.rotport_deprecated));
+            memcpy(&rs->rotport_deprecated, rotp,
+                   sizeof(rs->rotport_deprecated));
             return status;
         }
     }
 
-    memcpy(&rot->state.rotport_deprecated, &rot->state.rotport,
-           sizeof(rot->state.rotport_deprecated));
+    memcpy(&rs->rotport_deprecated, rotp,
+           sizeof(rs->rotport_deprecated));
 
     return RIG_OK;
 }
@@ -516,6 +611,7 @@ int HAMLIB_API rot_close(ROT *rot)
 {
     const struct rot_caps *caps;
     struct rot_state *rs;
+    hamlib_port_t *rotp = ROTPORT(rot);
 
     rot_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -525,7 +621,7 @@ int HAMLIB_API rot_close(ROT *rot)
     }
 
     caps = rot->caps;
-    rs = &rot->state;
+    rs = ROTSTATE(rot);
 
     if (!rs->comm_state)
     {
@@ -542,43 +638,43 @@ int HAMLIB_API rot_close(ROT *rot)
     }
 
 
-    if (rs->rotport.fd != -1)
+    if (rotp->fd != -1)
     {
-        switch (rs->rotport.type.rig)
+        switch (rotp->type.rig)
         {
         case RIG_PORT_SERIAL:
-            ser_close(&rs->rotport);
+            ser_close(rotp);
             break;
 
         case RIG_PORT_PARALLEL:
-            par_close(&rs->rotport);
+            par_close(rotp);
             break;
 
 #if defined(HAVE_LIB_USB_H) || defined(HAMB_LIBUSB_1_0_LIBUSB_H)
 
         case RIG_PORT_USB:
-            usb_port_close(&rs->rotport);
+            usb_port_close(rotp);
             break;
 #endif
 
         case RIG_PORT_NETWORK:
         case RIG_PORT_UDP_NETWORK:
-            network_close(&rs->rotport);
+            network_close(rotp);
             break;
 
         default:
-            close(rs->rotport.fd);
+            close(rotp->fd);
         }
 
-        rs->rotport.fd = -1;
+        rotp->fd = -1;
     }
 
     remove_opened_rot(rot);
 
     rs->comm_state = 0;
 
-    memcpy(&rot->state.rotport_deprecated, &rot->state.rotport,
-           sizeof(rot->state.rotport_deprecated));
+    memcpy(&rs->rotport_deprecated, rotp,
+           sizeof(rs->rotport_deprecated));
 
     return RIG_OK;
 }
@@ -612,7 +708,7 @@ int HAMLIB_API rot_cleanup(ROT *rot)
     /*
      * check if they forgot to close the rot
      */
-    if (rot->state.comm_state)
+    if (ROTSTATE(rot)->comm_state)
     {
         rot_close(rot);
     }
@@ -625,6 +721,8 @@ int HAMLIB_API rot_cleanup(ROT *rot)
         rot->caps->rot_cleanup(rot);
     }
 
+    //TODO Release any allocated port structures
+
     free(rot);
 
     return RIG_OK;
@@ -669,11 +767,11 @@ int HAMLIB_API rot_set_position(ROT *rot,
         return -RIG_EINVAL;
     }
 
-    azimuth += rot->state.az_offset;
-    elevation += rot->state.el_offset;
-
     caps = rot->caps;
-    rs = &rot->state;
+    rs = ROTSTATE(rot);
+
+    azimuth += rs->az_offset;
+    elevation += rs->el_offset;
 
     rot_debug(RIG_DEBUG_VERBOSE, "%s: south_zero=%d \n", __func__, rs->south_zero);
 
@@ -691,7 +789,7 @@ int HAMLIB_API rot_set_position(ROT *rot,
         rot_debug(RIG_DEBUG_TRACE,
                   "%s: range problem az=%.02f(min=%.02f,max=%.02f), el=%02f(min=%.02f,max=%02f)\n",
                   __func__, azimuth, rs->min_az, rs->max_az, elevation, rs->min_el, rs->max_el);
-        return -RIG_EINVAL;
+        return -RIG_ELIMIT;
     }
 
     if (caps->set_position == NULL)
@@ -744,7 +842,7 @@ int HAMLIB_API rot_get_position(ROT *rot,
     }
 
     caps = rot->caps;
-    rs = &rot->state;
+    rs = ROTSTATE(rot);
 
     if (caps->get_position == NULL)
     {
@@ -763,8 +861,8 @@ int HAMLIB_API rot_get_position(ROT *rot,
         rot_debug(RIG_DEBUG_VERBOSE, "%s: south adj to az=%.2f\n", __func__, az);
     }
 
-    *azimuth = az - rot->state.az_offset;
-    *elevation = el - rot->state.el_offset;
+    *azimuth = az - rs->az_offset;
+    *elevation = el - rs->el_offset;
 
     return RIG_OK;
 }
@@ -892,8 +990,9 @@ int HAMLIB_API rot_reset(ROT *rot, rot_reset_t reset)
  *
  * Move the rotator in the specified direction.  The \a direction is one of
  * #ROT_MOVE_CCW, #ROT_MOVE_CW, #ROT_MOVE_LEFT, #ROT_MOVE_RIGHT, #ROT_MOVE_UP,
- * or #ROT_MOVE_DOWN.  The \a speed is a value between 1 and 100 or
- * #ROT_SPEED_NOCHANGE.
+ * #ROT_MOVE_DOWN, #ROT_MOVE_UP_LEFT, #ROT_MOVE_CCW, #ROT_MOVE_UP_RIGHT, #ROT_MOVE_UP_CW,
+ * #ROT_MOVE_DOWN_LEFT, #ROT_MOVE_DOWN_CCW, #ROT_MOVE_DOWN_RIGHT, #ROT_MOVE_DOWN_CW.
+ * The \a speed is a value between 1 and 100 or #ROT_SPEED_NOCHANGE.
  *
  * \retval RIG_OK The rotator move was successful.
  * \retval RIG_EINVAL \a rot is NULL or inconsistent.
@@ -986,4 +1085,28 @@ int HAMLIB_API rot_get_status(ROT *rot, rot_status_t *status)
     return rot->caps->get_status(rot, status);
 }
 
+/**
+ * \brief Get the address of rotator data structure(s)
+ *
+ * \sa rig_data_pointer
+ *
+ */
+void *HAMLIB_API rot_data_pointer(ROT *rot, rig_ptrx_t idx)
+{
+    switch (idx)
+    {
+    case RIG_PTRX_ROTPORT:
+        return ROTPORT(rot);
+
+    case RIG_PTRX_ROTPORT2:
+        return ROTPORT2(rot);
+
+    case RIG_PTRX_ROTSTATE:
+        return ROTSTATE(rot);
+
+    default:
+        rot_debug(RIG_DEBUG_ERR, "%s: Invalid data index=%d\n", __func__, idx);
+        return NULL;
+    }
+}
 /*! @} */
