@@ -39,6 +39,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>   /* Error number definitions */
+#include <unistd.h>
 
 #include <hamlib/rig.h>
 #include "cal.h"
@@ -47,7 +48,7 @@
 
 #ifndef DOC_HIDDEN
 
-#  define CHECK_RIG_ARG(r) (!(r) || !(r)->caps || !(r)->state.comm_state)
+#  define CHECK_RIG_ARG(r) (!(r) || !(r)->caps || !STATE(r)->comm_state)
 
 #endif /* !DOC_HIDDEN */
 
@@ -91,8 +92,18 @@ int HAMLIB_API rig_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 
     if ((caps->targetable_vfo & RIG_TARGETABLE_LEVEL)
             || vfo == RIG_VFO_CURR
-            || vfo == rig->state.current_vfo)
+            || vfo == STATE(rig)->current_vfo)
     {
+#if defined(HAVE_PTHREAD)
+
+        if (level == RIG_LEVEL_KEYSPD)
+        {
+            extern int morse_data_handler_set_keyspd(RIG * rig, int keyspd);
+            morse_data_handler_set_keyspd(rig, val.i);
+        }
+
+#endif
+
         return caps->set_level(rig, vfo, level, val);
     }
 
@@ -101,7 +112,7 @@ int HAMLIB_API rig_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
         return -RIG_ENTARGET;
     }
 
-    curr_vfo = rig->state.current_vfo;
+    curr_vfo = STATE(rig)->current_vfo;
     retcode = caps->set_vfo(rig, vfo);
 
     if (retcode != RIG_OK)
@@ -142,6 +153,7 @@ int HAMLIB_API rig_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 int HAMLIB_API rig_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
     const struct rig_caps *caps;
+    struct rig_state *rs = STATE(rig);
     int retcode;
     vfo_t curr_vfo;
 
@@ -166,7 +178,7 @@ int HAMLIB_API rig_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
     if (level == RIG_LEVEL_STRENGTH
             && (caps->has_get_level & RIG_LEVEL_STRENGTH) == 0
             && rig_has_get_level(rig, RIG_LEVEL_RAWSTR)
-            && rig->state.str_cal.size)
+            && rs->str_cal.size)
     {
 
         value_t rawstr;
@@ -178,14 +190,14 @@ int HAMLIB_API rig_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
             return retcode;
         }
 
-        val->i = (int)rig_raw2val(rawstr.i, &rig->state.str_cal);
+        val->i = (int)rig_raw2val(rawstr.i, &rs->str_cal);
         return RIG_OK;
     }
 
 
     if ((caps->targetable_vfo & RIG_TARGETABLE_LEVEL)
             || vfo == RIG_VFO_CURR
-            || vfo == rig->state.current_vfo)
+            || vfo == rs->current_vfo)
     {
 
         return caps->get_level(rig, vfo, level, val);
@@ -196,7 +208,7 @@ int HAMLIB_API rig_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
         return -RIG_ENTARGET;
     }
 
-    curr_vfo = rig->state.current_vfo;
+    curr_vfo = rs->current_vfo;
     retcode = caps->set_vfo(rig, vfo);
 
     if (retcode != RIG_OK)
@@ -304,7 +316,7 @@ setting_t HAMLIB_API rig_has_get_level(RIG *rig, setting_t level)
         return 0;
     }
 
-    return (rig->state.has_get_level & level);
+    return (STATE(rig)->has_get_level & level);
 }
 
 
@@ -334,7 +346,7 @@ setting_t HAMLIB_API rig_has_set_level(RIG *rig, setting_t level)
         return 0;
     }
 
-    return (rig->state.has_set_level & level);
+    return (STATE(rig)->has_set_level & level);
 }
 
 
@@ -363,7 +375,7 @@ setting_t HAMLIB_API rig_has_get_parm(RIG *rig, setting_t parm)
         return 0;
     }
 
-    return (rig->state.has_get_parm & parm);
+    return (STATE(rig)->has_get_parm & parm);
 }
 
 
@@ -392,7 +404,7 @@ setting_t HAMLIB_API rig_has_set_parm(RIG *rig, setting_t parm)
         return 0;
     }
 
-    return (rig->state.has_set_parm & parm);
+    return (STATE(rig)->has_set_parm & parm);
 }
 
 
@@ -422,7 +434,7 @@ setting_t HAMLIB_API rig_has_get_func(RIG *rig, setting_t func)
         return 0;
     }
 
-    return (rig->state.has_get_func & func);
+    return (STATE(rig)->has_get_func & func);
 }
 
 
@@ -451,7 +463,7 @@ setting_t HAMLIB_API rig_has_set_func(RIG *rig, setting_t func)
         return 0;
     }
 
-    return (rig->state.has_set_func & func);
+    return (STATE(rig)->has_set_func & func);
 }
 
 
@@ -476,6 +488,7 @@ setting_t HAMLIB_API rig_has_set_func(RIG *rig, setting_t func)
 int HAMLIB_API rig_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 {
     const struct rig_caps *caps;
+    struct rig_state *rs = STATE(rig);
     int retcode;
     vfo_t curr_vfo;
 
@@ -488,14 +501,37 @@ int HAMLIB_API rig_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 
     caps = rig->caps;
 
-    if (caps->set_func == NULL || !rig_has_set_func(rig, func))
+    if ((caps->set_func == NULL || !rig_has_set_func(rig, func))
+            && access(rs->tuner_control_pathname, X_OK) == -1)
     {
         return -RIG_ENAVAIL;
     }
 
+    if (access(rs->tuner_control_pathname, X_OK) != -1)
+    {
+        char cmd[1024];
+        snprintf(cmd, sizeof(cmd), "%s %d", rs->tuner_control_pathname, status);
+        rig_debug(RIG_DEBUG_TRACE, "%s: Calling external script '%s'\n", __func__,
+                  rs->tuner_control_pathname);
+        retcode = system(cmd);
+
+        if (retcode != 0) { rig_debug(RIG_DEBUG_ERR, "%s: executing %s failed\n", __func__, rs->tuner_control_pathname); }
+
+        return (retcode == 0 ? RIG_OK : -RIG_ERJCTED);
+    }
+    else
+    {
+        if (strcmp(rs->tuner_control_pathname, "hamlib_tuner_control"))
+        {
+            rig_debug(RIG_DEBUG_ERR, "%s: unable to find '%s'\n", __func__,
+                      rs->tuner_control_pathname);
+            return -RIG_EINVAL;
+        }
+    }
+
     if ((caps->targetable_vfo & RIG_TARGETABLE_FUNC)
             || vfo == RIG_VFO_CURR
-            || vfo == rig->state.current_vfo)
+            || vfo == rs->current_vfo)
     {
 
         return caps->set_func(rig, vfo, func, status);
@@ -504,7 +540,7 @@ int HAMLIB_API rig_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
     {
         int targetable = caps->targetable_vfo & RIG_TARGETABLE_FUNC;
         rig_debug(RIG_DEBUG_TRACE, "%s: targetable=%d, vfo=%s, currvfo=%s\n", __func__,
-                  targetable, rig_strvfo(vfo), rig_strvfo(rig->state.current_vfo));
+                  targetable, rig_strvfo(vfo), rig_strvfo(rs->current_vfo));
     }
 
     if (!caps->set_vfo)
@@ -512,7 +548,7 @@ int HAMLIB_API rig_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
         return -RIG_ENTARGET;
     }
 
-    curr_vfo = rig->state.current_vfo;
+    curr_vfo = rs->current_vfo;
     retcode = caps->set_vfo(rig, vfo);
 
     if (retcode != RIG_OK)
@@ -549,6 +585,7 @@ int HAMLIB_API rig_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 int HAMLIB_API rig_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 {
     const struct rig_caps *caps;
+    struct rig_state *rs = STATE(rig);
     int retcode;
     vfo_t curr_vfo;
 
@@ -569,7 +606,7 @@ int HAMLIB_API rig_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 
     if ((caps->targetable_vfo & RIG_TARGETABLE_FUNC)
             || vfo == RIG_VFO_CURR
-            || vfo == rig->state.current_vfo)
+            || vfo == rs->current_vfo)
     {
 
         return caps->get_func(rig, vfo, func, status);
@@ -580,7 +617,7 @@ int HAMLIB_API rig_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
         return -RIG_ENTARGET;
     }
 
-    curr_vfo = rig->state.current_vfo;
+    curr_vfo = rs->current_vfo;
     retcode = caps->set_vfo(rig, vfo);
 
     if (retcode != RIG_OK)
@@ -612,7 +649,7 @@ int HAMLIB_API rig_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
  */
 int HAMLIB_API rig_set_ext_level(RIG *rig,
                                  vfo_t vfo,
-                                 token_t token,
+                                 hamlib_token_t token,
                                  value_t val)
 {
     const struct rig_caps *caps;
@@ -635,7 +672,7 @@ int HAMLIB_API rig_set_ext_level(RIG *rig,
 
     if ((caps->targetable_vfo & RIG_TARGETABLE_LEVEL)
             || vfo == RIG_VFO_CURR
-            || vfo == rig->state.current_vfo)
+            || vfo == STATE(rig)->current_vfo)
     {
 
         return caps->set_ext_level(rig, vfo, token, val);
@@ -646,7 +683,7 @@ int HAMLIB_API rig_set_ext_level(RIG *rig,
         return -RIG_ENTARGET;
     }
 
-    curr_vfo = rig->state.current_vfo;
+    curr_vfo = STATE(rig)->current_vfo;
     retcode = caps->set_vfo(rig, vfo);
 
     if (retcode != RIG_OK)
@@ -678,7 +715,7 @@ int HAMLIB_API rig_set_ext_level(RIG *rig,
  */
 int HAMLIB_API rig_get_ext_level(RIG *rig,
                                  vfo_t vfo,
-                                 token_t token,
+                                 hamlib_token_t token,
                                  value_t *val)
 {
     const struct rig_caps *caps;
@@ -701,7 +738,7 @@ int HAMLIB_API rig_get_ext_level(RIG *rig,
 
     if ((caps->targetable_vfo & RIG_TARGETABLE_LEVEL)
             || vfo == RIG_VFO_CURR
-            || vfo == rig->state.current_vfo)
+            || vfo == STATE(rig)->current_vfo)
     {
 
         return caps->get_ext_level(rig, vfo, token, val);
@@ -712,7 +749,7 @@ int HAMLIB_API rig_get_ext_level(RIG *rig,
         return -RIG_ENTARGET;
     }
 
-    curr_vfo = rig->state.current_vfo;
+    curr_vfo = STATE(rig)->current_vfo;
     retcode = caps->set_vfo(rig, vfo);
 
     if (retcode != RIG_OK)
@@ -743,7 +780,7 @@ int HAMLIB_API rig_get_ext_level(RIG *rig,
  */
 int HAMLIB_API rig_set_ext_func(RIG *rig,
                                 vfo_t vfo,
-                                token_t token,
+                                hamlib_token_t token,
                                 int status)
 {
     const struct rig_caps *caps;
@@ -766,7 +803,7 @@ int HAMLIB_API rig_set_ext_func(RIG *rig,
 
     if ((caps->targetable_vfo & RIG_TARGETABLE_FUNC)
             || vfo == RIG_VFO_CURR
-            || vfo == rig->state.current_vfo)
+            || vfo == STATE(rig)->current_vfo)
     {
 
         return caps->set_ext_func(rig, vfo, token, status);
@@ -777,7 +814,7 @@ int HAMLIB_API rig_set_ext_func(RIG *rig,
         return -RIG_ENTARGET;
     }
 
-    curr_vfo = rig->state.current_vfo;
+    curr_vfo = STATE(rig)->current_vfo;
     retcode = caps->set_vfo(rig, vfo);
 
     if (retcode != RIG_OK)
@@ -809,7 +846,7 @@ int HAMLIB_API rig_set_ext_func(RIG *rig,
  */
 int HAMLIB_API rig_get_ext_func(RIG *rig,
                                 vfo_t vfo,
-                                token_t token,
+                                hamlib_token_t token,
                                 int *status)
 {
     const struct rig_caps *caps;
@@ -832,7 +869,7 @@ int HAMLIB_API rig_get_ext_func(RIG *rig,
 
     if ((caps->targetable_vfo & RIG_TARGETABLE_FUNC)
             || vfo == RIG_VFO_CURR
-            || vfo == rig->state.current_vfo)
+            || vfo == STATE(rig)->current_vfo)
     {
 
         return caps->get_ext_func(rig, vfo, token, status);
@@ -843,7 +880,7 @@ int HAMLIB_API rig_get_ext_func(RIG *rig,
         return -RIG_ENTARGET;
     }
 
-    curr_vfo = rig->state.current_vfo;
+    curr_vfo = STATE(rig)->current_vfo;
     retcode = caps->set_vfo(rig, vfo);
 
     if (retcode != RIG_OK)
@@ -872,7 +909,7 @@ int HAMLIB_API rig_get_ext_func(RIG *rig,
  *
  * \sa rig_get_ext_parm()
  */
-int HAMLIB_API rig_set_ext_parm(RIG *rig, token_t token, value_t val)
+int HAMLIB_API rig_set_ext_parm(RIG *rig, hamlib_token_t token, value_t val)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -904,7 +941,7 @@ int HAMLIB_API rig_set_ext_parm(RIG *rig, token_t token, value_t val)
  *
  * \sa rig_set_ext_parm()
  */
-int HAMLIB_API rig_get_ext_parm(RIG *rig, token_t token, value_t *val)
+int HAMLIB_API rig_get_ext_parm(RIG *rig, hamlib_token_t token, value_t *val)
 {
     rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
@@ -999,13 +1036,24 @@ HAMLIB_EXPORT(int) rig_settings_get_path(char *path, int pathlen)
 #endif
 #endif
 
-    char *xdgpath = getenv("XDG_CONFIG_HOME");
+    const char *xdgpath = getenv("XDG_CONFIG_HOME");
     char *home = getenv("HOME");
+
+    if (home == NULL)
+    {
+        home = getenv("HOMEPATH");
+    }
+
+    if (home == NULL)
+    {
+        home = "?HOME";
+    }
+
     snprintf(path, pathlen, "%s/.config", home);
 
     if (xdgpath)
     {
-        snprintf(path, pathlen - 1, "%s/%s/%s", xdgpath, cwd, HAMLIB_SETTINGS_FILE);
+        snprintf(path, pathlen - 1, "%s/%s", xdgpath, HAMLIB_SETTINGS_FILE);
     }
     else if (home && access(path, F_OK) != -1)
     {
@@ -1033,7 +1081,7 @@ HAMLIB_EXPORT(int) rig_settings_get_path(char *path, int pathlen)
  *
  * \sa rig_setting_load()
  */
-HAMLIB_EXPORT(int) rig_settings_save(char *setting, void *value,
+HAMLIB_EXPORT(int) rig_settings_save(const char *setting, void *value,
                                      settings_value_t valuetype)
 {
     FILE *fp;
@@ -1180,17 +1228,21 @@ HAMLIB_EXPORT(int) rig_settings_load_all(char *settings_file)
 
     if (fp == NULL)
     {
+#if 0 // until we actually implement this
         rig_debug(RIG_DEBUG_VERBOSE, "%s: settings_file (%s): %s\n", __func__,
                   settings_file, strerror(errno));
         return -RIG_EINVAL;
+#else
+        return RIG_OK;
+#endif
     }
 
     rig_debug(RIG_DEBUG_TRACE, "%s: opened %s\n", __func__, settings_file);
 
     while (fgets(buf, sizeof(buf), fp))
     {
-        char *s = strtok(buf, "=");
-        char *v = strtok(NULL, "\r\n");
+        const char *s = strtok(buf, "=");
+        const char *v = strtok(NULL, "\r\n");
 
         if (strcmp(s, "sharedkey") == 0)
         {
