@@ -77,9 +77,9 @@ int main(int argc, char *argv[])
     /* Set up serial port, baud rate */
     rig_file = argv[2];        // your serial device
 
-    strncpy(my_rig->state.rigport.pathname, rig_file, HAMLIB_FILPATHLEN - 1);
+    strncpy(RIGPORT(my_rig)->pathname, rig_file, HAMLIB_FILPATHLEN - 1);
 
-    my_rig->state.rigport.parm.serial.rate = baud; // your baud rate
+    RIGPORT(my_rig)->parm.serial.rate = baud; // your baud rate
 
     /* Open my rig */
     retcode = rig_open(my_rig);
