@@ -37,7 +37,7 @@ static char *decode_modes(rmode_t modes);
 static int dump_chan(RIG *rig, int chan_num);
 
 
-int main(int argc, char *argv[])
+int main(int argc, const char *argv[])
 {
     RIG *my_rig;
     int status, i, j;
@@ -57,7 +57,7 @@ int main(int argc, char *argv[])
         exit(1); /* whoops! something went wrong (mem alloc?) */
     }
 
-    strncpy(my_rig->state.rigport.pathname, SERIAL_PORT, HAMLIB_FILPATHLEN - 1);
+    strncpy(RIGPORT(my_rig)->pathname, SERIAL_PORT, HAMLIB_FILPATHLEN - 1);
 
     if (rig_open(my_rig))
     {
@@ -83,11 +83,12 @@ int main(int argc, char *argv[])
      *      RIG_CHAN_END
      *  }
      */
+    struct rig_state *rs = STATE(my_rig);
 
-    for (i = 0; my_rig->state.chan_list[i].type; i++)
+    for (i = 0; rs->chan_list[i].type; i++)
     {
-        for (j = my_rig->state.chan_list[i].startc;
-                j <= my_rig->state.chan_list[i].endc; j++)
+        for (j = rs->chan_list[i].startc;
+                j <= rs->chan_list[i].endc; j++)
         {
             dump_chan(my_rig, j);
         }
