@@ -26,6 +26,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 
 #include <hamlib/config.h>
 
@@ -35,6 +36,8 @@
 #include <windows.h>
 #endif
 
+// cppcheck-suppress *
+#include <stdint.h>
 // cppcheck-suppress *
 #include <stdio.h>
 // cppcheck-suppress *
@@ -42,9 +45,6 @@
 // cppcheck-suppress *
 #include <string.h>
 // cppcheck-suppress *
-// cppcheck-suppress *
-#include <ctype.h>
-// cppcheck-suppress *
 #include <errno.h>
 // cppcheck-suppress *
 #include <signal.h>
@@ -79,9 +79,8 @@
 #include <hamlib/rig.h>
 #include "misc.h"
 #include "iofunc.h"
-#include "serial.h"
-#include "sprintflst.h"
 #include "rigctl_parse.h"
+#include "riglist.h"
 
 /*
  * Reminder: when adding long options,
@@ -133,7 +132,7 @@ static sig_atomic_t volatile ctrl_c;
 static int volatile ctrl_c;
 #endif
 
-#define MAXCONFLEN 1024
+#define MAXCONFLEN 2048
 
 #if 0
 # ifdef WIN32
@@ -225,7 +224,7 @@ int main(int argc, char *argv[])
     char conf_parms[MAXCONFLEN] = "";
     int status;
 
-    printf("rigctlcom Version 1.4\n");
+    printf("rigctlcom Version 1.6\n");
 
     while (1)
     {
@@ -251,7 +250,7 @@ int main(int argc, char *argv[])
             exit(0);
 
         case 'V':
-            version();
+            rig_version();
             exit(0);
 
         case 'B':
@@ -440,7 +439,7 @@ int main(int argc, char *argv[])
                 return 1;
             }
 
-            strncat(conf_parms, optarg, MAXCONFLEN - strlen(conf_parms));
+            strncat(conf_parms, optarg, MAXCONFLEN - strlen(conf_parms) - 1);
             break;
 
         case 'v':
@@ -494,6 +493,8 @@ int main(int argc, char *argv[])
         exit(2);
     }
 
+#if 0
+    retcode = -RIG_ENIMPL;
     retcode = set_conf(my_rig, conf_parms);
 
     if (retcode != RIG_OK)
@@ -502,6 +503,8 @@ int main(int argc, char *argv[])
         exit(2);
     }
 
+#endif
+
     if (my_model > 5 && !rig_file)
     {
         fprintf(stderr, "-r rig com port not provided\n");
@@ -510,7 +513,7 @@ int main(int argc, char *argv[])
 
     if (rig_file)
     {
-        strncpy(my_rig->state.rigport.pathname, rig_file, HAMLIB_FILPATHLEN - 1);
+        strncpy(RIGPORT(my_rig)->pathname, rig_file, HAMLIB_FILPATHLEN - 1);
     }
 
     if (!rig_file2)
@@ -526,28 +529,28 @@ int main(int argc, char *argv[])
      */
     if (ptt_type != RIG_PTT_NONE)
     {
-        my_rig->state.pttport.type.ptt = ptt_type;
+        PTTPORT(my_rig)->type.ptt = ptt_type;
     }
 
     if (dcd_type != RIG_DCD_NONE)
     {
-        my_rig->state.dcdport.type.dcd = dcd_type;
+        DCDPORT(my_rig)->type.dcd = dcd_type;
     }
 
     if (ptt_file)
     {
-        strncpy(my_rig->state.pttport.pathname, ptt_file, HAMLIB_FILPATHLEN - 1);
+        strncpy(PTTPORT(my_rig)->pathname, ptt_file, HAMLIB_FILPATHLEN - 1);
     }
 
     if (dcd_file)
     {
-        strncpy(my_rig->state.dcdport.pathname, dcd_file, HAMLIB_FILPATHLEN - 1);
+        strncpy(DCDPORT(my_rig)->pathname, dcd_file, HAMLIB_FILPATHLEN - 1);
     }
 
     /* FIXME: bound checking and port type == serial */
     if (serial_rate != 0)
     {
-        my_rig->state.rigport.parm.serial.rate = serial_rate;
+        RIGPORT(my_rig)->parm.serial.rate = serial_rate;
     }
 
     if (serial_rate2 != 0)
@@ -652,6 +655,9 @@ int main(int argc, char *argv[])
     }
     while (retcode == 0 && !ctrl_c);
 
+    rig_debug(RIG_DEBUG_VERBOSE, "%s: rigctlcom exiting, retcode=%d, ctrl_c=%d\n",
+              __func__, retcode, ctrl_c);
+
     rig_close(my_rig);          /* close port */
     rig_cleanup(my_rig);        /* if you care about memory */
 
@@ -663,9 +669,10 @@ static rmode_t ts2000_get_mode()
 {
     rmode_t mode;
     pbwidth_t width;
-    rig_get_mode(my_rig, vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split),
+    rig_get_mode(my_rig, vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split),
                  &mode, &width);
-
+    kwidth = width;
+#if 0
     // Perhaps we should emulate a rig that has PKT modes instead??
     int kwidth_ssb[] = { 10, 50, 100, 200, 300, 400, 500, 600, 700, 800, 900, 1000 };
     int kwidth_am[] = { 10, 100, 200, 500 };
@@ -703,6 +710,47 @@ static rmode_t ts2000_get_mode()
     default: mode = 0; break;
     }
 
+#else
+    // Perhaps we should emulate a rig that has PKT modes instead??
+    //int kwidth_ssb[] = { 10, 50, 100, 200, 300, 400, 500, 600, 700, 800, 900, 1000 };
+    //int kwidth_am[] = { 10, 100, 200, 500 };
+
+    // still need to cover packet filter 00=wide, 01=nar
+    switch (mode)
+    {
+    case RIG_MODE_LSB:   mode = 1; break;
+
+    case RIG_MODE_USB:   mode = 2; break;
+
+    case RIG_MODE_CW:    mode = 3;
+        break; // is this correct?
+
+    case RIG_MODE_FM:    mode = 4; break;
+
+    case RIG_MODE_AM:    mode = 5; break;
+
+    case RIG_MODE_RTTY:  mode = 6; break;
+
+    case RIG_MODE_CWR:   mode = 7;
+        break; // is this correct?
+
+    case RIG_MODE_NONE:  mode = 8;
+        break; // is this correct?
+
+    case RIG_MODE_RTTYR: mode = 9; break;
+
+    case RIG_MODE_PKTUSB: mode = 2;
+        break; // need to change to a TS_2000 mode
+
+    case RIG_MODE_PKTLSB: mode = 1;;
+        break; // need to change to a TS_2000 mode
+
+    default: mode = 0; break;
+    }
+
+#endif
+
+
     return mode;
 }
 
@@ -745,27 +793,28 @@ static int handle_ts2000(void *arg)
     }
     else if (strcmp(arg, "IF;") == 0)
     {
-        freq_t freq;            // P1
-        int freq_step = 10;     // P2 just use default value for now
-        int rit_xit_freq = 0;   // P3 dummy value for now
-        int rit = 0;            // P4 dummy value for now
-        int xit = 0;            // P5 dummy value for now
-        int bank1 = 0;          // P6 dummy value for now
-        int bank2 = 0;          // P7 dummy value for now
-        ptt_t ptt;              // P8
-        rmode_t mode;           // P9
-        vfo_t vfo;              // P10
-        int scan = 0;           // P11 dummy value for now
-        split_t split = 0;      // P1 2
-        int p13 = 0;            // P13 Tone dummy value for now
-        int p14 = 0;            // P14 Tone Freq dummy value for now
-        int p15 = 0;            // P15 Shift status dummy value for now
+        freq_t freq;            // P1(11)
+        int freq_step = 10;     // P2(4) just use default value for now
+        //int rit_xit_freq = 0; // P3(6) dummy value for now
+        int rit = 0;            // P4(1) dummy value for now
+        int xit = 0;            // P5(1) dummy value for now
+        int bank1 = 0;          // P6(1) dummy value for now
+        int bank2 = 0;          // P7(2) dummy value for now
+        ptt_t ptt;              // P8(1)
+        rmode_t mode;           // P9(1)
+        vfo_t vfo;              // P10(1)
+        int scan = 0;           // P11(1) dummy value for now
+        split_t split = 0;      // P12(1)
+        int p13 = 0;            // P13(1) Tone dummy value for now
+        int p14 = 0;            // P14(2) Tone Freq dummy value for now
+        int p15 = 0;            // P15(1) Shift status dummy value for now
         int retval = rig_get_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
-                                  my_rig->state.cache.split), &freq);
+                                  CACHE(my_rig)->split),
+                                  &freq);
         char response[64];
         char *fmt =
             // cppcheck-suppress *
-            "IF%011"PRIll"%04d+%05d%1d%1d%1d%02d%1d%1"PRIll"%1d%1d%1d%1d%02d%1d;";
+            "IF%011"PRIll"%04d      %1d%1d%1d%02d%1d%1"PRIll"%1d%1d%1d%1d%02d%1d;";
 
         if (retval != RIG_OK)
         {
@@ -773,8 +822,8 @@ static int handle_ts2000(void *arg)
         }
 
         mode = ts2000_get_mode();
-        retval = rig_get_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
-                                               my_rig->state.cache.split), &ptt);
+        retval = rig_get_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split),
+                             &ptt);
 
         if (retval != RIG_OK)
         {
@@ -793,7 +842,10 @@ static int handle_ts2000(void *arg)
 
         if (retval != RIG_OK)
         {
+            vfo = RIG_VFO_A;
+#if 0 // so we work with rigs (like Icom) that have no get_vfo
             return retval;
+#endif
         }
 
         switch (vfo)
@@ -821,7 +873,6 @@ static int handle_ts2000(void *arg)
                  fmt,
                  (uint64_t)freq,
                  freq_step,
-                 rit_xit_freq,
                  rit, xit,
                  bank1,
                  bank2,
@@ -857,7 +908,8 @@ static int handle_ts2000(void *arg)
         char response[32];
 
         int retval = rig_get_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
-                                  my_rig->state.cache.split), &freq);
+                                  CACHE(my_rig)->split),
+                                  &freq);
 
         if (retval != RIG_OK)
         {
@@ -874,7 +926,8 @@ static int handle_ts2000(void *arg)
         char response[32];
         freq_t freq = 0;
         int retval = rig_get_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
-                                  my_rig->state.cache.split), &freq);
+                                  CACHE(my_rig)->split),
+                                  &freq);
 
         if (retval != RIG_OK)
         {
@@ -897,7 +950,7 @@ static int handle_ts2000(void *arg)
     {
         char response[32];
 
-        rig_set_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split), 0);
+        rig_set_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split), 0);
         SNPRINTF(response, sizeof(response), "RX0;");
         return write_block2((void *)__func__, &my_com, response, strlen(response));
     }
@@ -928,8 +981,8 @@ static int handle_ts2000(void *arg)
     }
     else if (strcmp(arg, "TX;") == 0)
     {
-        return rig_set_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
-                                             my_rig->state.cache.split), 1);
+        return rig_set_ptt(my_rig, vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split),
+                           1);
     }
     else if (strcmp(arg, "AI0;") == 0)
     {
@@ -943,13 +996,11 @@ static int handle_ts2000(void *arg)
     }
     else if (strcmp(arg, "FR0;") == 0)
     {
-        return rig_set_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
-                                             my_rig->state.cache.split));
+        return rig_set_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split));
     }
     else if (strcmp(arg, "FR1;") == 0)
     {
-        return rig_set_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
-                                             my_rig->state.cache.split));
+        return rig_set_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_B, CACHE(my_rig)->split));
     }
     else if (strcmp(arg, "FR;") == 0)
     {
@@ -960,14 +1011,17 @@ static int handle_ts2000(void *arg)
 
         if (retval != RIG_OK)
         {
+            vfo = RIG_VFO_A;
+#if 0 // so we work with rigs (like Icom) that have no get_vfo
             rig_debug(RIG_DEBUG_ERR, "%s: get vfo failed: %s\n", __func__,
                       rigerror(retval));
             return retval;
+#endif
         }
 
 
-        if (vfo == vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split)) { nvfo = 0; }
-        else if (vfo == vfo_fixup(my_rig, RIG_VFO_B, my_rig->state.cache.split)) { nvfo = 1; }
+        if (vfo == vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split)) { nvfo = 0; }
+        else if (vfo == vfo_fixup(my_rig, RIG_VFO_B, CACHE(my_rig)->split)) { nvfo = 1; }
         else
         {
             retval = -RIG_EPROTO;
@@ -982,7 +1036,7 @@ static int handle_ts2000(void *arg)
     else if (strcmp(arg, "FT;") == 0)
     {
         char response[32];
-        vfo_t vfo, vfo_curr = vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split);
+        vfo_t vfo, vfo_curr = vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split);
         split_t split;
         int nvfo = 0;
         int retval = rig_get_split_vfo(my_rig, vfo_curr, &split, &vfo);
@@ -995,8 +1049,8 @@ static int handle_ts2000(void *arg)
         }
 
 
-        if (vfo == vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split)) { nvfo = 0; }
-        else if (vfo == vfo_fixup(my_rig, RIG_VFO_B, my_rig->state.cache.split)) { nvfo = 1; }
+        if (vfo == vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split)) { nvfo = 0; }
+        else if (vfo == vfo_fixup(my_rig, RIG_VFO_B, CACHE(my_rig)->split)) { nvfo = 1; }
         else
         {
             retval = -RIG_EPROTO;
@@ -1046,8 +1100,8 @@ static int handle_ts2000(void *arg)
         char response[32];
         int valA;
         int retval = rig_get_func(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
-                                  my_rig->state.cache.split), RIG_FUNC_AIP,
-                                  &valA);
+                                  CACHE(my_rig)->split),
+                                  RIG_FUNC_AIP, &valA);
         int valB;
 
         if (retval != RIG_OK)
@@ -1066,8 +1120,8 @@ static int handle_ts2000(void *arg)
         }
 
         retval = rig_get_func(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
-                                                my_rig->state.cache.split), RIG_FUNC_AIP,
-                              &valB);
+                                                CACHE(my_rig)->split),
+                              RIG_FUNC_AIP, &valB);
 
         if (retval != RIG_OK)
         {
@@ -1093,7 +1147,8 @@ static int handle_ts2000(void *arg)
         }
 
         retval = rig_set_func(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
-                                                my_rig->state.cache.split), RIG_FUNC_AIP, valA);
+                                                CACHE(my_rig)->split),
+                              RIG_FUNC_AIP, valA);
 
         if (retval != RIG_OK)
         {
@@ -1103,7 +1158,8 @@ static int handle_ts2000(void *arg)
         }
 
         retval = rig_set_func(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
-                                                my_rig->state.cache.split), RIG_FUNC_AIP, valB);
+                                                CACHE(my_rig)->split),
+                              RIG_FUNC_AIP, valB);
 
         if (retval != RIG_OK)
         {
@@ -1468,7 +1524,7 @@ static int handle_ts2000(void *arg)
     }
     else if (strcmp(arg, "DC;") == 0)
     {
-        vfo_t vfo, vfo_curr = vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split);
+        vfo_t vfo, vfo_curr = vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split);
         split_t split;
         char response[32];
         int retval = rig_get_split_vfo(my_rig, vfo_curr, &split, &vfo);
@@ -1487,12 +1543,12 @@ static int handle_ts2000(void *arg)
     }
     else if (strncmp(arg, "DC", 2) == 0)
     {
-        vfo_t vfo_curr = vfo_fixup(my_rig, RIG_VFO_A, my_rig->state.cache.split);
+        vfo_t vfo_curr = vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split);
         split_t split;
         int isplit;
         int retval;
         char response[32];
-        // Expecting DCnn -- but we dont' care about the control param
+        // Expecting DCnn -- but we don't care about the control param
         int n = sscanf(arg, "DC%d", &isplit);
 
         if (n != 1)
@@ -1519,14 +1575,14 @@ static int handle_ts2000(void *arg)
     else if (strcmp(arg, "FT0;") == 0)
     {
         return rig_set_split_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_A,
-                                 my_rig->state.cache.split), vfo_fixup(my_rig,
-                                         RIG_VFO_A, my_rig->state.cache.split), 0);
+                                 CACHE(my_rig)->split),
+                                 vfo_fixup(my_rig, RIG_VFO_A, CACHE(my_rig)->split), 0);
     }
     else if (strcmp(arg, "FT1;") == 0)
     {
         return rig_set_split_vfo(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
-                                 my_rig->state.cache.split), vfo_fixup(my_rig,
-                                         RIG_VFO_B, my_rig->state.cache.split), 0);
+                                 CACHE(my_rig)->split),
+                                 vfo_fixup(my_rig, RIG_VFO_B, CACHE(my_rig)->split), 0);
     }
     else if (strncmp(arg, "FA0", 3) == 0)
     {
@@ -1536,20 +1592,18 @@ static int handle_ts2000(void *arg)
         if (mapa2b) { vfo = RIG_VFO_B; }
 
         sscanf((char *)arg + 2, "%"SCNfreq, &freq);
-        return rig_set_freq(my_rig, vfo_fixup(my_rig, vfo,
-                                              my_rig->state.cache.split), freq);
+        return rig_set_freq(my_rig, vfo_fixup(my_rig, vfo, CACHE(my_rig)->split), freq);
     }
     else if (strncmp(arg, "FB0", 3) == 0)
     {
         freq_t freq;
 
         sscanf((char *)arg + 2, "%"SCNfreq, &freq);
-        return rig_set_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_B,
-                                              my_rig->state.cache.split), freq);
+        return rig_set_freq(my_rig, vfo_fixup(my_rig, RIG_VFO_B, CACHE(my_rig)->split),
+                            freq);
     }
     else if (strncmp(arg, "MD", 2) == 0)
     {
-        char response[32];
         mode_t mode = 0;
         int imode = 0;
 
@@ -1577,9 +1631,7 @@ static int handle_ts2000(void *arg)
 
         case 9: mode = RIG_MODE_RTTYR; break;
         }
-
-        SNPRINTF(response, sizeof(response), "MD%c;", mode + '0');
-        return write_block2((void *)__func__, &my_com, response, strlen(response));
+	rig_set_mode(my_rig, RIG_VFO_A, mode, -1);
     }
     else if (strcmp(arg, "PS1;") == 0)
     {
