@@ -20,18 +20,15 @@
  *
  */
 
-#include <hamlib/config.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ctype.h>
-#include <errno.h>
 
 #include <getopt.h>
 
 #include <hamlib/rig.h>
 #include "misc.h"
+#include "riglist.h"
 
 
 /*
@@ -62,7 +59,7 @@ static struct option long_options[] =
     {0, 0, 0, 0}
 };
 
-#define MAXCONFLEN 1024
+#define MAXCONFLEN 2048
 
 
 int main(int argc, char *argv[])
@@ -169,7 +166,7 @@ int main(int argc, char *argv[])
                 return 1;
             }
 
-            strncat(conf_parms, optarg, MAXCONFLEN - strlen(conf_parms));
+            strncat(conf_parms, optarg, MAXCONFLEN - strlen(conf_parms) - 1);
             break;
 
         case 'p':
@@ -260,23 +257,23 @@ int main(int argc, char *argv[])
 
     if (ptt_type != RIG_PTT_NONE)
     {
-        rig->state.pttport.type.ptt = ptt_type;
+        PTTPORT(rig)->type.ptt = ptt_type;
     }
 
     if (ptt_file)
     {
-        strncpy(rig->state.pttport.pathname, ptt_file, HAMLIB_FILPATHLEN - 1);
+        strncpy(PTTPORT(rig)->pathname, ptt_file, HAMLIB_FILPATHLEN - 1);
     }
 
     if (rig_file)
     {
-        strncpy(rig->state.rigport.pathname, rig_file, HAMLIB_FILPATHLEN - 1);
+        strncpy(RIGPORT(rig)->pathname, rig_file, HAMLIB_FILPATHLEN - 1);
     }
 
     /* FIXME: bound checking and port type == serial */
     if (serial_rate != 0)
     {
-        rig->state.rigport.parm.serial.rate = serial_rate;
+        RIGPORT(rig)->parm.serial.rate = serial_rate;
     }
 
     if (civaddr)
@@ -286,7 +283,7 @@ int main(int argc, char *argv[])
 
 
     if (!rig_has_get_level(rig, RIG_LEVEL_SWR)
-            || rig->state.pttport.type.ptt == RIG_PTT_NONE)
+            || PTTPORT(rig)->type.ptt == RIG_PTT_NONE)
     {
 
         fprintf(stderr,
